
function demo_nurbs_indomain_05(domain_type)

%--------------------------------------------------------------------------
% OBJECT:
%--------------------------------------------------------------------------
% Demo illustrating INDOMAIN routine:
%
% In this demo we use the case in which the geometry of the domain is not
% built,  but the description of the boundary in terms of piecewise
% rational splines is available from data.
%--------------------------------------------------------------------------
% Dates
%--------------------------------------------------------------------------
% First version: February 16, 2021;
% Checked: February 16, 2021.
%--------------------------------------------------------------------------

% ------------------------------ Settings ---------------------------------

% Number of tests to determine the median cputime. We suggest to set
% "tests=10", while we do not recommend "tests=1" because it often turns
% out to provide unreliable cputimes.
% We remind that cputime may vary with the computer.
tests=10;

% Nbox is a technical parameter for indomain routine; in doubt set 100.
Nbox=20;

% In indomain routine one must be certain that points are inside the
% domain. In our cubature needs we just wants some points in the domain.
% Consequently, if we are not fully sure that a point is in the domain, due
% to geometrical issues, we do not take it into account.
safe_mode=1;

% We determine a tensorial grid on the smaller rectangle with sides
% parallel to the axis, containing all the control points.
% The grid has "Ngrid" points per dimension. For instance, "Ngrid=100"
% provides a grid with "100 * 100=10000" points.
Ngrid=50;

% The variable "domain_type" set the domain taken into account. The
% invented names are just given to remember something of the region.
%
%       0. Disk
%       1. Lune like
%       2. Tau-like-symbol
%       3. Quadrangloid
%       4. Curved trapezoid
%       5. Weird eta
%       6. Weird eta 2
%       7. Weird eta 3
%       8. Weird eta skinny
%       9. Rough ball
%      10. L-shaped
%      11. M-shaped domain
%      12. defined by a disk, an ellipse and a segment
%      13. defined by a disk, an ellipse, a segment and a free "spline"
%          (variable order)
%      otherwise: defined by a disk, an ellipse, a segment and a free SPLINE
%          (variable order)

if nargin < 1, domain_type=1; end






% ----------------------------- Main code ---------------------------------

%--------------------------------------------------------------------------
% 1. Make SPLINE structure
%--------------------------------------------------------------------------
[sp_xnV,sp_xdV,sp_ynV,sp_ydV,domain_str]=define_domain(domain_type);



%--------------------------------------------------------------------------
% 3. Indomain (several cputime tests!).
%--------------------------------------------------------------------------
fprintf('\n \t ');
for k=1:tests

    tic;
    % Compute box and turning points
    [~,~,~,~,~,~,boxVxy,turn_pts_X, ...
        turn_pts_Y,~]=inRS([],[],Nbox,safe_mode,sp_xnV,sp_xdV,sp_ynV,...
        sp_ydV);

    % Define test pointset.
    [pts,boxXY]=ptsRS([],Ngrid,boxVxy);

    % Determine indomain.
    [in,on,~,~,~,~,boxVxy,turn_pts_X, ...
        turn_pts_Y,pgon]=inRS(pts,[],Nbox,safe_mode,...
        sp_xnV,sp_xdV,sp_ynV,sp_ydV,boxVxy,turn_pts_X,turn_pts_Y);
    cpus(k)=toc;

end


%--------------------------------------------------------------------------
% 4. Plot domain and control points polygon.
%--------------------------------------------------------------------------


h=figure(1);
f1=ishandle(h)&&strcmp(get(h,'type'),'figure');
if f1,clf(1);end
figure(1)
hold on;
axis equal;

% A. plot SPLINE curve (black)
% plotNURBSPL(geometry_SPLINE)
Npieces=length(sp_xnV);
XV=[]; YV=[];
for k=1:Npieces
    sp_xnVL=sp_xnV(k);
    sp_xdVL=sp_xdV(k);
    sp_ynVL=sp_ynV(k);
    sp_ydVL=sp_ydV(k);
    breaksL=sp_xnVL.breaks;
    t0=breaksL(1);
    t1=breaksL(end);
    tV=linspace(t0,t1,10000); tV=tV';
    X=fnval(sp_xnVL,tV)./fnval(sp_xdVL,tV);
    Y=fnval(sp_ynVL,tV)./fnval(sp_ydVL,tV);
    XV=[XV; X]; YV=[YV; Y];
end
plot(XV,YV,'k-','LineWidth',4);

% B. plot test points strictly inside and not strictly inside.

iok=find(in == 1);
plot(pts(iok,1),pts(iok,2),'g.','MarkerEdgeColor','g',...
    'MarkerFaceColor','g','MarkerSize',10);

iko=find(not(in == 1));
plot(pts(iko,1),pts(iko,2),'r.','MarkerEdgeColor','r',...
    'MarkerFaceColor','r','MarkerSize',10);

titlesrt=strcat('Indomain test:  ',num2str(size(pts,1)), ' points');
title(titlesrt);

hold off;

% 
% h=figure(2);
% f2=ishandle(h)&&strcmp(get(h,'type'),'figure');
% if f2,clf(2);end
% figure(2)
% hold on;
% axis equal;
% 
% 
% % A. plot SPLINE curve (black)
% 
% 
% % B. Plot monotone boxes
% LB=size(boxVxy,1);
% for k=1:LB
%     a=boxVxy(k,1); b=boxVxy(k,2); c=boxVxy(k,3); d=boxVxy(k,4);
%     plot([a b b a a],[c c d d c],'c-','LineWidth',3);
% end
% 
% % C. plot turning points
% plot(turn_pts_X(:,1),turn_pts_X(:,2),'bd',...
%     'MarkerEdgeColor','b',...
%     'MarkerFaceColor','b',...
%     'MarkerSize',10);
% 
% plot(turn_pts_Y(:,1),turn_pts_Y(:,2),'md',...
%     'MarkerEdgeColor','m',...
%     'MarkerFaceColor','m',...
%     'MarkerSize',10);
% 
% hold off;


%--------------------------------------------------------------------------
% 5. Display statistics.
%--------------------------------------------------------------------------

fprintf('\n \t ------------------------------------------- \n \t');
fprintf('\n \t            SPLINE INDOMAIN TESTS \n \t');
fprintf('\n \t ------------------------------------------- \n \t');
% fprintf('\n \t DOMAIN: '); disp(domain_str);
fprintf('\n');
fprintf('\n \t # TRIAL POINTS               : %6.0f',size(pts,1));
cardIN=length(find(in == 1));
fprintf('\n \t # TRIAL POINTS IN DOMAIN     : %6.0f \n',cardIN);
fprintf('\n \t MEDIAN CPUTIME               : %1.1e',median(cpus));
fprintf('\n \t CPUTIME TESTS                : %6.0f \n \n',tests);
fprintf('\n \t ------------------------------------------- \n \t');
fprintf('\n \t             PLOT DESCRIPTION \n \t');
fprintf('\n \t ------------------------------------------- \n \t');
fprintf('\n \t FIGURE 1   ');
fprintf('\n ');
fprintf('\n \t * Green dots: points inside the domain.   \n \t');
fprintf('\n \t * Red dots: points not inside the domain.   \n \t');
fprintf('\n ');
% fprintf('\n \t FIGURE 2   ');
% fprintf('\n ');
% fprintf('\n \t * Cyan squares: monotone boxes (even "small")  \n \t');
% % fprintf('\n \t * Black dotted lines: control polygon.   \n \t');
% 
% fprintf('\n \t * Blue diamonds: bound. sing. points X dir.   \n \t');
% fprintf('\n \t * Magenta diamonds: bound. sing. points Y dir.    \n \t');
fprintf('\n \t ------------------------------------------- \n');











%--------------------------------------------------------------------------
% ATTACHED ROUTINES
%--------------------------------------------------------------------------
function [sp_xnV,sp_xdV,sp_ynV,sp_ydV,domain_str]=define_domain(example)

switch example

    case 1 % M-shaped domain

        domain_str='Domain 1: Minion)';
    
         X=  [2.382466960352423e+01     1.121096916299559e+02
            2.428634361233480e+01     1.190348017621145e+02
            2.659471365638768e+01     1.259599118942731e+02
            2.751806167400883e+01     1.305766519823788e+02
            2.890308370044056e+01     1.351933920704845e+02
            2.936475770925113e+01     1.398101321585902e+02
            2.890308370044056e+01     1.462735682819383e+02
            2.705638766519826e+01     1.508903083700440e+02
            2.613303964757710e+01     1.555070484581497e+02
            2.059295154185023e+01     1.582770925110132e+02
            1.366784140969165e+01     1.610471365638766e+02
            8.589427312775342e+00     1.628938325991189e+02
            3.049339207048462e+00     1.661255506607929e+02
            2.125991189427310e+00     1.730506607929515e+02
            3.972687224669613e+00     1.818224669603524e+02
            9.512775330396494e+00     1.827458149779735e+02
            1.320616740088107e+01     1.841308370044052e+02
            1.505286343612334e+01     1.859775330396475e+02
            1.366784140969165e+01     1.901325991189427e+02
            1.643788546255507e+01     1.915176211453744e+02
            1.551453744493392e+01     1.975193832599118e+02
            1.597621145374450e+01     2.021361233480176e+02
            1.782290748898680e+01     2.049061674008810e+02
            2.151629955947135e+01     2.053678414096916e+02
            2.613303964757710e+01     2.049061674008810e+02
            3.213480176211453e+01     2.049061674008810e+02
            3.675154185022029e+01     2.072145374449339e+02
            3.905991189427311e+01     2.150629955947136e+02
            3.998325991189427e+01     2.229114537444934e+02
            4.182995594713657e+01     2.270665198237885e+02
            4.737004405286342e+01     2.330682819383260e+02
            5.106343612334803e+01     2.358383259911894e+02
            5.660352422907488e+01     2.376850220264317e+02
            5.891189427312776e+01     2.386083700440528e+02
            6.352863436123351e+01     2.399933920704846e+02
            6.445198237885461e+01     2.436867841409691e+02
            6.491365638766518e+01     2.455334801762114e+02
            6.075859030837006e+01     2.483035242290749e+02
            5.845022026431718e+01     2.524585903083700e+02
            5.845022026431718e+01     2.575370044052863e+02
            6.399030837004410e+01     2.598453744493392e+02
            7.322378854625549e+01     2.593837004405286e+02
            7.968722466960355e+01     2.575370044052863e+02
            8.615066079295156e+01     2.575370044052863e+02
            8.984405286343616e+01     2.566136563876652e+02
            8.799735682819386e+01     2.473801762114537e+02
            9.169074889867841e+01     2.450718061674008e+02
            9.169074889867841e+01     2.372233480176211e+02
            9.723083700440533e+01     2.386083700440528e+02
            9.723083700440533e+01     2.404550660792951e+02
            1.000008810572687e+02     2.441484581497797e+02
            1.004625550660793e+02     2.515352422907488e+02
            1.046176211453745e+02     2.566136563876652e+02
            1.120044052863436e+02     2.593837004405286e+02
            1.170828193832599e+02     2.598453744493392e+02
            1.221612334801762e+02     2.598453744493392e+02
            1.304713656387665e+02     2.561519823788546e+02
            1.277013215859031e+02     2.501502202643172e+02
            1.235462555066080e+02     2.464568281938326e+02
            1.244696035242291e+02     2.404550660792951e+02
            1.309330396475771e+02     2.395317180616740e+02
            1.383198237885463e+02     2.376850220264317e+02
            1.452449339207049e+02     2.339916299559471e+02
            1.512466960352423e+02     2.293748898678414e+02
            1.567867841409692e+02     2.229114537444934e+02
            1.590951541850220e+02     2.155246696035242e+02
            1.600185022026432e+02     2.090612334801762e+02
            1.600185022026432e+02     2.021361233480176e+02
            1.600185022026432e+02     1.942876651982378e+02
            1.590951541850220e+02     1.855158590308370e+02
            1.577101321585903e+02     1.758207048458149e+02
            1.577101321585903e+02     1.661255506607929e+02
            1.586334801762115e+02     1.573537444933920e+02
            1.618651982378855e+02     1.439651982378854e+02
            1.650969162995595e+02     1.324233480176211e+02
            1.660202643171806e+02     1.254982378854625e+02
            1.683286343612335e+02     1.176497797356828e+02
            1.701753303964758e+02     1.116480176211453e+02
            1.761770925110132e+02     1.107246696035242e+02
            1.761770925110132e+02     1.010295154185021e+02
            1.812555066079295e+02     9.641277533039641e+01
            1.854105726872247e+02     8.671762114537438e+01
            1.891039647577093e+02     7.840748898678407e+01
            1.881806167400881e+02     7.148237885462549e+01
            1.849488986784141e+02     6.917400881057262e+01
            1.798704845814978e+02     7.148237885462549e+01
            1.784854625550661e+02     6.455726872246692e+01
            1.734070484581498e+02     6.271057268722461e+01
            1.683286343612335e+02     6.501894273127749e+01
            1.660202643171806e+02     7.332907488986780e+01
            1.650969162995595e+02     7.840748898678407e+01
            1.609418502202643e+02     7.102070484581492e+01
            1.554017621145375e+02     7.148237885462549e+01
            1.521700440528634e+02     7.471409691629952e+01
            1.540167400881057e+02     8.163920704845810e+01
            1.558634361233480e+02     8.764096916299553e+01
            1.595568281938326e+02     9.271938325991184e+01
            1.609418502202643e+02     9.825947136563872e+01
            1.572484581497798e+02     1.033378854625550e+02
            1.595568281938326e+02     1.065696035242290e+02
            1.581718061674009e+02     1.139563876651982e+02
            1.563251101321586e+02     1.190348017621145e+02
            1.544784140969163e+02     1.250365638766519e+02
            1.507850220264317e+02     1.125713656387665e+02
            1.484766519823789e+02     1.070312775330396e+02
            1.470916299559472e+02     1.001061674008810e+02
            1.457066079295154e+02     9.133436123348014e+01
            1.438599118942731e+02     8.440925110132153e+01
            1.429365638766520e+02     7.886916299559465e+01
            1.424748898678414e+02     7.286740088105724e+01
            1.447832599118943e+02     7.148237885462549e+01
            1.424748898678414e+02     6.455726872246692e+01
            1.420132158590308e+02     5.947885462555061e+01
            1.401665198237886e+02     5.624713656387661e+01
            1.369348017621145e+02     5.070704845814973e+01
            1.332414096916299e+02     4.285859030836997e+01
            1.309330396475771e+02     4.055022026431711e+01
            1.277013215859031e+02     3.824185022026427e+01
            1.249312775330396e+02     3.454845814977966e+01
            1.263162995594714e+02     3.316343612334796e+01
            1.290863436123348e+02     3.224008810572681e+01
            1.341647577092511e+02     2.947004405286339e+01
            1.360114537444934e+02     2.854669603524223e+01
            1.300096916299560e+02     2.854669603524223e+01
            1.244696035242291e+02     3.131674008810566e+01
            1.216995594713656e+02     3.131674008810566e+01
            1.226229074889868e+02     2.808502202643166e+01
            1.267779735682819e+02     2.531497797356820e+01
            1.309330396475771e+02     2.392995594713651e+01
            1.235462555066080e+02     2.531497797356820e+01
            1.166211453744493e+02     2.762334801762108e+01
            1.152361233480177e+02     2.669999999999993e+01
            1.193911894273128e+02     2.300660792951535e+01
            1.235462555066080e+02     1.931321585903078e+01
            1.300096916299560e+02     1.792819383259905e+01
            1.364731277533040e+02     1.746651982378847e+01
            1.309330396475771e+02     1.654317180616732e+01
            1.226229074889868e+02     1.746651982378847e+01
            1.133894273127754e+02     2.023656387665193e+01
            1.092343612334802e+02     2.115991189427308e+01
            1.032325991189427e+02     2.023656387665193e+01
            1.060026431718062e+02     1.377312775330390e+01
            1.138511013215859e+02     8.233039647577016e+00
            1.166211453744493e+02     4.539647577092467e+00
            1.078493392070484e+02     8.694713656387592e+00
            1.018475770925110e+02     1.469647577092505e+01
            1.013859030837004e+02     1.885154185022020e+01
            9.492246696035244e+01     1.977488986784135e+01
            9.353744493392071e+01     1.331145374449332e+01
            9.584581497797359e+01     4.077973568281891e+00
            9.492246696035244e+01    -1.462114537445018e+00
            9.030572687224668e+01     6.848017621145318e+00
            8.892070484581501e+01     1.238810572687220e+01
            8.845903083700443e+01     1.654317180616732e+01
            8.245726872246695e+01     1.838986784140963e+01
            7.922555066079298e+01     1.654317180616732e+01
            7.968722466960355e+01     9.618061674008743e+00
            8.061057268722470e+01     1.307929515418436e+00
            7.691718061674010e+01     3.616299559471315e+00
            7.691718061674010e+01     9.618061674008743e+00
            7.507048458149779e+01     1.654317180616732e+01
            7.368546255506607e+01     1.746651982378847e+01
            6.768370044052864e+01     1.885154185022020e+01
            6.168193832599122e+01     2.069823788546250e+01
            5.660352422907488e+01     1.700484581497790e+01
            5.106343612334803e+01     1.331145374449332e+01
            4.367665198237887e+01     1.100308370044047e+01
            3.952158590308369e+01     1.192643171806162e+01
            4.460000000000002e+01     1.469647577092505e+01
            5.014008810572687e+01     1.746651982378847e+01
            5.291013215859033e+01     2.254493392070478e+01
            4.783171806167400e+01     2.808502202643166e+01
            4.136828193832599e+01     3.131674008810566e+01
            3.490484581497799e+01     3.177841409691624e+01
            2.797973568281941e+01     2.623832599118936e+01
            1.782290748898680e+01     2.947004405286339e+01
            2.336299559471365e+01     3.131674008810566e+01
            3.167312775330396e+01     3.362511013215852e+01
            3.351982378854626e+01     3.731850220264312e+01
            2.705638766519826e+01     4.101189427312769e+01
            1.689955947136565e+01     3.685682819383254e+01
            9.512775330396494e+00     3.962687224669600e+01
            9.512775330396494e+00     4.378193832599112e+01
            2.013127753303965e+01     4.147356828193827e+01
            2.428634361233480e+01     4.470528634361227e+01
            2.474801762114538e+01     4.562863436123342e+01
            2.151629955947135e+01     5.163039647577085e+01
            2.059295154185023e+01     5.809383259911888e+01
            1.966960352422907e+01     6.409559471365634e+01
            1.736123348017622e+01     7.194405286343607e+01
            1.736123348017622e+01     7.886916299559465e+01
            1.459118942731280e+01     8.302422907488983e+01
            1.597621145374450e+01     8.902599118942726e+01
            1.597621145374450e+01     9.364273127753299e+01
            1.689955947136565e+01     9.733612334801757e+01
            2.013127753303965e+01     9.733612334801757e+01
            2.151629955947135e+01     1.024145374449339e+02
            2.151629955947135e+01     1.056462555066079e+02];

        P=-[X; X(1,:)]/max(abs(X(:,1)));
        geometry_SPLINE=makeSPLINEarc('free','P',P,'order',4);
        [sp_xnV,sp_xdV,sp_ynV,sp_ydV]=NURBSPL2ratsplines(geometry_SPLINE,...
            'pp');



    case 2

        domain_str='Domain 2: Felix the cat.)';
        order=3;

        X=[ 8.157500000000000e+02     1.607500000000000e+03
            8.637500000000000e+02     1.628500000000000e+03
            9.237500000000000e+02     1.640500000000000e+03
            9.807500000000000e+02     1.655500000000000e+03
            1.046750000000000e+03     1.655500000000000e+03
            1.127750000000000e+03     1.649500000000000e+03
            1.193750000000000e+03     1.613500000000000e+03
            1.238750000000000e+03     1.571500000000000e+03
            1.229750000000000e+03     1.505500000000000e+03
            1.187750000000000e+03     1.448500000000000e+03
            1.130750000000000e+03     1.418500000000000e+03
            1.061750000000000e+03     1.436500000000000e+03
            9.807500000000000e+02     1.457500000000000e+03
            1.094750000000000e+03     1.007500000000000e+03
            1.103750000000000e+03     8.965000000000000e+02
            1.079750000000000e+03     8.275000000000000e+02
            1.043750000000000e+03     7.915000000000000e+02
            9.747500000000000e+02     7.645000000000000e+02
            9.657500000000000e+02     7.495000000000000e+02
            1.019750000000000e+03     7.285000000000000e+02
            1.076750000000000e+03     6.985000000000000e+02
            1.124750000000000e+03     6.625000000000000e+02
            1.160750000000000e+03     6.295000000000000e+02
            1.199750000000000e+03     5.905000000000000e+02
            1.259750000000000e+03     6.295000000000000e+02
            1.310750000000000e+03     6.565000000000000e+02
            1.373750000000000e+03     6.775000000000000e+02
            1.430750000000000e+03     6.535000000000000e+02
            1.484750000000000e+03     6.325000000000000e+02
            1.484750000000000e+03     5.875000000000000e+02
            1.493750000000000e+03     5.695000000000000e+02
            1.451750000000000e+03     5.335000000000000e+02
            1.409750000000000e+03     5.125000000000000e+02
            1.355750000000000e+03     4.765000000000001e+02
            1.295750000000000e+03     4.315000000000001e+02
            1.334750000000000e+03     3.835000000000000e+02
            1.328750000000000e+03     3.235000000000000e+02
            1.304750000000000e+03     2.935000000000000e+02
            1.256750000000000e+03     2.995000000000000e+02
            1.244750000000000e+03     3.415000000000000e+02
            1.232750000000000e+03     3.925000000000000e+02
            1.220750000000000e+03     4.045000000000000e+02
            1.178750000000000e+03     4.105000000000000e+02
            1.154750000000000e+03     4.495000000000001e+02
            1.100750000000000e+03     5.275000000000000e+02
            1.031750000000000e+03     5.875000000000000e+02
            9.507500000000000e+02     6.415000000000000e+02
            9.867500000000001e+02     5.785000000000000e+02
            1.013750000000000e+03     5.155000000000000e+02
            1.013750000000000e+03     4.615000000000001e+02
            1.013750000000000e+03     4.195000000000001e+02
            1.025750000000000e+03     3.895000000000000e+02
            1.025750000000000e+03     3.535000000000000e+02
            1.007750000000000e+03     3.205000000000000e+02
            9.867500000000001e+02     3.175000000000000e+02
            9.597500000000000e+02     2.455000000000000e+02
            9.117499999999999e+02     1.915000000000000e+02
            8.577500000000001e+02     1.435000000000000e+02
            7.887500000000000e+02     1.135000000000000e+02
            7.347500000000000e+02     8.950000000000000e+01
            6.957500000000000e+02     5.650000000000000e+01
            6.447500000000000e+02     8.500000000000000e+00
            6.057500000000000e+02     9.550000000000000e+01
            5.487500000000000e+02     1.015000000000000e+02
            5.007500000000000e+02     1.255000000000000e+02
            4.407499999999999e+02     9.850000000000000e+01
            3.447500000000000e+02     5.350000000000000e+01
            3.507500000000000e+02     1.375000000000000e+02
            3.417500000000000e+02     2.005000000000000e+02
            3.447500000000000e+02     2.875000000000000e+02
            3.357500000000000e+02     3.775000000000000e+02
            3.147500000000000e+02     4.735000000000001e+02
            2.787500000000000e+02     5.455000000000000e+02
            3.147500000000000e+02     5.815000000000000e+02
            3.717500000000000e+02     6.055000000000000e+02
            3.267500000000000e+02     6.235000000000000e+02
            4.107500000000000e+02     6.565000000000000e+02
            3.627500000000000e+02     6.475000000000000e+02
            3.027500000000000e+02     6.385000000000000e+02
            2.877500000000000e+02     6.025000000000000e+02
            2.517500000000000e+02     5.965000000000000e+02
            2.127500000000000e+02     5.905000000000000e+02
            1.857500000000000e+02     5.605000000000000e+02
            1.587500000000000e+02     5.185000000000000e+02
            1.167500000000000e+02     5.035000000000001e+02
            9.274999999999997e+01     5.365000000000000e+02
            9.274999999999997e+01     5.875000000000000e+02
            1.197500000000000e+02     6.355000000000000e+02
            1.497500000000000e+02     6.745000000000000e+02
            1.317500000000000e+02     7.105000000000000e+02
            8.974999999999997e+01     7.345000000000000e+02
            4.774999999999997e+01     7.585000000000000e+02
            1.774999999999997e+01     7.825000000000000e+02
            1.474999999999997e+01     8.155000000000000e+02
            1.174999999999997e+01     8.305000000000000e+02
            3.574999999999997e+01     8.665000000000000e+02
            6.574999999999997e+01     8.755000000000000e+02
            9.574999999999997e+01     8.965000000000000e+02
            1.497500000000000e+02     8.875000000000000e+02
            2.007500000000000e+02     8.665000000000000e+02
            2.517500000000000e+02     8.335000000000000e+02
            2.907500000000000e+02     8.005000000000000e+02
            3.267500000000000e+02     7.855000000000000e+02
            3.897499999999999e+02     7.945000000000000e+02
            4.497500000000000e+02     8.125000000000000e+02
            5.157500000000000e+02     8.155000000000000e+02
            5.757500000000000e+02     8.215000000000000e+02
            6.237500000000000e+02     8.275000000000000e+02
            6.807500000000000e+02     8.185000000000000e+02
            7.377500000000000e+02     8.155000000000000e+02
            7.677500000000000e+02     8.305000000000000e+02
            7.677500000000000e+02     8.545000000000000e+02
            7.557500000000000e+02     9.025000000000000e+02
            7.617500000000000e+02     9.445000000000000e+02
            7.767500000000000e+02     9.865000000000000e+02
            7.947500000000000e+02     1.022500000000000e+03
            7.797500000000000e+02     1.076500000000000e+03
            7.647500000000000e+02     1.112500000000000e+03
            7.167500000000000e+02     1.139500000000000e+03
            6.657500000000000e+02     1.157500000000000e+03
            6.147500000000000e+02     1.151500000000000e+03
            5.757500000000000e+02     1.118500000000000e+03
            5.367500000000000e+02     1.058500000000000e+03
            4.857500000000000e+02     1.046500000000000e+03
            4.377500000000000e+02     1.064500000000000e+03
            4.167500000000000e+02     1.127500000000000e+03
            4.317500000000000e+02     1.190500000000000e+03
            4.707500000000001e+02     1.229500000000000e+03
            5.157500000000000e+02     1.253500000000000e+03
            5.757500000000000e+02     1.268500000000000e+03
            6.387500000000000e+02     1.259500000000000e+03
            6.927500000000000e+02     1.256500000000000e+03
            7.527500000000000e+02     1.238500000000000e+03
            7.437500000000000e+02     1.292500000000000e+03
            7.257500000000000e+02     1.346500000000000e+03
            7.167500000000000e+02     1.403500000000000e+03
            6.957500000000000e+02     1.451500000000000e+03
            6.927500000000000e+02     1.466500000000000e+03
            6.357500000000000e+02     1.478500000000000e+03
            5.727500000000000e+02     1.463500000000000e+03
            5.217500000000000e+02     1.466500000000000e+03
            4.527500000000000e+02     1.487500000000000e+03
            4.167500000000000e+02     1.526500000000000e+03
            4.017500000000000e+02     1.583500000000000e+03
            4.347500000000001e+02     1.634500000000000e+03
            4.947500000000000e+02     1.649500000000000e+03
            5.727500000000000e+02     1.652500000000000e+03
            6.597500000000000e+02     1.652500000000000e+03
            7.377500000000000e+02     1.646500000000000e+03
            7.887500000000000e+02     1.622500000000000e+03];

        P=-[X; X(1,:)]/max(abs(X(:,1)));

        kk=size(P,1)-order;
        knots_mid=linspace(0.1,0.9,kk);
        knots=[0 0 0 knots_mid 1 1 1]; % 12-3
        w=1000*ones(1,size(P,1));

        geometry_NURBS=makeNURBSarc('free','P',...
            P,'knots',knots,'weights',w,'order',order);

        [sp_xnV,sp_xdV,sp_ynV,sp_ydV]=NURBSPL2ratsplines(geometry_NURBS);

    case 3 
        
         domain_str='S(40): snoopy';
        order=5;

        X=[     5.600000000000000e+02     6.480000000000001e+02
            5.480000000000000e+02     6.120000000000001e+02
            5.460000000000000e+02     5.900000000000001e+02
            5.460000000000000e+02     5.440000000000001e+02
            5.480000000000000e+02     5.060000000000001e+02
            5.660000000000000e+02     4.920000000000001e+02
            5.900000000000000e+02     4.600000000000001e+02
            6.120000000000000e+02     4.500000000000001e+02
            6.340000000000000e+02     4.500000000000001e+02
            6.580000000000000e+02     4.780000000000001e+02
            7.039999999999999e+02     4.780000000000001e+02
            7.479999999999999e+02     4.600000000000001e+02
            7.899999999999999e+02     4.100000000000001e+02
            8.039999999999999e+02     3.440000000000002e+02
            8.179999999999999e+02     2.580000000000002e+02
            8.039999999999999e+02     1.840000000000002e+02
            7.779999999999999e+02     1.160000000000002e+02
            7.359999999999999e+02     7.800000000000023e+01
            6.879999999999999e+02     4.200000000000023e+01
            6.440000000000000e+02     1.600000000000023e+01
            5.920000000000000e+02     1.600000000000023e+01
            5.440000000000000e+02     2.200000000000023e+01
            5.220000000000000e+02     3.200000000000023e+01
            5.180000000000000e+02     8.000000000000227e+00
            4.840000000000001e+02     6.000000000000227e+00
            4.800000000000000e+02     2.200000000000023e+01
            4.980000000000001e+02     2.600000000000023e+01
            5.060000000000000e+02     5.400000000000023e+01
            4.879999999999999e+02     7.200000000000023e+01
            4.480000000000000e+02     1.060000000000002e+02
            4.020000000000000e+02     1.100000000000002e+02
            3.540000000000000e+02     1.160000000000002e+02
            2.860000000000000e+02     1.300000000000002e+02
            2.320000000000001e+02     1.660000000000002e+02
            1.880000000000001e+02     2.080000000000002e+02
            1.640000000000001e+02     2.520000000000002e+02
            1.540000000000001e+02     2.940000000000002e+02
            1.220000000000001e+02     3.080000000000002e+02
            1.020000000000001e+02     3.280000000000002e+02
            8.000000000000011e+01     3.700000000000001e+02
            9.200000000000009e+01     4.040000000000001e+02
            1.440000000000001e+02     3.920000000000001e+02
            1.800000000000001e+02     4.000000000000001e+02
            2.100000000000001e+02     4.320000000000001e+02
            2.520000000000001e+02     4.440000000000001e+02
            3.000000000000000e+02     4.580000000000001e+02
            3.420000000000000e+02     4.720000000000001e+02
            3.840000000000000e+02     4.800000000000001e+02
            4.320000000000000e+02     4.900000000000001e+02
            4.660000000000000e+02     5.100000000000001e+02
            4.719999999999999e+02     5.460000000000001e+02
            4.540000000000001e+02     5.620000000000001e+02
            4.680000000000001e+02     5.840000000000001e+02
            4.580000000000000e+02     6.160000000000001e+02
            4.340000000000000e+02     6.460000000000001e+02
            4.140000000000000e+02     6.760000000000001e+02
            4.040000000000000e+02     7.140000000000001e+02
            3.980000000000000e+02     7.660000000000000e+02
            4.080000000000000e+02     8.220000000000000e+02
            4.340000000000000e+02     8.540000000000000e+02
            4.660000000000000e+02     8.740000000000000e+02
            4.640000000000000e+02     9.000000000000000e+02
            4.240000000000000e+02     9.160000000000000e+02
            3.700000000000000e+02     9.140000000000000e+02
            3.340000000000000e+02     9.260000000000000e+02
            3.060000000000000e+02     9.260000000000000e+02
            2.860000000000000e+02     9.460000000000000e+02
            2.700000000000001e+02     9.860000000000000e+02
            3.100000000000000e+02     1.008000000000000e+03
            3.540000000000000e+02     1.012000000000000e+03
            3.940000000000000e+02     1.016000000000000e+03
            4.380000000000000e+02     1.020000000000000e+03
            4.859999999999999e+02     1.022000000000000e+03
            5.280000000000000e+02     1.018000000000000e+03
            5.680000000000000e+02     1.018000000000000e+03
            6.120000000000000e+02     1.006000000000000e+03
            6.540000000000000e+02     9.980000000000000e+02
            6.819999999999999e+02     9.920000000000000e+02
            6.619999999999999e+02     9.540000000000000e+02
            6.180000000000000e+02     9.380000000000000e+02
            5.800000000000000e+02     9.300000000000000e+02
            5.800000000000000e+02     9.000000000000000e+02
            5.740000000000000e+02     8.740000000000000e+02
            5.980000000000000e+02     8.640000000000000e+02
            6.460000000000000e+02     8.840000000000000e+02
            6.799999999999999e+02     8.900000000000000e+02
            7.239999999999999e+02     8.860000000000000e+02
            7.599999999999999e+02     8.740000000000000e+02
            7.799999999999999e+02     8.740000000000000e+02
            7.339999999999999e+02     8.560000000000000e+02
            7.039999999999999e+02     8.520000000000000e+02
            6.779999999999999e+02     8.480000000000000e+02
            6.400000000000000e+02     8.400000000000000e+02
            6.280000000000000e+02     8.340000000000000e+02
            6.140000000000000e+02     8.220000000000000e+02
            6.140000000000000e+02     7.860000000000000e+02
            6.140000000000000e+02     7.560000000000000e+02
            6.000000000000000e+02     7.240000000000001e+02
            5.900000000000000e+02     7.020000000000001e+02
            5.740000000000000e+02     6.800000000000001e+02];

        P=-[X; X(1,:)]/max(abs(X(:,1)));

        geometry_SPLINE=makeBEZIERarc('free','P',P,'order',order);
        [sp_xnV,sp_xdV,sp_ynV,sp_ydV]=NURBSPL2ratsplines(geometry_SPLINE,...
            'pp');

end

