
function demo_nurbs_indomain_06(domain_type)

%--------------------------------------------------------------------------
% OBJECT:
%--------------------------------------------------------------------------
% Demo illustrating INDOMAIN routine:
%
% In this demo we consider the case in which the geometry of the domain is 
% given through a point cloud that approximates the boundary.
% In particular
% 1. We approximate via smoothing periodic cubic splines the boundary,
% 2. we perform the indomain routine on a tensorial grid belonging to the
%    bounding box of the domain,
% 3. Plot results.
%--------------------------------------------------------------------------
% Dates
%--------------------------------------------------------------------------
% First version: February 17, 2022.
% Checked: February 22, 2022 (14:43).
%--------------------------------------------------------------------------

if not(isfile('spcsp.m'))
    fprintf('\n \t This routine requires spcsp.m available at');
    fprintf('\n \t https://it.mathworks.com/matlabcentral/fileexchange/');
    fprintf('\n \t 59463-smoothing-cubic-splines-with-periodic-conditions');
    return;
end

% ................. Define pointset parameters  .....................

Ngrid=100; %  The grid in the bound. box is given by a 100x100 tensor. grid
Nbox=100;  % Number of subboxes per monotone box.
safe_mode=1; % Certificate points on the boundary.


% ................. Define a circle via noisy points  .....................

if nargin< 1, domain_type=3; end

switch domain_type
    case 1 % ellipse
        p=0.5; % smoothing parameter
        a = 2; b = 4;
        t = 0:.2:2*pi;
        Y = [a*cos(t); b*sin(t)] + ...
            8*10^(-2)*(rand(2,length(t))-0.5);
    case 2 % cardioid
        p=0.5; % smoothing parameter
        t = 0:.2:2*pi;
        Y = [(1-cos(t)).*cos(t); (1-cos(t)).*sin(t)] + ...
            8*10^(-2)*(rand(2,length(t))-0.5);
    case 3
        p=0.995; % smoothing parameter
        Y=[-1 1; -1 0; -1 -1; -0.6 -1; -0.6 0; -0.6 0.6; 0 0; 0.6 0.6; ...
            0.6 0; 0.6 -1; 1 -1; 1 0; 1 1; 0.6 1; 0 0.4; -0.6 1; -1 1];
        Y=Y'+8*10^(-2)*(rand(size(Y'))-0.5);
        t=1:size(Y,2);
end



x = 1:numel(t);
xx = linspace(x(1),x(end),10*length(x)+1);
pp = spcsp(x,Y,p);
val = ppval(pp,xx);



% ................. Define splines  .....................

% x numerator
SxN=pp;
SxN_coefs=SxN.coefs;
SxN_coefs=SxN_coefs(1:2:end,:);
SxN.coefs=SxN_coefs;
SxN.dim=1;

% y numerator
SyN=pp;
SyN_coefs=SyN.coefs;
SyN_coefs=SyN_coefs(2:2:end,:);
SyN.coefs=SyN_coefs;
SyN.dim=1;

% x,y denominator.
% By setting SxD, SyD as empty matrix, the indomain routine will set the
% "x=ppval(SxN,t)" and "y=ppval(SyN,t)".
SxD=[]; SyD=[];




% ................. In domain code  .....................

% Compute box and turning points
[~,~,~,~,~,~,boxVxy,turn_pts_X, ...
    turn_pts_Y,~]=inRS([],[],Nbox,safe_mode,SxN,SxD,SyN,...
    SyD);

% Define test pointset.
[pts,boxXY]=ptsRS([],Ngrid,boxVxy);

% Determine indomain.
[in,on,~,~,~,~,boxVxy,turn_pts_X, ...
    turn_pts_Y,pgon]=inRS(pts,[],Nbox,safe_mode,...
    SxN,SxD,SyN,SyD,boxVxy,turn_pts_X,turn_pts_Y);


% ................. plot pointset / domain  .....................
h=figure(1);
f1=ishandle(h)&&strcmp(get(h,'type'),'figure');
if f1,clf(1);end
figure(1)
hold on;
axis equal;
axis off;

% Plot boundary point cloud
plot(Y(1,:),Y(2,:),'co',...
    'LineWidth',4, ...
    'MarkerEdgeColor','k',...
    'MarkerFaceColor','c',...
    'MarkerSize',10);

% Plot boundary approximation
plot(val(1,:),val(2,:),'k-','LineWidth',4);

% Plot pointset
plot(pts(:,1),pts(:,2),'ro',...
    'MarkerEdgeColor','r',...
    'MarkerFaceColor','r',...
    'MarkerSize',3);

% Plot internal points
iok=find(in == 1);
C=[56 142 60]/256;
plot(pts(iok,1),pts(iok,2),'go',...
    'MarkerEdgeColor',C,...
    'MarkerFaceColor',C,...
    'MarkerSize',3);

% Plot boundary points
ion=find(on == 1);
plot(pts(ion,1),pts(ion,2),'go',...
    'MarkerEdgeColor','g',...
    'MarkerFaceColor','g',...
    'MarkerSize',20);

hold off


