
function demo_nurbs_indomain_08(domain_type)

%--------------------------------------------------------------------------
% OBJECT:
%--------------------------------------------------------------------------
% Demo illustrating INDOMAIN routine:
%
% In this demo we use the case in which the geometry of the domain is given
% through a point cloud that define the whole domain.
% 1. We approximate via alphashape the boundary, 
% 2. we approximate the latter via cubic smoothing spline,
% 3. we perform the indomain routine on a tensorial grid belonging to the
% bounding box of the domain.
%--------------------------------------------------------------------------
% Dates
%--------------------------------------------------------------------------
% First version: February 17, 2022.
% Checked: February 22, 2022 (14:43).
%--------------------------------------------------------------------------

if not(isfile('spcsp.m'))
    fprintf('\n \t This routine requires spcsp.m available at');
    fprintf('\n \t https://it.mathworks.com/matlabcentral/fileexchange/');
    fprintf('\n \t 59463-smoothing-cubic-splines-with-periodic-conditions');
    return;
end
% ................. Define pointset parameters  ...........................

% Nbox is a technical parameter for indomain routine; in doubt set 100.
% It is the number of subboxes per monotone box.

Nbox=100;

% In indomain routine one must be certain that points are inside the
% domain. In our cubature needs we just wants some points in the domain.
% Consequently, if we are not fully sure that a point is in the domain, due
% to geometrical issues, we do not take it into account.

safe_mode=1;

% Pointset:
% if 'grid' then an equispaced tensorial grid with "Npts^2" is provided
% if 'halton' or 'rand' then a bivariate pointset with "Npts" respectively
% Halton or random points is choosen.

pointset='grid';

% If 'pointset' is equal to
% 'grid' then an equispaced tensorial grid with "Npts^2" is provided
% 'halton' or 'rand' then a bivariate pointset with "Npts" respectively
% Halton or random points is choosen.

Npts=100;

% Domain type:
% 1. Elliptical data cloud (from noisy domain definition),
% 2. Cardioid data cloud  (from noisy domain definition),
% 3. M data cloud (from discrete data).

if nargin < 1, domain_type=2; end



% ................. Define a circle via noisy points  .....................
% Pcloud defines a point cloud. "p" is alphashape parameter.
[Pcloud,pSHP]=define_domain(domain_type); 

% .................. Get the boundary by alphashape .......................
shp = alphaShape(Pcloud(:,1),Pcloud(:,2),pSHP);
ptsSHP=shp.Points;
[bf, p] = shp.boundaryFacets();
bf = bf';
% compute vertices "[xp,yp]" of the polygon bounding the cloud
xp = p(:,1); yp = p(:,2); xp = xp(bf); yp = yp(bf);

% .......................... Define NURBS .................................
XV=(xp(1,1:end))';  XV(end+1,:)=XV(1,:);
YV=(yp(1,1:end))';  YV(end+1,:)=YV(1,:);
P=[XV YV]; P=P';
t=1:size(P,2);
x = 1:numel(t);
xx = linspace(x(1),x(end),10*length(x)+1);


pp = spcsp(x,P,pSHP);
val = ppval(pp,xx);



% ................. Define splines  .....................

% x numerator
SxN=pp;
SxN_coefs=SxN.coefs;
SxN_coefs=SxN_coefs(1:2:end,:);
SxN.coefs=SxN_coefs;
SxN.dim=1;

% y numerator
SyN=pp;
SyN_coefs=SyN.coefs;
SyN_coefs=SyN_coefs(2:2:end,:);
SyN.coefs=SyN_coefs;
SyN.dim=1;

% x,y denominator.
% By setting SxD, SyD as empty matrix, the indomain routine will set the
% "x=ppval(SxN,t)" and "y=ppval(SyN,t)".
SxD=[]; SyD=[];




% ................. In domain code  .....................

% Compute box and turning points
[~,~,~,~,~,~,boxVxy,turn_pts_X, ...
    turn_pts_Y,~]=inRS([],[],Nbox,safe_mode,SxN,[],SyN,...
    []);

% Define test pointset.
[pts,boxXY]=ptsRS([],Npts,boxVxy);

% Determine indomain.
[in,on,~,~,~,~,boxVxy,turn_pts_X, ...
    turn_pts_Y,pgon]=inRS(pts,[],Nbox,safe_mode,...
    SxN,SxD,SyN,SyD,boxVxy,turn_pts_X,turn_pts_Y);




% ................... Plot domain via cloud & alphashape ..................

h=figure(1);
f1=ishandle(h)&&strcmp(get(h,'type'),'figure');
if f1,clf(1);end
figure(1)
hold on;
axis equal;
axis off;
C=[56 142 60]/256;
plot(Pcloud(:,1),Pcloud(:,2),'o',...
    'LineWidth',2, ...
    'MarkerEdgeColor',C,...
    'MarkerFaceColor',C,...
    'MarkerSize',2);
plot(ptsSHP(:,1),ptsSHP(:,2),'co',...
    'LineWidth',2, ...
    'MarkerEdgeColor','k',...
    'MarkerFaceColor','c',...
    'MarkerSize',2);

plot(xp,yp,'k-','LineWidth',2);

breaksV=SxN.breaks;
aa=breaksV(1); bb=breaksV(end);
tt=linspace(aa,bb,1000);
xB=ppval(SxN,tt);
yB=ppval(SyN,tt);
plot(xB,yB,'m-','LineWidth',4);

% plotNURBSPL(geometry_NURBS)
hold off;


h=figure(2);
f2=ishandle(h)&&strcmp(get(h,'type'),'figure');
if f2,clf(2);end
figure(2)
hold on;
axis equal;
axis off;
C=[56 142 60]/256;
plot(xB,yB,'m-','LineWidth',4);

plot(pts(:,1),pts(:,2),'o',...
    'LineWidth',2, ...
    'MarkerEdgeColor','r',...
    'MarkerFaceColor','r',...
    'MarkerSize',2);

iok=find(in == 1);
plot(pts(iok,1),pts(iok,2),'o',...
    'LineWidth',2, ...
    'MarkerEdgeColor',C,...
    'MarkerFaceColor',C,...
    'MarkerSize',2);

hold off;




function [Y,p]=define_domain(domain_type)

switch domain_type
    case 1 % ellipse
        p=0.5; % alphashape parameter
        a = 2; b = 4;
        t = 1:10^4; t=t';
        r=rand(size(t,1),1);
        theta=rand(size(t,1),1)*2*pi;
        noisy=8*10^(-2)*(rand(length(t),2)-0.5);
        val=[a*cos(theta) b*sin(theta)];
        Y = r.*val + noisy;
        
        
        
    case 2 % cardioid
        p=0.08; % alphashape parameter
        t = 1:10000; t=t';
        r=rand(size(t,1),1);
        theta=rand(size(t,1),1)*2*pi;
        noisy=8*10^(-2)*(rand(length(t),2)-0.5);
        val=[(1-cos(theta)).*cos(theta) (1-cos(theta)).*sin(theta)];
        Y = r.*val + noisy;
        
    case 3
        p=0.08;
        Y=[ -7.500000000000000e-01    -1.111111111111112e-01
     2.500000000000000e-01     5.555555555555554e-01
     7.500000000000000e-01     1.111111111111112e-01
    -8.750000000000000e-01     7.777777777777777e-01
     6.250000000000000e-01     4.074074074074074e-01
    -6.250000000000000e-01    -7.037037037037037e-01
     8.750000000000000e-01    -4.814814814814815e-01
    -9.375000000000000e-01     1.851851851851851e-01
    -6.875000000000000e-01     4.814814814814814e-01
     8.125000000000000e-01     7.037037037037035e-01
    -8.125000000000000e-01    -4.074074074074074e-01
     1.875000000000000e-01     2.592592592592593e-01
     9.375000000000000e-01    -8.641975308641980e-02
    -9.687500000000000e-01     5.802469135802468e-01
     5.312500000000000e-01     8.024691358024691e-01
    -7.187500000000000e-01    -9.012345679012346e-01
    -2.187500000000000e-01     4.320987654320989e-01
     7.812500000000000e-01    -6.790123456790124e-01
    -8.437500000000000e-01    -1.234567901234573e-02
     6.562500000000000e-01     2.098765432098766e-01
    -5.937500000000000e-01     8.765432098765431e-01
     9.062500000000000e-01     5.061728395061729e-01
    -9.062500000000000e-01    -6.049382716049383e-01
    -4.062500000000000e-01     7.283950617283947e-01
    -6.562500000000000e-01     2.839506172839505e-01
     8.437500000000000e-01    -2.839506172839507e-01
    -7.812500000000000e-01     3.827160493827160e-01
     7.187500000000000e-01     6.049382716049381e-01
    -9.843750000000000e-01    -2.098765432098766e-01
     1.562500000000000e-02     4.567901234567902e-01
    -7.343750000000000e-01     6.790123456790120e-01
     7.656250000000000e-01     9.012345679012344e-01
    -8.593750000000000e-01    -8.024691358024691e-01
    -3.593750000000000e-01     5.308641975308641e-01
     6.406250000000000e-01    -5.802469135802469e-01
    -6.093750000000000e-01     8.641975308641969e-02
     3.906250000000000e-01     7.530864197530862e-01
     8.906250000000000e-01     3.086419753086420e-01
    -9.218750000000000e-01     9.753086419753085e-01
    -6.718750000000000e-01    -7.695473251028807e-01
    -1.718750000000000e-01     5.637860082304524e-01
     8.281250000000000e-01    -5.473251028806585e-01
    -7.968750000000000e-01     1.193415637860082e-01
     7.031250000000000e-01    -2.510288065843622e-01
     9.531250000000000e-01     6.378600823045264e-01
    -9.531250000000000e-01    -4.732510288065844e-01
     4.687500000000000e-02     1.934156378600822e-01
    -7.031250000000000e-01    -1.769547325102881e-01
     2.968750000000000e-01     4.897119341563785e-01
     7.968750000000000e-01     4.526748971193406e-02
    -8.281250000000000e-01     7.119341563786006e-01
     6.718750000000000e-01     9.341563786008229e-01
    -7.812500000000000e-02     3.662551440329216e-01
     9.218750000000000e-01    -7.448559670781894e-01
    -8.906250000000000e-01    -7.818930041152272e-02
     6.093750000000000e-01     1.440329218106997e-01
    -6.406250000000000e-01     8.106995884773662e-01
     8.593750000000000e-01     4.403292181069960e-01
    -7.656250000000000e-01    -6.707818930041152e-01
    -2.656250000000000e-01     6.625514403292179e-01
     7.343750000000000e-01    -4.485596707818931e-01
     9.843750000000000e-01    -1.522633744855968e-01
    -9.921875000000000e-01     5.144032921810699e-01
     5.078125000000000e-01     7.366255144032918e-01
    -7.421875000000000e-01    -3.744855967078190e-01
     2.578125000000000e-01     2.921810699588476e-01
     7.578125000000000e-01    -9.423868312757202e-01
    -8.671875000000000e-01    -2.757201646090536e-01
     1.328125000000000e-01     3.909465020576131e-01
     6.328125000000000e-01    -5.349794238683137e-02
    -6.171875000000000e-01     6.131687242798352e-01
     8.828125000000000e-01     8.353909465020575e-01
    -9.296875000000000e-01    -8.683127572016461e-01
    -4.296875000000000e-01     4.650205761316872e-01
    -6.796875000000000e-01     2.057613168724282e-02
     3.203125000000000e-01     6.872427983539091e-01
     8.203125000000000e-01     2.427983539094649e-01
    -8.046875000000000e-01     9.094650205761314e-01
     6.953125000000000e-01     5.390946502057612e-01
     9.453125000000000e-01    -3.497942386831276e-01
    -9.609375000000000e-01     3.168724279835391e-01
    -7.109375000000000e-01     3.497942386831274e-01
     7.890625000000000e-01     5.720164609053495e-01
    -8.359375000000000e-01    -5.390946502057614e-01
     4.140625000000000e-01     4.238683127572016e-01
     9.140625000000000e-01    -2.057613168724282e-02
    -8.984375000000000e-01     6.460905349794235e-01
     6.015625000000000e-01     8.683127572016458e-01
    -6.484375000000000e-01    -8.353909465020576e-01
    -1.484375000000000e-01     4.979423868312756e-01
     8.515625000000000e-01    -6.131687242798354e-01
    -7.734375000000000e-01     5.349794238683114e-02
     7.265625000000000e-01     2.757201646090535e-01
     9.765625000000000e-01     3.744855967078187e-01
    -9.765625000000000e-01    -7.366255144032923e-01
    -4.765625000000000e-01     5.967078189300410e-01
    -7.265625000000000e-01     1.522633744855968e-01
     7.734375000000000e-01    -2.181069958847737e-01
    -8.515625000000000e-01     4.485596707818931e-01
     6.484375000000000e-01     6.707818930041149e-01
    -6.015625000000000e-01    -4.403292181069959e-01
     8.984375000000000e-01    -8.106995884773662e-01
    -9.140625000000000e-01    -1.440329218106996e-01
     8.593750000000000e-02     5.226337448559670e-01
    -6.640625000000000e-01     7.448559670781889e-01
    -1.640625000000000e-01     3.004115226337447e-01
     8.359375000000000e-01     9.670781893004112e-01
    -7.890625000000000e-01    -9.341563786008230e-01
    -2.890625000000000e-01     3.991769547325101e-01
     7.109375000000000e-01    -7.119341563786008e-01
     4.609375000000000e-01     6.213991769547322e-01
     9.609375000000000e-01     1.769547325102880e-01
    -9.453125000000000e-01     8.436213991769546e-01
     5.546875000000000e-01     4.732510288065843e-01
    -6.953125000000000e-01    -6.378600823045268e-01
     8.046875000000000e-01    -4.156378600823045e-01
    -8.203125000000000e-01     2.510288065843620e-01
     6.796875000000000e-01    -1.193415637860082e-01
    -5.703125000000000e-01     5.473251028806583e-01
     9.296875000000000e-01     7.695473251028804e-01
    -8.828125000000000e-01    -3.415637860082305e-01
     1.171875000000000e-01     3.251028806584362e-01
    -6.328125000000000e-01    -3.305898491083676e-01
     8.671875000000000e-01    -1.083676268861454e-01
    -7.578125000000000e-01     5.582990397805210e-01
     7.421875000000000e-01     7.805212620027433e-01
    -7.812500000000000e-03     4.101508916323731e-01
    -9.960937500000000e-01    -3.429355281207136e-02
    -7.460937500000000e-01     8.545953360768173e-01
     7.539062500000000e-01     4.842249657064470e-01
    -8.710937500000000e-01    -6.268861454046639e-01
    -3.710937500000000e-01     7.064471879286691e-01
     6.289062500000000e-01    -4.046639231824417e-01
    -6.210937500000000e-01     2.620027434842249e-01
     8.789062500000000e-01    -3.058984910836763e-01
    -9.335937500000000e-01     3.607681755829901e-01
     5.664062500000000e-01     5.829903978052124e-01
    -6.835937500000000e-01    -5.281207133058985e-01
     8.164062500000000e-01    -8.984910836762688e-01
    -8.085937500000000e-01    -2.318244170096022e-01
     1.914062500000000e-01     4.348422496570645e-01
     6.914062500000000e-01    -9.602194787380003e-03
    -5.585937500000000e-01     6.570644718792864e-01
    -5.859375000000000e-02     2.126200274348422e-01
     9.414062500000000e-01     8.792866941015087e-01
    -9.648437500000000e-01    -8.244170096021948e-01
    -4.648437500000000e-01     5.089163237311385e-01
    -7.148437500000000e-01     6.447187928669385e-02
     7.851562500000000e-01     2.866941015089162e-01
    -8.398437500000000e-01     9.533607681755827e-01
     6.601562500000000e-01     3.854595336076816e-01
     9.101562500000000e-01    -5.034293552812071e-01
    -9.023437500000000e-01     1.632373113854595e-01
    -6.523437500000000e-01     4.595336076817558e-01
     8.476562500000000e-01     6.817558299039777e-01
    -7.773437500000000e-01    -4.293552812071331e-01
     2.226562500000000e-01     2.373113854595335e-01
     7.226562500000000e-01    -7.997256515775034e-01
     4.726562500000000e-01     5.336076817558297e-01
     9.726562500000000e-01     8.916323731138531e-02
    -9.804687500000000e-01     7.558299039780518e-01
    -2.304687500000000e-01     3.443072702331960e-01
     7.695312500000000e-01    -7.668038408779150e-01
    -8.554687500000000e-01    -1.001371742112483e-01
     1.445312500000000e-01     5.665294924554181e-01
     6.445312500000000e-01     1.220850480109739e-01
    -6.054687500000000e-01     7.887517146776404e-01
     8.945312500000000e-01     4.183813443072701e-01
    -9.179687500000000e-01    -6.927297668038408e-01
    -4.179687500000000e-01     6.406035665294920e-01
    -6.679687500000000e-01     1.961591220850478e-01
     8.320312500000000e-01    -1.742112482853224e-01
    -7.929687500000000e-01     4.924554183813441e-01
     7.070312500000000e-01     7.146776406035662e-01
    -9.492187500000000e-01    -2.976680384087792e-01
     5.078125000000000e-02     3.689986282578872e-01
    -6.992187500000000e-01     5.912208504801095e-01
     8.007812500000000e-01     8.134430727023318e-01
    -8.242187500000000e-01    -8.902606310013718e-01
    -3.242187500000000e-01     4.430727023319616e-01
     6.757812500000000e-01    -6.680384087791496e-01
     4.257812500000000e-01     6.652949245541835e-01
     9.257812500000000e-01     2.208504801097393e-01
    -8.867187500000000e-01     8.875171467764058e-01
     6.132812500000000e-01     5.171467764060356e-01
    -6.367187500000000e-01    -5.939643347050754e-01
     8.632812500000000e-01    -3.717421124828533e-01
    -7.617187500000000e-01     2.949245541838132e-01
     7.382812500000000e-01    -2.729766803840878e-01
     9.882812500000000e-01     6.159122085048008e-01
    -9.882812500000000e-01    -4.951989026063101e-01
     1.171875000000000e-02     1.714677640603566e-01
    -4.882812500000000e-01     8.381344307270231e-01
    -7.382812500000000e-01    -1.989026063100138e-01
     2.617187500000000e-01     4.677640603566529e-01
     7.617187500000000e-01     2.331961591220844e-02
    -8.632812500000000e-01     6.899862825788747e-01
     6.367187500000000e-01     9.122085048010971e-01
    -1.132812500000000e-01     5.418381344307268e-01
     8.867187500000000e-01    -5.692729766803841e-01
    -9.257812500000000e-01     9.739368998628239e-02
     8.242187500000000e-01     3.525377229080930e-01
    -8.007812500000000e-01    -7.585733882030179e-01
    -3.007812500000000e-01     5.747599451303151e-01
     6.992187500000000e-01    -5.363511659807956e-01
     4.492187500000000e-01     7.969821673525375e-01
     9.492187500000000e-01    -2.400548696844993e-01
    -9.570312500000000e-01     4.266117969821672e-01
     5.429687500000000e-01     6.488340192043891e-01
    -7.070312500000000e-01    -4.622770919067215e-01
     7.929687500000000e-01    -8.326474622770919e-01
    -8.320312500000000e-01    -1.659807956104252e-01
     1.679687500000000e-01     5.006858710562412e-01
     6.679687500000000e-01     5.624142661179676e-02
    -5.820312500000000e-01     7.229080932784633e-01
    -8.203125000000000e-02     2.784636488340191e-01
    -8.945312500000000e-01    -9.561042524005487e-01
    -6.445312500000000e-01    -6.721536351165980e-02
     3.554687500000000e-01     5.994513031550066e-01
     8.554687500000000e-01     1.550068587105624e-01
    -7.695312500000000e-01     8.216735253772289e-01
     7.304687500000000e-01     4.513031550068587e-01
     9.804687500000000e-01    -4.375857338820301e-01
    -9.726562500000000e-01     2.290809327846364e-01
    -7.226562500000000e-01     5.253772290809327e-01
     7.773437500000000e-01     7.475994513031545e-01
    -8.476562500000000e-01    -3.635116598079561e-01
     1.523437500000000e-01     3.031550068587103e-01
     4.023437500000000e-01     4.019204389574758e-01
     9.023437500000000e-01    -4.252400548696844e-02
    -9.101562500000000e-01     6.241426611796979e-01
     5.898437500000000e-01     8.463648834019202e-01
    -6.601562500000000e-01    -8.573388203017833e-01
    -1.601562500000000e-01     4.759945130315499e-01
     8.398437500000000e-01    -6.351165980795610e-01
    -7.851562500000000e-01     3.155006858710552e-02
     7.148437500000000e-01     2.537722908093276e-01
     9.648437500000000e-01     5.500685871056239e-01
    -9.414062500000000e-01    -5.610425240054870e-01
    -4.414062500000000e-01     7.722908093278460e-01
    -6.914062500000000e-01     3.278463648834018e-01
     8.085937500000000e-01    -3.278463648834019e-01
    -8.164062500000000e-01     3.388203017832647e-01
     6.835937500000000e-01     5.610425240054868e-01
    -8.789062500000000e-01    -2.537722908093278e-01
     1.210937500000000e-01     4.128943758573389e-01
     6.210937500000000e-01    -3.155006858710563e-02
    -6.289062500000000e-01     6.351165980795608e-01
    -1.289062500000000e-01     1.906721536351166e-01
     8.710937500000000e-01     8.573388203017831e-01
    -7.539062500000000e-01    -8.463648834019204e-01
    -2.539062500000000e-01     4.869684499314129e-01
     7.460937500000000e-01    -6.241426611796983e-01
     4.960937500000000e-01     7.091906721536350e-01
     9.960937500000000e-01     2.647462277091908e-01
    -9.980468750000000e-01     9.314128943758573e-01
    -7.480468750000000e-01    -7.475994513031550e-01
    -2.480468750000000e-01     5.857338820301783e-01
     7.519531250000000e-01    -5.253772290809329e-01
    -8.730468750000000e-01     1.412894375857341e-01
     6.269531250000000e-01    -2.290809327846365e-01
    -6.230468750000000e-01     4.375857338820304e-01
     8.769531250000000e-01     6.598079561042522e-01
    -9.355468750000000e-01    -4.513031550068587e-01
     6.445312500000000e-02     2.153635116598080e-01
    -6.855468750000000e-01    -1.550068587105624e-01
     3.144531250000000e-01     5.116598079561043e-01
     8.144531250000000e-01     6.721536351165969e-02
    -8.105468750000000e-01     7.338820301783262e-01
     6.894531250000000e-01     9.561042524005485e-01
    -6.054687500000000e-02     3.882030178326474e-01
     9.394531250000000e-01    -7.229080932784637e-01
    -9.667968750000000e-01    -5.624142661179699e-02
    -7.167968750000000e-01     8.326474622770919e-01
     7.832031250000000e-01     4.622770919067216e-01
    -8.417968750000000e-01    -6.488340192043895e-01
    -3.417968750000000e-01     6.844993141289435e-01
     6.582031250000000e-01    -4.266117969821673e-01
     9.082031250000000e-01    -1.303155006858711e-01
    -9.042968750000000e-01     5.363511659807956e-01
     5.957031250000000e-01     7.585733882030177e-01
    -6.542968750000000e-01    -3.525377229080933e-01
     8.457031250000000e-01    -9.862825788751715e-01
    -7.792968750000000e-01    -3.196159122085048e-01
     2.207031250000000e-01     3.470507544581618e-01
     7.207031250000000e-01    -9.739368998628262e-02
    -5.292968750000000e-01     5.692729766803839e-01
     9.707031250000000e-01     7.914951989026062e-01
    -7.324218750000000e-01    -2.331961591220855e-02
     2.675781250000000e-01     6.433470507544579e-01
     7.675781250000000e-01     1.989026063100137e-01
    -8.574218750000000e-01     8.655692729766802e-01
     6.425781250000000e-01     4.951989026063099e-01
    -6.074218750000000e-01    -6.159122085048011e-01
     8.925781250000000e-01    -3.936899862825789e-01
    -9.199218750000000e-01     2.729766803840878e-01
    -6.699218750000000e-01     3.717421124828530e-01
     8.300781250000000e-01     5.939643347050754e-01
    -7.949218750000000e-01    -5.171467764060357e-01
     7.050781250000000e-01    -8.875171467764060e-01
     4.550781250000000e-01     4.458161865569275e-01
     9.550781250000000e-01     1.371742112482810e-03
    -9.511718750000000e-01     6.680384087791493e-01
     5.488281250000000e-01     8.902606310013716e-01
    -7.011718750000000e-01    -8.134430727023320e-01
    -2.011718750000000e-01     5.198902606310014e-01
     7.988281250000000e-01    -5.912208504801097e-01
    -8.261718750000000e-01     7.544581618655677e-02
     6.738281250000000e-01     2.976680384087791e-01
     9.238281250000000e-01     3.964334705075445e-01
    -8.886718750000000e-01    -7.146776406035665e-01
    -3.886718750000000e-01     6.186556927297666e-01
     6.113281250000000e-01    -4.924554183813443e-01
    -6.386718750000000e-01     1.742112482853224e-01
     8.613281250000000e-01    -1.961591220850480e-01
    -7.636718750000000e-01     4.705075445816187e-01
     7.363281250000000e-01     6.927297668038406e-01
    -9.902343750000000e-01    -1.220850480109740e-01
    -7.402343750000000e-01     7.668038408779148e-01
    -2.402343750000000e-01     3.223593964334706e-01
     7.597656250000000e-01     9.890260631001371e-01
    -8.652343750000000e-01    -9.780521262002744e-01
     6.347656250000000e-01    -7.558299039780522e-01
    -6.152343750000000e-01    -8.916323731138542e-02
     3.847656250000000e-01     5.775034293552810e-01
     8.847656250000000e-01     1.330589849108368e-01
    -9.277343750000000e-01     7.997256515775033e-01
     5.722656250000000e-01     4.293552812071331e-01
    -6.777343750000000e-01    -6.817558299039781e-01
     8.222656250000000e-01    -4.595336076817558e-01
    -8.027343750000000e-01     2.071330589849107e-01
     6.972656250000000e-01    -1.632373113854595e-01
    -5.527343750000000e-01     5.034293552812070e-01
     9.472656250000000e-01     7.256515775034291e-01
    -9.589843750000000e-01    -3.854595336076817e-01
     4.101562500000000e-02     2.812071330589849e-01
    -7.089843750000000e-01    -2.866941015089163e-01
     2.910156250000000e-01     3.799725651577501e-01
     7.910156250000000e-01    -6.447187928669407e-02
    -8.339843750000000e-01     6.021947873799725e-01
     6.660156250000000e-01     8.244170096021948e-01
    -8.398437500000000e-02     4.540466392318245e-01
     9.160156250000000e-01    -6.570644718792867e-01
    -8.964843750000000e-01     9.602194787379892e-03
     6.035156250000000e-01     2.318244170096022e-01
    -6.464843750000000e-01     8.984910836762687e-01
     8.535156250000000e-01     5.281207133058985e-01
    -7.714843750000000e-01    -5.829903978052127e-01
     7.285156250000000e-01    -3.607681755829903e-01
     9.785156250000000e-01    -2.620027434842249e-01
    -9.746093750000000e-01     4.046639231824416e-01
     5.253906250000000e-01     6.268861454046637e-01
    -7.246093750000000e-01    -4.842249657064471e-01
     7.753906250000000e-01    -8.545953360768176e-01
    -8.496093750000000e-01    -1.879286694101509e-01
     1.503906250000000e-01     4.787379972565158e-01
     6.503906250000000e-01     3.429355281207136e-02
    -5.996093750000000e-01     7.009602194787377e-01
    -9.960937500000000e-02     2.565157750342935e-01
     9.003906250000000e-01     9.231824417009600e-01
    -9.121093750000000e-01    -7.805212620027435e-01
    -4.121093750000000e-01     5.528120713305897e-01
    -6.621093750000000e-01     1.083676268861453e-01
     8.378906250000000e-01     3.305898491083676e-01
     7.128906250000000e-01     3.342478280749885e-01
     9.628906250000000e-01    -5.546410608139003e-01
    -9.433593750000000e-01     1.120256058527664e-01
    -6.933593750000000e-01     4.083219021490627e-01
     8.066406250000000e-01     6.305441243712846e-01
    -8.183593750000000e-01    -4.805669867398262e-01
     6.816406250000000e-01    -8.509373571101966e-01
     4.316406250000000e-01     4.823959762231367e-01
     9.316406250000000e-01     3.795153177869226e-02
    -8.808593750000000e-01     7.046181984453588e-01
     6.191406250000000e-01     9.268404206675811e-01
    -1.308593750000000e-01     3.589391860996798e-01
     8.691406250000000e-01    -7.521719250114312e-01
    -7.558593750000000e-01    -8.550525834476452e-02
     2.441406250000000e-01     5.811614083219021e-01
     7.441406250000000e-01     1.367169638774579e-01
    -5.058593750000000e-01     8.033836305441244e-01
     9.941406250000000e-01     4.330132601737542e-01
    -9.941406250000000e-01    -6.780978509373572e-01
    -4.941406250000000e-01     6.552354823959761e-01
    -7.441406250000000e-01     2.107910379515319e-01
     7.558593750000000e-01    -1.595793324188386e-01
    -8.691406250000000e-01     5.070873342478281e-01
     6.308593750000000e-01     7.293095564700500e-01
    -6.191406250000000e-01    -3.818015546410608e-01
     8.808593750000000e-01    -9.497027892089620e-01
    -9.316406250000000e-01    -2.830361225422954e-01
     6.835937500000000e-02     3.836305441243713e-01
    -6.816406250000000e-01     6.058527663465934e-01
     8.183593750000000e-01     8.280749885688157e-01
    -8.066406250000000e-01    -8.756287151348879e-01
    -3.066406250000000e-01     4.577046181984454e-01
     6.933593750000000e-01    -6.534064929126657e-01
     4.433593750000000e-01     6.799268404206673e-01
     9.433593750000000e-01     2.354823959762231e-01
    -9.628906250000000e-01     9.021490626428896e-01
     5.371093750000000e-01     5.317786922725194e-01
    -7.128906250000000e-01    -5.793324188385918e-01
     7.871093750000000e-01    -3.571101966163694e-01
    -8.378906250000000e-01     3.095564700502973e-01
     6.621093750000000e-01    -3.241883859167810e-01
     9.121093750000000e-01     5.647005029721077e-01
    -9.003906250000000e-01    -5.464106081390032e-01
    -6.503906250000000e-01    -2.501143118427069e-01
     3.496093750000000e-01     4.165523548239598e-01
     8.496093750000000e-01    -2.789208962048473e-02
    -7.753906250000000e-01     6.387745770461817e-01
     7.246093750000000e-01     8.609967992684040e-01
    -2.539062500000000e-02     4.906264288980338e-01
     9.746093750000000e-01    -6.204846822130773e-01
    -9.785156250000000e-01     4.618198445358934e-02
    -7.285156250000000e-01     9.350708733424782e-01
     7.714843750000000e-01     3.671696387745769e-01
    -8.535156250000000e-01    -7.439414723365341e-01
    -3.535156250000000e-01     5.893918609967992e-01
     6.464843750000000e-01    -5.217192501143119e-01
    -6.035156250000000e-01     1.449474165523550e-01
     8.964843750000000e-01    -2.254229538180156e-01
    -9.160156250000000e-01     4.412437128486513e-01
     5.839843750000000e-01     6.634659350708731e-01
    -6.660156250000000e-01    -4.476451760402378e-01
     8.339843750000000e-01    -8.180155464106081e-01
    -7.910156250000000e-01    -1.513488797439415e-01
     2.089843750000000e-01     5.153177869227252e-01
     7.089843750000000e-01     7.087334247828059e-02
    -5.410156250000000e-01     7.375400091449471e-01
    -4.101562500000000e-02     2.930955647005029e-01
    -6.972656250000000e-01    -5.258344764517608e-02
     3.027343750000000e-01     6.140832190214904e-01
     8.027343750000000e-01     1.696387745770462e-01
    -8.222656250000000e-01     8.363054412437128e-01
     6.777343750000000e-01     4.659350708733425e-01
     9.277343750000000e-01    -4.229538180155464e-01
    -8.847656250000000e-01     2.437128486511202e-01
     6.152343750000000e-01    -1.266575217192502e-01
    -6.347656250000000e-01     5.400091449474165e-01
     8.652343750000000e-01     7.622313671696386e-01
    -7.597656250000000e-01    -3.488797439414724e-01
     2.402343750000000e-01     3.177869227251944e-01
     7.402343750000000e-01    -9.826245999085506e-01
     9.902343750000000e-01    -9.373571101966161e-02
    -9.863281250000000e-01     5.729309556470048e-01
     5.136718750000000e-01     7.951531778692271e-01
    -7.363281250000000e-01    -9.085505258344765e-01
    -2.363281250000000e-01     4.247828074988569e-01
     7.636718750000000e-01    -6.863283036122543e-01
    -8.613281250000000e-01    -1.966163694558754e-02
     6.386718750000000e-01     2.025605852766346e-01
    -6.113281250000000e-01     8.692272519433011e-01
     8.886718750000000e-01     4.988568815729308e-01
    -9.238281250000000e-01    -6.122542295381802e-01
    -4.238281250000000e-01     7.210791037951529e-01
    -6.738281250000000e-01     2.766346593507087e-01
     8.261718750000000e-01    -2.912665752171925e-01
    -7.988281250000000e-01     3.754000914494739e-01
     7.011718750000000e-01     5.976223136716963e-01
    -9.550781250000000e-01    -2.171925011431184e-01
     4.492187500000000e-02     4.494741655235484e-01
    -7.050781250000000e-01     6.716963877457702e-01
    -2.050781250000000e-01     2.272519433013260e-01
     7.949218750000000e-01     8.939186099679926e-01
    -8.300781250000000e-01    -8.097850937357111e-01
    -3.300781250000000e-01     5.235482395976223e-01
     6.699218750000000e-01    -5.875628715134888e-01
     4.199218750000000e-01     7.457704618198442e-01
     9.199218750000000e-01     3.013260173754000e-01
    -8.925781250000000e-01     9.679926840420665e-01
     6.074218750000000e-01     4.000914494741654e-01
    -6.425781250000000e-01    -7.110196616369456e-01
     8.574218750000000e-01    -4.887974394147233e-01
    -7.675781250000000e-01     1.778692272519433e-01
     7.324218750000000e-01    -1.925011431184270e-01
    -5.175781250000000e-01     4.741655235482396e-01
     9.824218750000000e-01     6.963877457704615e-01
    -9.707031250000000e-01    -4.147233653406492e-01
     2.929687500000000e-02     2.519433013260173e-01
    -7.207031250000000e-01    -1.184270690443530e-01
     2.792968750000000e-01     5.482395976223136e-01
     7.792968750000000e-01     1.037951531778691e-01
    -8.457031250000000e-01     7.704618198445357e-01
    -9.570312500000000e-02     3.369913122999542e-01
     9.042968750000000e-01    -7.741197988111569e-01
    -9.082031250000000e-01    -1.074531321444901e-01
    -6.582031250000000e-01     7.814357567443986e-01
     8.417968750000000e-01     4.110653863740283e-01
    -7.832031250000000e-01    -7.000457247370828e-01
    -2.832031250000000e-01     6.332876085962502e-01
     7.167968750000000e-01    -4.778235025148605e-01
     9.667968750000000e-01    -1.815272062185642e-01
    -9.394531250000000e-01     4.851394604481023e-01
     5.605468750000000e-01     7.073616826703244e-01
    -6.894531250000000e-01    -4.037494284407864e-01
     8.105468750000000e-01    -9.716506630086877e-01
    -8.144531250000000e-01    -3.049839963420210e-01
     1.855468750000000e-01     3.616826703246454e-01
     6.855468750000000e-01    -8.276177411979879e-02
    -5.644531250000000e-01     5.839048925468677e-01
     9.355468750000000e-01     8.061271147690900e-01
    -8.769531250000000e-01    -8.975765889346137e-01
    -3.769531250000000e-01     4.357567443987198e-01
     6.230468750000000e-01    -6.753543667123914e-01
    -6.269531250000000e-01    -8.687700045724722e-03
     3.730468750000000e-01     6.579789666209417e-01
     8.730468750000000e-01     2.135345221764975e-01
    -7.519531250000000e-01     8.802011888431640e-01
     7.480468750000000e-01     5.098308184727938e-01
     9.980468750000000e-01    -3.790580704160951e-01
    -9.990234375000000e-01     2.876085962505714e-01
    -7.490234375000000e-01     3.863740283493369e-01
     7.509765625000000e-01     6.085962505715590e-01
    -8.740234375000000e-01    -5.025148605395520e-01
    -6.240234375000000e-01    -2.062185642432556e-01
     3.759765625000000e-01     4.604481024234111e-01
     8.759765625000000e-01     1.600365797896663e-02
    -9.365234375000000e-01     6.826703246456329e-01
     5.634765625000000e-01     9.048925468678553e-01
    -6.865234375000000e-01    -7.988111568358482e-01
    -1.865234375000000e-01     5.345221764974850e-01
     8.134765625000000e-01    -5.765889346136259e-01
    -8.115234375000000e-01     9.007773205304059e-02
     6.884765625000000e-01     3.122999542752629e-01
     9.384765625000000e-01     3.452217649748512e-01
    -9.677734375000000e-01    -7.658893461362597e-01
    -4.677734375000000e-01     5.674439871970733e-01
    -7.177734375000000e-01     1.229995427526291e-01
     7.822265625000000e-01    -2.473708276177412e-01
    -8.427734375000000e-01     4.192958390489254e-01
     6.572265625000000e-01     6.415180612711473e-01
     9.072265625000000e-01    -8.399634202103339e-01
    -9.052734375000000e-01    -1.732967535436671e-01
     9.472656250000000e-02     4.933699131229994e-01
    -6.552734375000000e-01     7.155921353452215e-01
    -1.552734375000000e-01     2.711476909007773e-01
     8.447265625000000e-01     9.378143575674438e-01
    -7.802734375000000e-01    -9.634202103337905e-01
    -2.802734375000000e-01     3.699131229995425e-01
     7.197265625000000e-01    -7.411979881115683e-01
     4.697265625000000e-01     5.921353452217648e-01
     9.697265625000000e-01     1.476909007773206e-01
    -9.833984375000000e-01     8.143575674439871e-01
    -7.333984375000000e-01    -6.671239140374943e-01
     7.666015625000000e-01    -4.449016918152721e-01
    -8.583984375000000e-01     2.217649748513946e-01
     6.416015625000000e-01    -1.486053955189758e-01
    -6.083984375000000e-01     5.180612711476908e-01
     8.916015625000000e-01     7.402834933699127e-01
    -9.208984375000000e-01    -3.708276177411980e-01
     7.910156250000000e-02     2.958390489254685e-01
    -6.708984375000000e-01    -2.720621856424326e-01
     3.291015625000000e-01     3.946044810242340e-01
     8.291015625000000e-01    -4.983996342021035e-02
    -7.958984375000000e-01     6.168267032464561e-01
     7.041015625000000e-01     8.390489254686784e-01
    -4.589843750000000e-02     4.686785550983081e-01
     9.541015625000000e-01    -6.424325560128029e-01
    -9.521484375000000e-01     2.423411065386372e-02
    -7.021484375000000e-01     9.131229995427523e-01
     7.978515625000000e-01     5.427526291723821e-01
    -8.271484375000000e-01    -5.683584819387288e-01
     6.728515625000000e-01    -3.461362597165066e-01
     9.228515625000000e-01    -3.132144490169181e-01
    -8.896484375000000e-01     3.534522176497483e-01
     6.103515625000000e-01     5.756744398719704e-01
    -6.396484375000000e-01    -5.354366712391404e-01
     8.603515625000000e-01    -9.058070416095108e-01
    -7.646484375000000e-01    -2.391403749428440e-01
     2.353515625000000e-01     4.275262917238225e-01
     7.353515625000000e-01    -1.691815272062180e-02
    -5.146484375000000e-01     6.497485139460444e-01
    -1.464843750000000e-02     2.053040695016002e-01
    -4.912109375000000e-01     5.016003657978965e-01
    -7.412109375000000e-01     5.715592135345204e-02
     7.587890625000000e-01     2.793781435756744e-01
    -8.662109375000000e-01     9.460448102423409e-01
     6.337890625000000e-01     3.781435756744396e-01
    -6.162109375000000e-01    -7.329675354366713e-01
     8.837890625000000e-01    -5.107453132144490e-01
    -9.287109375000000e-01     1.559213534522177e-01
    -6.787109375000000e-01     4.522176497485140e-01
     8.212890625000000e-01     6.744398719707358e-01
    -8.037109375000000e-01    -4.366712391403749e-01
     1.962890625000000e-01     2.299954275262917e-01
     6.962890625000000e-01    -8.070416095107453e-01
     4.462890625000000e-01     5.262917238225879e-01
     9.462890625000000e-01     8.184727937814329e-02
    -9.599609375000000e-01     7.485139460448098e-01
    -7.099609375000000e-01    -9.304983996342021e-01
    -2.099609375000000e-01     4.028349336991310e-01
     7.900390625000000e-01    -7.082761774119799e-01
    -8.349609375000000e-01    -4.160951074531316e-02
     6.650390625000000e-01     1.806127114769089e-01
    -5.849609375000000e-01     8.472793781435755e-01
     9.150390625000000e-01     4.769090077732052e-01
    -8.974609375000000e-01    -6.342021033379058e-01
    -3.974609375000000e-01     6.991312299954271e-01
     6.025390625000000e-01    -4.119798811156835e-01
    -6.474609375000000e-01     2.546867855509829e-01
     8.525390625000000e-01    -1.156835848193872e-01
    -7.724609375000000e-01     5.509830818472792e-01
     7.275390625000000e-01     7.732053040695013e-01
    -9.755859375000000e-01    -3.269318701417466e-01
     2.441406250000000e-02     3.397347965249200e-01
    -7.255859375000000e-01     5.619570187471421e-01
     7.744140625000000e-01     7.841792409693644e-01
    -8.505859375000000e-01    -9.195244627343393e-01
    -3.505859375000000e-01     4.138088705989942e-01
     6.494140625000000e-01    -6.973022405121171e-01
    -6.005859375000000e-01    -3.063557384545035e-02
     3.994140625000000e-01     6.360310928212161e-01
     8.994140625000000e-01     1.915866483767719e-01
    -9.130859375000000e-01     8.582533150434384e-01
     5.869140625000000e-01     4.878829446730681e-01
    -6.630859375000000e-01    -6.232281664380430e-01
     8.369140625000000e-01    -4.010059442158207e-01
    -7.880859375000000e-01     2.656607224508460e-01
     7.119140625000000e-01    -3.022405121170553e-01
     9.619140625000000e-01     5.866483767718336e-01
    -9.443359375000000e-01    -5.244627343392776e-01
    -4.443359375000000e-01     8.088705989940559e-01
    -6.943359375000000e-01    -2.281664380429812e-01
     3.056640625000000e-01     4.385002286236857e-01
     8.056640625000000e-01    -5.944215820758991e-03
    -8.193359375000000e-01     6.607224508459075e-01
     6.806640625000000e-01     8.829446730681298e-01
    -6.933593750000000e-02     5.125743026977596e-01
     9.306640625000000e-01    -5.985368084133517e-01
    -8.818359375000000e-01     6.812985825331497e-02
     6.181640625000000e-01     2.903520804755373e-01
     8.681640625000000e-01     3.891175125743027e-01
    -7.568359375000000e-01    -7.219935985368084e-01
    -2.568359375000000e-01     6.113397347965248e-01
     7.431640625000000e-01    -4.997713763145862e-01
     4.931640625000000e-01     8.335619570187471e-01
     9.931640625000000e-01    -2.034750800182898e-01
    -9.951171875000000e-01     4.631915866483769e-01
     5.048828125000000e-01     6.854138088705988e-01
    -7.451171875000000e-01    -4.256973022405121e-01
     7.548828125000000e-01    -7.960676726108825e-01
    -8.701171875000000e-01    -1.294010059442158e-01
     1.298828125000000e-01     5.372656607224509e-01
     6.298828125000000e-01     9.282121627800644e-02
    -6.201171875000000e-01     7.594878829446730e-01
    -1.201171875000000e-01     3.150434385002288e-01
    -6.826171875000000e-01    -9.647919524462734e-02
     3.173828125000000e-01     5.701874714220392e-01
     8.173828125000000e-01     1.257430269775950e-01
    -8.076171875000000e-01     7.924096936442615e-01
     6.923828125000000e-01     4.220393232738913e-01
     9.423828125000000e-01    -4.668495656149977e-01
    -9.638671875000000e-01     1.998171010516689e-01
    -7.138671875000000e-01     4.961133973479652e-01
     7.861328125000000e-01     7.183356195701873e-01
    -8.388671875000000e-01    -3.927754915409236e-01
     1.611328125000000e-01     2.738911751257431e-01
     9.111328125000000e-01    -7.178783721993598e-02
    -9.013671875000000e-01     5.948788294467307e-01
     5.986328125000000e-01     8.171010516689530e-01
    -1.513671875000000e-01     4.467306812985827e-01
     8.486328125000000e-01    -6.643804298125287e-01
    -7.763671875000000e-01     2.286236854138091e-03
     7.236328125000000e-01     2.245084590763604e-01
     9.736328125000000e-01     5.208047553726567e-01
    -9.794921875000000e-01    -5.903063557384545e-01
    -4.794921875000000e-01     7.430269775948786e-01
    -7.294921875000000e-01     2.985825331504344e-01
     7.705078125000000e-01    -2.693187014174668e-01
    -8.544921875000000e-01     3.973479652491998e-01
     6.455078125000000e-01     6.195701874714219e-01
    -6.044921875000000e-01    -4.915409236396890e-01
     8.955078125000000e-01    -8.619112940100595e-01
    -9.169921875000000e-01    -1.952446273433928e-01
     8.300781250000000e-02     4.714220393232740e-01
    -6.669921875000000e-01     6.936442615454959e-01
    -1.669921875000000e-01     2.491998171010517e-01
     8.330078125000000e-01     9.158664837677182e-01
    -7.919921875000000e-01    -7.878372199359854e-01
    -2.919921875000000e-01     5.454961133973479e-01
     7.080078125000000e-01    -5.656149977137632e-01
     4.580078125000000e-01     7.677183356195700e-01
     9.580078125000000e-01     3.232738911751258e-01
    -9.482421875000000e-01     9.899405578417924e-01
    -6.982421875000000e-01    -7.549154092363969e-01
    -1.982421875000000e-01     5.784179240969363e-01
     8.017578125000000e-01    -5.326931870141747e-01
    -8.232421875000000e-01     1.339734796524921e-01
     6.767578125000000e-01    -2.363968907178783e-01
    -5.732421875000000e-01     4.302697759487883e-01
     9.267578125000000e-01     6.524919981710102e-01
    -8.857421875000000e-01    -4.586191129401005e-01
     1.142578125000000e-01     2.080475537265660e-01
    -6.357421875000000e-01    -1.623228166438042e-01
     3.642578125000000e-01     5.043438500228623e-01
     8.642578125000000e-01     5.989940557841789e-02
    -7.607421875000000e-01     7.265660722450844e-01
    -2.607421875000000e-01     2.821216278006402e-01
     7.392578125000000e-01     9.487882944673067e-01
    -1.074218750000000e-02     3.808870598994054e-01
    -9.873046875000000e-01    -6.355738454503879e-02
    -7.373046875000000e-01     8.253315043438501e-01
     7.626953125000000e-01     4.549611339734798e-01
    -8.623046875000000e-01    -6.561499771376316e-01
    -3.623046875000000e-01     6.771833561957017e-01
     6.376953125000000e-01    -4.339277549154091e-01
    -6.123046875000000e-01     2.327389117512575e-01
     8.876953125000000e-01    -1.376314586191129e-01
    -9.248046875000000e-01     5.290352080475538e-01
     5.751953125000000e-01     7.512574302697757e-01
    -6.748046875000000e-01    -3.598536808413351e-01
     8.251953125000000e-01    -9.277549154092364e-01
    -7.998046875000000e-01    -2.610882487425696e-01
     2.001953125000000e-01     4.055784179240969e-01
     7.001953125000000e-01    -3.886602652034743e-02
    -5.498046875000000e-01     6.278006401463190e-01
    -4.980468750000000e-02     1.833561957018748e-01
     9.501953125000000e-01     8.500228623685413e-01
    -9.560546875000000e-01    -8.536808413351623e-01
    -4.560546875000000e-01     4.796524919981711e-01
    -7.060546875000000e-01     3.520804755372664e-02
     7.939453125000000e-01     2.574302697759487e-01
    -8.310546875000000e-01     9.240969364426153e-01
     6.689453125000000e-01     5.537265660722450e-01
     9.189453125000000e-01    -3.351623228166437e-01
    -8.935546875000000e-01     3.315043438500229e-01
     6.064453125000000e-01    -3.315043438500229e-01
    -6.435546875000000e-01     3.351623228166438e-01
     8.564453125000000e-01     5.573845450388659e-01
    -7.685546875000000e-01    -5.537265660722451e-01
     7.314453125000000e-01    -9.240969364426155e-01
     9.814453125000000e-01    -3.520804755372664e-02
    -9.716796875000000e-01     6.314586191129399e-01
     5.283203125000000e-01     8.536808413351622e-01
    -7.216796875000000e-01    -8.500228623685414e-01
    -2.216796875000000e-01     4.833104709647920e-01
     7.783203125000000e-01    -6.278006401463192e-01
    -8.466796875000000e-01     3.886602652034754e-02
     6.533203125000000e-01     2.610882487425699e-01
     9.033203125000000e-01     3.598536808413351e-01
    -9.091796875000000e-01    -7.512574302697760e-01
    -4.091796875000000e-01     5.820759030635574e-01
    -6.591796875000000e-01     1.376314586191132e-01
     8.408203125000000e-01    -2.327389117512575e-01
    -7.841796875000000e-01     4.339277549154095e-01
     7.158203125000000e-01     6.561499771376313e-01
     9.658203125000000e-01    -8.253315043438501e-01
    -9.404296875000000e-01    -1.586648376771834e-01
     5.957031250000000e-02     5.080018289894834e-01
    -6.904296875000000e-01     7.302240512117053e-01
    -1.904296875000000e-01     2.857796067672611e-01
     8.095703125000000e-01     9.524462734339276e-01
    -8.154296875000000e-01    -9.487882944673068e-01
    -3.154296875000000e-01     3.845450388660265e-01
     6.845703125000000e-01    -7.265660722450846e-01
     4.345703125000000e-01     6.067672610882486e-01
     9.345703125000000e-01     1.623228166438044e-01
    -8.779296875000000e-01     8.289894833104710e-01
     6.220703125000000e-01     4.586191129401007e-01
    -6.279296875000000e-01    -6.524919981710106e-01
     8.720703125000000e-01    -4.302697759487883e-01
    -7.529296875000000e-01     2.363968907178784e-01
     7.470703125000000e-01    -1.339734796524921e-01
    -5.029296875000000e-01     5.326931870141747e-01
    -9.970703125000000e-01    -3.561957018747143e-01
     2.929687500000000e-03     3.104709647919526e-01
    -7.470703125000000e-01    -3.232738911751258e-01
     2.529296875000000e-01     3.433927754915409e-01
     7.529296875000000e-01    -1.010516689529036e-01
    -8.720703125000000e-01     5.656149977137630e-01
     6.279296875000000e-01     7.878372199359853e-01
    -1.220703125000000e-01     4.174668495656151e-01
     8.779296875000000e-01    -6.936442615454961e-01
    -9.345703125000000e-01    -2.697759487882956e-02
    -6.845703125000000e-01     8.619112940100593e-01
     8.154296875000000e-01     4.915409236396890e-01
    -8.095703125000000e-01    -6.195701874714221e-01
     6.904296875000000e-01    -3.973479652491999e-01
     9.404296875000000e-01    -2.985825331504345e-01
    -9.658203125000000e-01     3.680841335162321e-01
     5.341796875000000e-01     5.903063557384545e-01
    -7.158203125000000e-01    -5.208047553726567e-01
     7.841796875000000e-01    -8.911751257430269e-01
    -8.408203125000000e-01    -2.245084590763604e-01
     1.591796875000000e-01     4.421582075903066e-01
     6.591796875000000e-01    -2.286236854138202e-03
    -5.908203125000000e-01     6.643804298125284e-01
    -9.082031250000000e-02     2.199359853680842e-01
     9.091796875000000e-01     8.866026520347507e-01
    -9.033203125000000e-01    -8.171010516689530e-01
    -4.033203125000000e-01     5.162322816643805e-01
    -6.533203125000000e-01     7.178783721993587e-02
     3.466796875000000e-01     7.384545038866024e-01
     8.466796875000000e-01     2.940100594421582e-01
    -7.783203125000000e-01     9.606767261088247e-01
     7.216796875000000e-01     3.927754915409236e-01
     9.716796875000000e-01    -4.961133973479653e-01
    -9.814453125000000e-01     1.705532693187015e-01
    -7.314453125000000e-01     4.668495656149978e-01
     7.685546875000000e-01     6.890717878372197e-01
    -8.564453125000000e-01    -4.220393232738913e-01
     1.435546875000000e-01     2.446273433927755e-01
     6.435546875000000e-01    -7.924096936442615e-01
    -6.064453125000000e-01    -1.257430269775950e-01
     3.935546875000000e-01     5.409236396890718e-01
     8.935546875000000e-01     9.647919524462734e-02
    -9.189453125000000e-01     7.631458619112939e-01
    -1.689453125000000e-01     3.516232281664380e-01
     8.310546875000000e-01    -7.594878829446731e-01
    -7.939453125000000e-01    -9.282121627800644e-02
     2.060546875000000e-01     5.738454503886601e-01
     7.060546875000000e-01     1.294010059442159e-01
    -5.439453125000000e-01     7.960676726108824e-01
     9.560546875000000e-01     4.256973022405122e-01
    -9.501953125000000e-01    -6.854138088705990e-01
    -4.501953125000000e-01     6.479195244627340e-01
    -7.001953125000000e-01     2.034750800182898e-01
     7.998046875000000e-01    -1.668952903520805e-01
    -8.251953125000000e-01     4.997713763145861e-01
     6.748046875000000e-01     7.219935985368082e-01
    -8.876953125000000e-01    -2.903520804755373e-01
     1.123046875000000e-01     3.763145861911292e-01
     6.123046875000000e-01    -6.812985825331508e-02
    -6.376953125000000e-01     5.985368084133516e-01
     8.623046875000000e-01     8.207590306355739e-01
    -7.626953125000000e-01    -8.829446730681298e-01
    -2.626953125000000e-01     4.503886602652036e-01
     7.373046875000000e-01    -6.607224508459077e-01
     4.873046875000000e-01     6.726108824874255e-01
     9.873046875000000e-01     2.281664380429813e-01
    -9.892578125000000e-01     8.948331047096478e-01
     5.107421875000000e-01     5.244627343392776e-01
    -7.392578125000000e-01    -5.866483767718336e-01
     7.607421875000000e-01    -3.644261545496114e-01
    -8.642578125000000e-01     3.022405121170553e-01
     6.357421875000000e-01    -2.656607224508459e-01
    -6.142578125000000e-01     4.010059442158207e-01
     8.857421875000000e-01     6.232281664380428e-01
    -9.267578125000000e-01    -4.878829446730681e-01
     7.324218750000000e-02     1.787837219935986e-01
    -6.767578125000000e-01    -1.915866483767719e-01
     3.232421875000000e-01     4.750800182898949e-01
     8.232421875000000e-01     3.063557384545046e-02
    -8.017578125000000e-01     6.973022405121168e-01
     6.982421875000000e-01     9.195244627343391e-01
     9.482421875000000e-01    -5.619570187471423e-01
    -9.580078125000000e-01     1.047096479195244e-01
     7.919921875000000e-01     3.379058070416094e-01
    -8.330078125000000e-01    -7.732053040695016e-01
    -3.330078125000000e-01     5.601280292638315e-01
     6.669921875000000e-01    -5.509830818472794e-01
     4.169921875000000e-01     7.823502514860539e-01
     9.169921875000000e-01    -2.546867855509831e-01
    -8.955078125000000e-01     4.119798811156836e-01
     6.044921875000000e-01     6.342021033379055e-01
    -6.455078125000000e-01    -4.769090077732053e-01
     8.544921875000000e-01    -8.472793781435757e-01
    -7.705078125000000e-01    -1.806127114769090e-01
     2.294921875000000e-01     4.860539551897576e-01
     7.294921875000000e-01     4.160951074531316e-02
    -5.205078125000000e-01     7.082761774119797e-01
    -2.050781250000000e-02     2.638317329675355e-01
    -7.236328125000000e-01    -8.184727937814362e-02
     2.763671875000000e-01     5.848193872885230e-01
     7.763671875000000e-01     1.403749428440788e-01
    -8.486328125000000e-01     8.070416095107453e-01
     6.513671875000000e-01     4.366712391403751e-01
     9.013671875000000e-01    -4.522176497485140e-01
    -9.111328125000000e-01     2.144490169181528e-01
    -6.611328125000000e-01     5.107453132144490e-01
     8.388671875000000e-01     7.329675354366709e-01
    -7.861328125000000e-01    -3.781435756744399e-01
     2.138671875000000e-01     2.885230909922267e-01
     7.138671875000000e-01    -9.460448102423411e-01
     9.638671875000000e-01    -5.715592135345227e-02
    -9.423828125000000e-01     6.095107453132143e-01
     5.576171875000000e-01     8.317329675354366e-01
    -6.923828125000000e-01    -8.719707361682670e-01
    -1.923828125000000e-01     4.613625971650663e-01
     8.076171875000000e-01    -6.497485139460448e-01
    -8.173828125000000e-01     1.691815272062192e-02
     6.826171875000000e-01     2.391403749428440e-01
     9.326171875000000e-01     5.354366712391403e-01
    -8.798828125000000e-01    -5.756744398719708e-01
    -3.798828125000000e-01     7.576588934613624e-01
     6.201171875000000e-01    -3.534522176497485e-01
    -6.298828125000000e-01     3.132144490169182e-01
     8.701171875000000e-01    -3.205304069501601e-01
    -7.548828125000000e-01     3.461362597165065e-01
     7.451171875000000e-01     5.683584819387286e-01
    -9.931640625000000e-01    -2.464563328760860e-01
     6.835937500000000e-03     4.202103337905807e-01
    -7.431640625000000e-01     6.424325560128026e-01
     7.568359375000000e-01     8.646547782350249e-01
    -8.681640625000000e-01    -8.390489254686786e-01
    -3.681640625000000e-01     4.942844078646547e-01
     6.318359375000000e-01    -6.168267032464563e-01
    -6.181640625000000e-01     4.983996342021024e-02
     3.818359375000000e-01     7.165066300868768e-01
     8.818359375000000e-01     2.720621856424326e-01
    -9.306640625000000e-01     9.387288523090991e-01
    -6.806640625000000e-01    -7.402834933699132e-01
     8.193359375000000e-01    -5.180612711476908e-01
    -8.056640625000000e-01     1.486053955189759e-01
     6.943359375000000e-01    -2.217649748513947e-01
    -5.556640625000000e-01     4.449016918152722e-01
     9.443359375000000e-01     6.671239140374940e-01
    -9.619140625000000e-01    -4.439871970736169e-01
     3.808593750000000e-02     2.226794695930499e-01
    -7.119140625000000e-01    -1.476909007773206e-01
     2.880859375000000e-01     5.189757658893461e-01
     7.880859375000000e-01     7.453132144490149e-02
    -8.369140625000000e-01     7.411979881115680e-01
     6.630859375000000e-01     9.634202103337903e-01
    -8.691406250000000e-02     3.955189757658892e-01
     9.130859375000000e-01    -7.155921353452217e-01
    -8.994140625000000e-01    -4.892546867855518e-02
     6.005859375000000e-01     1.732967535436671e-01
    -6.494140625000000e-01     8.399634202103337e-01
     8.505859375000000e-01     4.695930498399634e-01
    -7.744140625000000e-01    -6.415180612711477e-01
     7.255859375000000e-01    -4.192958390489255e-01
     9.755859375000000e-01    -1.229995427526293e-01
    -9.775390625000000e-01     5.436671239140374e-01
     5.224609375000000e-01     7.658893461362595e-01
    -7.275390625000000e-01    -3.452217649748515e-01
     2.724609375000000e-01     3.214449016918153e-01
     7.724609375000000e-01    -9.789666209419295e-01
    -8.525390625000000e-01    -3.122999542752629e-01
     1.474609375000000e-01     3.543667123914036e-01
     6.474609375000000e-01    -9.007773205304070e-02
    -6.025390625000000e-01     5.765889346136257e-01
     8.974609375000000e-01     7.988111568358480e-01
    -9.150390625000000e-01    -9.048925468678555e-01
    -4.150390625000000e-01     4.284407864654778e-01
    -6.650390625000000e-01    -1.600365797896663e-02
     3.349609375000000e-01     6.506630086876997e-01
     8.349609375000000e-01     2.062185642432555e-01
    -7.900390625000000e-01     8.728852309099220e-01
     7.099609375000000e-01     5.025148605395517e-01
     9.599609375000000e-01    -3.863740283493370e-01
    -9.462890625000000e-01     2.802926383173296e-01
    -6.962890625000000e-01     3.790580704160948e-01
     8.037109375000000e-01     6.012802926383172e-01
    -8.212890625000000e-01    -5.098308184727938e-01
     6.787109375000000e-01    -8.802011888431641e-01
     4.287109375000000e-01     4.531321444901693e-01
     9.287109375000000e-01     8.687700045724611e-03
    -8.837890625000000e-01     6.753543667123911e-01
     6.162109375000000e-01     8.975765889346135e-01
    -6.337890625000000e-01    -8.061271147690900e-01
    -1.337890625000000e-01     5.272062185642432e-01
     8.662109375000000e-01    -5.839048925468679e-01
    -7.587890625000000e-01     8.276177411979857e-02
     7.412109375000000e-01     3.049839963420209e-01
     9.912109375000000e-01     4.037494284407863e-01
    -9.853515625000000e-01    -7.073616826703246e-01
    -4.853515625000000e-01     6.259716506630084e-01
    -7.353515625000000e-01     1.815272062185642e-01
     7.646484375000000e-01    -1.888431641518061e-01
    -8.603515625000000e-01     4.778235025148605e-01
     6.396484375000000e-01     7.000457247370824e-01
    -6.103515625000000e-01    -4.110653863740283e-01
     8.896484375000000e-01    -7.814357567443987e-01
    -9.228515625000000e-01    -1.147690900777321e-01
    -6.728515625000000e-01     7.741197988111566e-01
    -1.728515625000000e-01     3.296753543667124e-01
     8.271484375000000e-01     9.963420210333789e-01
    -7.978515625000000e-01    -9.926840420667581e-01
    -2.978515625000000e-01     3.406492912665753e-01
     7.021484375000000e-01    -7.704618198445359e-01
     4.521484375000000e-01     5.628715134887974e-01
     9.521484375000000e-01     1.184270690443532e-01
    -9.541015625000000e-01     7.850937357110197e-01
    -7.041015625000000e-01    -6.963877457704619e-01
     7.958984375000000e-01    -4.741655235482396e-01
    -8.291015625000000e-01     1.925011431184271e-01
     6.708984375000000e-01    -1.778692272519433e-01
    -5.791015625000000e-01     4.887974394147234e-01
     9.208984375000000e-01     7.110196616369455e-01
    -8.916015625000000e-01    -4.000914494741655e-01
     1.083984375000000e-01     2.665752171925013e-01
    -6.416015625000000e-01    -3.013260173754001e-01
     3.583984375000000e-01     3.653406492912665e-01
     8.583984375000000e-01    -7.910379515317789e-02
    -7.666015625000000e-01     5.875628715134888e-01
     7.333984375000000e-01     8.097850937357112e-01
    -1.660156250000000e-02     4.394147233653409e-01
     9.833984375000000e-01    -6.716963877457705e-01
    -9.697265625000000e-01    -5.029721079103822e-03
    -7.197265625000000e-01     8.838591678097851e-01
     7.802734375000000e-01     5.134887974394149e-01
    -8.447265625000000e-01    -5.976223136716965e-01
     6.552734375000000e-01    -3.754000914494742e-01
     9.052734375000000e-01    -2.766346593507087e-01
    -9.072265625000000e-01     3.900320073159580e-01
     5.927734375000000e-01     6.122542295381801e-01
    -6.572265625000000e-01    -4.988568815729310e-01
     8.427734375000000e-01    -8.692272519433013e-01
    -7.822265625000000e-01    -2.025605852766347e-01
     2.177734375000000e-01     4.641060813900322e-01
     7.177734375000000e-01     1.966163694558776e-02
    -5.322265625000000e-01     6.863283036122541e-01
    -3.222656250000000e-02     2.418838591678099e-01
    -9.384765625000000e-01    -7.951531778692272e-01
    -4.384765625000000e-01     5.381801554641061e-01
    -6.884765625000000e-01     9.373571101966172e-02
     8.115234375000000e-01     3.159579332418840e-01
     6.865234375000000e-01     3.488797439414724e-01
     9.365234375000000e-01    -5.400091449474166e-01
    -8.759765625000000e-01     1.266575217192503e-01
     6.240234375000000e-01    -2.437128486511203e-01
    -6.259765625000000e-01     4.229538180155465e-01
     8.740234375000000e-01     6.451760402377684e-01
    -7.509765625000000e-01    -4.659350708733425e-01
     7.490234375000000e-01    -8.363054412437129e-01
     4.990234375000000e-01     4.970278920896205e-01
     9.990234375000000e-01     5.258344764517608e-02
    -9.995117187500000e-01     7.192501143118426e-01
    -7.495117187500000e-01    -9.597622313671696e-01
    -2.495117187500000e-01     3.735711019661636e-01
     7.504882812500000e-01    -7.375400091449474e-01
    -8.745117187500000e-01    -7.087334247828081e-02
     6.254882812500000e-01     1.513488797439417e-01
    -6.245117187500000e-01     8.180155464106083e-01
     8.754882812500000e-01     4.476451760402380e-01
    -9.370117187500000e-01    -6.634659350708734e-01
    -4.370117187500000e-01     6.698673982624599e-01
    -6.870117187500000e-01     2.254229538180157e-01
     8.129882812500000e-01    -1.449474165523549e-01
    -8.120117187500000e-01     5.217192501143120e-01
     6.879882812500000e-01     7.439414723365338e-01
    -9.682617187500000e-01    -2.684042066758117e-01
     3.173828125000000e-02     3.982624599908551e-01
    -7.182617187500000e-01     6.204846822130772e-01
     7.817382812500000e-01     8.427069044352995e-01
    -8.432617187500000e-01    -8.609967992684042e-01
    -3.432617187500000e-01     4.723365340649293e-01
     6.567382812500000e-01    -6.387745770461820e-01
     4.067382812500000e-01     6.945587562871511e-01
     9.067382812500000e-01     2.501143118427069e-01
    -9.057617187500000e-01     9.167809785093735e-01
     5.942382812500000e-01     5.464106081390032e-01
    -6.557617187500000e-01    -5.647005029721079e-01
     8.442382812500000e-01    -3.424782807498857e-01
    -7.807617187500000e-01     3.241883859167811e-01
     7.192382812500000e-01    -3.095564700502972e-01
     9.692382812500000e-01     5.793324188385915e-01
    -9.838867187500000e-01    -5.317786922725195e-01
    -4.838867187500000e-01     8.015546410608139e-01
    -7.338867187500000e-01    -2.354823959762231e-01
     2.661132812500000e-01     4.311842706904436e-01
     7.661132812500000e-01    -1.326017375400090e-02
    -8.588867187500000e-01     6.534064929126655e-01
     6.411132812500000e-01     8.756287151348878e-01
    -1.088867187500000e-01     5.052583447645176e-01
     8.911132812500000e-01    -6.058527663465936e-01
    -9.213867187500000e-01     6.081390032007317e-02
     8.286132812500000e-01     3.818015546410607e-01
    -7.963867187500000e-01    -7.293095564700504e-01
    -2.963867187500000e-01     6.040237768632830e-01
     7.036132812500000e-01    -5.070873342478281e-01
     4.536132812500000e-01     8.262459990855053e-01
     9.536132812500000e-01    -2.107910379515318e-01
    -9.526367187500000e-01     4.558756287151351e-01
     5.473632812500000e-01     6.780978509373570e-01
    -7.026367187500000e-01    -4.330132601737540e-01
     7.973632812500000e-01    -8.033836305441244e-01
    -8.276367187500000e-01    -1.367169638774577e-01
     1.723632812500000e-01     5.299497027892091e-01
     6.723632812500000e-01     8.550525834476441e-02
    -5.776367187500000e-01     7.521719250114309e-01
    -7.763671875000000e-02     3.077274805669867e-01
    -8.901367187500000e-01    -9.268404206675812e-01
    -3.901367187500000e-01     4.064929126657522e-01
    -6.401367187500000e-01    -3.795153177869226e-02
     3.598632812500000e-01     6.287151348879743e-01
     8.598632812500000e-01     1.842706904435301e-01
    -7.651367187500000e-01     8.509373571101966e-01
     7.348632812500000e-01     4.805669867398263e-01
     9.848632812500000e-01    -4.083219021490626e-01
    -9.916992187500000e-01     2.583447645176040e-01
    -7.416992187500000e-01     5.546410608139003e-01
     7.583007812500000e-01     7.768632830361224e-01
    -8.666992187500000e-01    -3.342478280749885e-01
     1.333007812500000e-01     3.324188385916782e-01
    -6.166992187500000e-01    -3.330285017527816e-01
     8.833007812500000e-01    -1.108062795305594e-01
    -9.291992187500000e-01     5.558603871361072e-01
     5.708007812500000e-01     7.780826093583295e-01
    -6.791992187500000e-01    -9.256210943453742e-01
    -1.791992187500000e-01     4.077122389879593e-01
     8.208007812500000e-01    -7.033988721231520e-01
    -8.041992187500000e-01    -3.673220545648537e-02
     6.958007812500000e-01     1.854900167657370e-01
    -5.541992187500000e-01     8.521566834324035e-01
     9.458007812500000e-01     4.817863130620332e-01
    -9.604492187500000e-01    -6.293247980490779e-01
    -4.604492187500000e-01     7.040085352842553e-01
    -7.104492187500000e-01     2.595640908398111e-01
     7.895507812500000e-01    -3.083371437280903e-01
    -8.354492187500000e-01     3.583295229385763e-01
     6.645507812500000e-01     5.805517451607987e-01
     9.145507812500000e-01    -9.009297363206829e-01
    -8.979492187500000e-01    -2.342630696540162e-01
     1.020507812500000e-01     4.324035970126507e-01
     6.020507812500000e-01    -1.204084743179401e-02
    -6.479492187500000e-01     6.546258192348726e-01
    -1.479492187500000e-01     2.101813747904284e-01
     8.520507812500000e-01     8.768480414570949e-01
    -7.729492187500000e-01    -8.268556622466088e-01
    -2.729492187500000e-01     5.064776710867247e-01
     7.270507812500000e-01    -6.046334400243866e-01
     4.770507812500000e-01     7.286998933089466e-01
     9.770507812500000e-01     2.842554488645024e-01
    -9.760742187500000e-01     9.509221155311689e-01
    -7.260742187500000e-01    -7.280902301478434e-01
    -2.260742187500000e-01     6.052431031854899e-01
     7.739257812500000e-01    -5.058680079256211e-01
    -8.510742187500000e-01     1.607986587410457e-01
     6.489257812500000e-01    -2.095717116293249e-01
    -6.010742187500000e-01     4.570949550373420e-01
     8.989257812500000e-01     6.793171772595639e-01
    -9.135742187500000e-01    -4.317939338515471e-01
     8.642578125000000e-02     2.348727328151197e-01
    -6.635742187500000e-01    -1.354976375552508e-01
     3.364257812500000e-01     5.311690291114159e-01
     8.364257812500000e-01     8.672458466697153e-02
    -7.885742187500000e-01     7.533912513336380e-01
    -2.885742187500000e-01     3.089468068891938e-01
     7.114257812500000e-01     9.756134735558604e-01
    -3.857421875000000e-02     3.418686175887822e-01
     9.614257812500000e-01    -7.692424935223290e-01
    -9.448242187500000e-01    -1.025758268556624e-01
    -6.948242187500000e-01     7.863130620332266e-01
     8.051757812500000e-01     4.159426916628564e-01
    -8.198242187500000e-01    -6.951684194482548e-01
    -3.198242187500000e-01     6.381649138850782e-01
     6.801757812500000e-01    -4.729461972260327e-01
     9.301757812500000e-01    -1.766499009297364e-01
    -8.823242187500000e-01     4.900167657369303e-01
     6.176757812500000e-01     7.122389879591524e-01
    -6.323242187500000e-01    -3.988721231519586e-01
     8.676757812500000e-01    -9.667733577198597e-01
    -7.573242187500000e-01    -3.001066910531932e-01
     2.426757812500000e-01     3.665599756134734e-01
     7.426757812500000e-01    -7.788446883097100e-02
    -5.073242187500000e-01     5.887821978356957e-01
    -7.456054687500000e-01    -3.810394756896929e-03
     7.543945312500000e-01     2.184118274653255e-01
    -8.706054687500000e-01     8.850784941319920e-01
     6.293945312500000e-01     5.147081237616218e-01
    -6.206054687500000e-01    -5.964029873494894e-01
     8.793945312500000e-01    -3.741807651272673e-01
    -9.331054687500000e-01     2.924859015393995e-01
    -6.831054687500000e-01     3.912513336381649e-01
     8.168945312500000e-01     6.134735558603870e-01
    -8.081054687500000e-01    -4.976375552507241e-01
     6.918945312500000e-01    -8.680079256210944e-01
     4.418945312500000e-01     4.653254077122391e-01
     9.418945312500000e-01     2.088096326779465e-02
    -9.643554687500000e-01     6.875476299344609e-01
    -7.143554687500000e-01    -7.939338515470202e-01
    -2.143554687500000e-01     5.393994817863130e-01
     7.856445312500000e-01    -5.717116293247981e-01
    -8.393554687500000e-01     9.495503734186861e-02
     6.606445312500000e-01     3.171772595640909e-01
     9.106445312500000e-01     3.500990702636793e-01
    -9.018554687500000e-01    -7.610120408474318e-01
    -4.018554687500000e-01     5.723212924859014e-01
    -6.518554687500000e-01     1.278768480414572e-01
     8.481445312500000e-01    -2.424935223289133e-01
    -7.768554687500000e-01     4.241731443377534e-01
     7.231445312500000e-01     6.463953665599753e-01
    -9.799804687500000e-01    -1.684194482548392e-01
     2.001953125000000e-02     4.982472184118274e-01
    -7.299804687500000e-01     7.204694406340495e-01
    -2.299804687500000e-01     2.760249961896053e-01
     7.700195312500000e-01     9.426916628562718e-01
    -8.549804687500000e-01    -9.585429050449626e-01
    -3.549804687500000e-01     3.747904282883705e-01
     6.450195312500000e-01    -7.363206828227404e-01
    -6.049804687500000e-01    -6.965401615607381e-02
     3.950195312500000e-01     5.970126505105928e-01
     8.950195312500000e-01     1.525682060661486e-01
    -9.174804687500000e-01     8.192348727328151e-01
     5.825195312500000e-01     4.488645023624449e-01
    -6.674804687500000e-01    -6.622466087486665e-01
     8.325195312500000e-01    -4.400243865264442e-01
    -7.924804687500000e-01     2.266422801402226e-01
     7.075195312500000e-01    -1.437280902301479e-01
    -5.424804687500000e-01     5.229385764365189e-01
     9.575195312500000e-01     7.451607986587407e-01
    -9.487304687500000e-01    -3.659503124523701e-01
     5.126953125000000e-02     3.007163542142965e-01
    -6.987304687500000e-01    -2.671848803536047e-01
     3.012695312500000e-01     3.994817863130620e-01
     8.012695312500000e-01    -4.496265813138245e-02
    -8.237304687500000e-01     6.217040085352841e-01
     6.762695312500000e-01     8.439262307575064e-01
    -7.373046875000000e-02     4.735558603871362e-01
     9.262695312500000e-01    -6.375552507239750e-01
    -8.862304687500000e-01     2.911141594269173e-02
     6.137695312500000e-01     2.513336381649138e-01
    -6.362304687500000e-01     9.180003048315803e-01
     8.637695312500000e-01     5.476299344612101e-01
    -7.612304687500000e-01    -5.634811766499010e-01
     7.387695312500000e-01    -3.412589544276787e-01
     9.887695312500000e-01    -3.302850175278159e-01
    -9.877929687500000e-01     3.363816491388507e-01
     5.122070312500000e-01     5.586038713610728e-01
    -7.377929687500000e-01    -5.525072397500381e-01
     7.622070312500000e-01    -9.228776101204085e-01
    -8.627929687500000e-01    -2.562109434537418e-01
     1.372070312500000e-01     4.104557232129249e-01
     6.372070312500000e-01    -3.398872123151964e-02
    -6.127929687500000e-01     6.326779454351468e-01
    -1.127929687500000e-01     1.882335009907026e-01
     8.872070312500000e-01     8.549001676573691e-01
    -9.252929687500000e-01    -8.488035360463344e-01
    -4.252929687500000e-01     4.845297972869989e-01
    -6.752929687500000e-01     4.008535284255443e-02
     3.247070312500000e-01     7.067520195092210e-01
     8.247070312500000e-01     2.623075750647768e-01
    -8.002929687500000e-01     9.289742417314433e-01
     6.997070312500000e-01     3.610730071635420e-01
     9.497070312500000e-01    -5.278158817253468e-01
    -9.565429687500000e-01     1.388507849413201e-01
    -7.065429687500000e-01     4.351470812376164e-01
     7.934570312500000e-01     6.573693034598382e-01
    -8.315429687500000e-01    -4.537418076512727e-01
     1.684570312500000e-01     2.129248590153940e-01
     6.684570312500000e-01    -8.241121780216430e-01
     4.184570312500000e-01     5.092211553116903e-01
     9.184570312500000e-01     6.477671086724568e-02
    -8.940429687500000e-01     7.314433775339122e-01
    -1.440429687500000e-01     3.857643651882334e-01
     8.559570312500000e-01    -7.253467459228776e-01
    -7.690429687500000e-01    -5.868007925621099e-02
     2.309570312500000e-01     6.079865874104555e-01
     7.309570312500000e-01     1.635421429660113e-01
    -5.190429687500000e-01     8.302088096326778e-01
     9.809570312500000e-01     4.598384392623076e-01
    -9.721679687500000e-01    -6.512726718488036e-01
    -4.721679687500000e-01     6.820606614845295e-01
    -7.221679687500000e-01     2.376162170400853e-01
     7.778320312500000e-01    -1.327541533302851e-01
    -8.471679687500000e-01     5.339125133363816e-01
     6.528320312500000e-01     7.561347355586037e-01
    -9.096679687500000e-01    -3.220545648529188e-01
     9.033203125000000e-02     3.446121018137478e-01
    -6.596679687500000e-01     5.668343240359699e-01
     8.403320312500000e-01     7.890565462581922e-01
    -7.846679687500000e-01    -9.146471574455114e-01
    -2.846679687500000e-01     4.186861758878220e-01
     7.153320312500000e-01    -6.924249352232892e-01
     4.653320312500000e-01     6.409083981100439e-01
     9.653320312500000e-01     1.964639536655997e-01
    -9.409179687500000e-01     8.631306203322662e-01
     5.590820312500000e-01     4.927602499618959e-01
    -6.909179687500000e-01    -6.183508611492150e-01
     8.090820312500000e-01    -3.961286389269929e-01
    -8.159179687500000e-01     2.705380277396738e-01
     6.840820312500000e-01    -2.973632068282275e-01
     9.340820312500000e-01     5.915256820606614e-01
    -8.784179687500000e-01    -5.195854290504496e-01
    -6.284179687500000e-01    -2.232891327541534e-01
     3.715820312500000e-01     4.433775339125134e-01
     8.715820312500000e-01    -1.066910531931198e-03
    -7.534179687500000e-01     6.655997561347353e-01
     7.465820312500000e-01     8.878219783569576e-01
    -3.417968750000000e-03     5.174516079865874e-01
     9.965820312500000e-01    -5.936595031245238e-01
    -9.975585937500000e-01     7.300716354214276e-02
    -7.475585937500000e-01     9.618960524310316e-01
     7.524414062500000e-01     3.939948178631305e-01
    -8.725585937500000e-01    -7.171162932479804e-01
    -3.725585937500000e-01     6.162170400853526e-01
     6.274414062500000e-01    -4.948940710257583e-01
    -6.225585937500000e-01     1.717725956409084e-01
     8.774414062500000e-01    -1.985977747294621e-01
    -9.350585937500000e-01     4.680688919372047e-01
     5.649414062500000e-01     6.902911141594266e-01
    -6.850585937500000e-01    -4.208199969516843e-01
     8.149414062500000e-01    -7.911903673220546e-01
    -8.100585937500000e-01    -1.245237006553880e-01
     1.899414062500000e-01     5.421429660112786e-01
     6.899414062500000e-01     9.769852156683423e-02
    -5.600585937500000e-01     7.643651882335007e-01
    -6.005859375000000e-02     3.199207437890565e-01
    -7.163085937500000e-01    -9.160188995579943e-02
     2.836914062500000e-01     5.750647767108670e-01
     7.836914062500000e-01     1.306203322664228e-01
    -8.413085937500000e-01     7.972869989330893e-01
     6.586914062500000e-01     4.269166285627191e-01
     9.086914062500000e-01    -4.619722603261698e-01
    -9.038085937500000e-01     2.046944063404967e-01
    -6.538085937500000e-01     5.009907026367930e-01
     8.461914062500000e-01     7.232129248590151e-01
    -7.788085937500000e-01    -3.878981862520957e-01
     2.211914062500000e-01     2.787684804145709e-01
     7.211914062500000e-01    -9.557994208199969e-01
     9.711914062500000e-01    -6.691053193110807e-02
    -9.819335937500000e-01     5.997561347355584e-01
     5.180664062500000e-01     8.219783569577808e-01
    -7.319335937500000e-01    -8.817253467459228e-01
    -2.319335937500000e-01     4.516079865874105e-01
     7.680664062500000e-01    -6.595031245237006e-01
    -8.569335937500000e-01     7.163542142965884e-03
     6.430664062500000e-01     2.293857643651882e-01
    -6.069335937500000e-01     8.960524310318547e-01
     8.930664062500000e-01     5.256820606614845e-01
    -9.194335937500000e-01    -5.854290504496267e-01
    -4.194335937500000e-01     7.479042828837064e-01
    -6.694335937500000e-01     3.034598384392622e-01
     8.305664062500000e-01    -2.644413961286389e-01
    -7.944335937500000e-01     4.022252705380276e-01
     7.055664062500000e-01     6.244474927602497e-01
     9.555664062500000e-01    -8.570339887212315e-01
    -9.506835937500000e-01    -1.903673220545649e-01
     4.931640625000000e-02     4.762993446121018e-01
    -7.006835937500000e-01     6.985215668343236e-01
    -2.006835937500000e-01     2.540771223898795e-01
     7.993164062500000e-01     9.207437890565460e-01
    -8.256835937500000e-01    -7.829599146471574e-01
    -3.256835937500000e-01     5.503734186861757e-01
     6.743164062500000e-01    -5.607376924249352e-01
     4.243164062500000e-01     7.725956409083978e-01
     9.243164062500000e-01     3.281511964639536e-01
     6.118164062500000e-01     3.391251333638166e-01
    -6.381835937500000e-01    -7.719859777472946e-01
     8.618164062500000e-01    -5.497637555250725e-01
    -7.631835937500000e-01     1.169029111415945e-01
     7.368164062500000e-01    -2.534674592287761e-01
     9.868164062500000e-01     6.354214296601126e-01
    -9.897460937500000e-01    -4.756896814509983e-01
     1.025390625000000e-02     1.909769852156684e-01
    -7.397460937500000e-01    -1.793933851547020e-01
     2.602539062500000e-01     4.872732815119647e-01
     7.602539062500000e-01     4.282883706752028e-02
    -8.647460937500000e-01     7.094955037341868e-01
     6.352539062500000e-01     9.317177259564091e-01
    -1.147460937500000e-01     3.638164913885078e-01
     8.852539062500000e-01    -7.472946197226034e-01
    -9.272460937500000e-01    -8.062795305593662e-02
    -6.772460937500000e-01     8.082609358329524e-01
     8.227539062500000e-01     4.378905654625822e-01
    -8.022460937500000e-01    -6.732205456485292e-01
    -3.022460937500000e-01     6.601127876848041e-01
     6.977539062500000e-01    -4.509983234263070e-01
     9.477539062500000e-01    -1.547020271300107e-01
    -9.584960937500000e-01     5.119646395366562e-01
     5.415039062500000e-01     7.341868617588780e-01
    -7.084960937500000e-01    -3.769242493522329e-01
     7.915039062500000e-01    -9.448254839201341e-01
    -8.334960937500000e-01    -2.781588172534675e-01
     1.665039062500000e-01     3.885078494131993e-01
     6.665039062500000e-01    -5.593659503124526e-02
    -5.834960937500000e-01     6.107300716354214e-01
    -8.349609375000000e-02     1.662856271909772e-01
     9.165039062500000e-01     8.329522938576437e-01
    -8.959960937500000e-01    -8.707514098460600e-01
    -3.959960937500000e-01     4.625819234872734e-01
    -6.459960937500000e-01     1.813747904282903e-02
     3.540039062500000e-01     6.848041457094953e-01
     8.540039062500000e-01     2.403597012650511e-01
    -7.709960937500000e-01     9.070263679317176e-01
     7.290039062500000e-01     5.366559975613474e-01
     9.790039062500000e-01    -3.522328913275415e-01
    -9.741210937500000e-01     3.144337753391253e-01
    -7.241210937500000e-01     3.473555860387136e-01
     7.758789062500000e-01     5.695778082609357e-01
    -8.491210937500000e-01    -5.415333028501753e-01
     4.008789062500000e-01     4.214296601127878e-01
     9.008789062500000e-01    -2.301478433165682e-02
    -9.116210937500000e-01     6.436518823350097e-01
     5.883789062500000e-01     8.658741045572320e-01
    -6.616210937500000e-01    -8.378295991464716e-01
    -1.616210937500000e-01     4.955037341868618e-01
     8.383789062500000e-01    -6.156073769242494e-01
    -7.866210937500000e-01     5.105928974241736e-02
     7.133789062500000e-01     2.732815119646397e-01
     9.633789062500000e-01     3.720469440634049e-01
    -9.428710937500000e-01    -7.390641670477062e-01
    -4.428710937500000e-01     5.942691662856272e-01
    -6.928710937500000e-01     1.498247218411830e-01
     8.071289062500000e-01    -2.205456485291877e-01
    -8.178710937500000e-01     4.461210181374793e-01
     6.821289062500000e-01     6.683432403597012e-01
     9.321289062500000e-01    -8.131382411217802e-01
    -8.803710937500000e-01    -1.464715744551136e-01
     1.196289062500000e-01     5.201950922115532e-01
     6.196289062500000e-01     7.575064776710860e-02
    -6.303710937500000e-01     7.424173144337751e-01
    -1.303710937500000e-01     2.979728699893309e-01
     8.696289062500000e-01     9.646395366559974e-01
    -7.553710937500000e-01    -9.365950312452370e-01
    -2.553710937500000e-01     3.967383020880964e-01
     7.446289062500000e-01    -7.143728090230148e-01
     4.946289062500000e-01     6.189605243103184e-01
     9.946289062500000e-01     1.745160798658743e-01
    -9.936523437500000e-01     8.411827465325408e-01
     5.063476562500000e-01     4.708123761621705e-01
    -7.436523437500000e-01    -6.402987349489407e-01
     7.563476562500000e-01    -4.180765127267185e-01
    -8.686523437500000e-01     2.485901539399482e-01
     6.313476562500000e-01    -1.217802164304223e-01
    -6.186523437500000e-01     5.448864502362445e-01
     8.813476562500000e-01     7.671086724584666e-01
    -9.311523437500000e-01    -3.440024386526445e-01
     6.884765625000000e-02     3.226642280140224e-01
    -6.811523437500000e-01    -3.110806279530559e-01
     3.188476562500000e-01     3.555860387136107e-01
     8.188476562500000e-01    -8.885840573083370e-02
    -8.061523437500000e-01     5.778082609358328e-01
     6.938476562500000e-01     8.000304831580551e-01
    -5.615234375000000e-02     4.296601127876849e-01
     9.438476562500000e-01    -6.814509983234264e-01
    -9.624023437500000e-01    -1.478433165675963e-02
    -7.124023437500000e-01     8.741045572321291e-01
     7.875976562500000e-01     5.037341868617589e-01
    -8.374023437500000e-01    -6.073769242493523e-01
    -3.374023437500000e-01     7.259564090839810e-01
     6.625976562500000e-01    -3.851547020271300e-01
     9.125976562500000e-01    -2.863892699283646e-01
    -8.999023437500000e-01     3.802773967383020e-01
     6.000976562500000e-01     6.024996189605243e-01
    -6.499023437500000e-01    -5.086114921505869e-01
     8.500976562500000e-01    -8.789818625209571e-01
    -7.749023437500000e-01    -2.123151958542905e-01
     2.250976562500000e-01     4.543514708123764e-01
     7.250976562500000e-01     9.907026367931726e-03
    -5.249023437500000e-01     6.765736930345982e-01
    -2.490234375000000e-02     2.321292485901540e-01
    -9.780273437500000e-01    -8.049077884468832e-01
    -4.780273437500000e-01     5.284255448864503e-01
    -7.280273437500000e-01     8.398110044200569e-02
     7.719726562500000e-01     3.062033226642280e-01
    -8.530273437500000e-01     9.728699893308945e-01
     6.469726562500000e-01     4.049687547629934e-01
     8.969726562500000e-01    -4.839201341258954e-01
    -9.155273437500000e-01     1.827465325407713e-01
    -6.655273437500000e-01     4.790428288370676e-01
     8.344726562500000e-01     7.012650510592895e-01
    -7.905273437500000e-01    -4.098460600518213e-01
     2.094726562500000e-01     2.568206066148453e-01
     7.094726562500000e-01    -7.802164304221917e-01
     4.594726562500000e-01     5.531169029111416e-01
     9.594726562500000e-01     1.086724584666972e-01
    -9.467773437500000e-01     7.753391251333637e-01
    -1.967773437500000e-01     3.345526596555404e-01
     8.032226562500000e-01    -7.765584514555708e-01
    -8.217773437500000e-01    -1.098917847889042e-01
     1.782226562500000e-01     5.567748818777625e-01
     6.782226562500000e-01     1.123304374333183e-01
    -5.717773437500000e-01     7.789971040999848e-01
     9.282226562500000e-01     4.086267337296146e-01
    -8.842773437500000e-01    -7.024843773814968e-01
    -3.842773437500000e-01     6.308489559518364e-01
     6.157226562500000e-01    -4.802621551592745e-01
    -6.342773437500000e-01     1.864045115073922e-01
     8.657226562500000e-01    -1.839658588629782e-01
    -7.592773437500000e-01     4.827008078036885e-01
     7.407226562500000e-01     7.049230300259106e-01
    -9.858398437500000e-01    -3.074226489864350e-01
     1.416015625000000e-02     3.592440176802316e-01
    -7.358398437500000e-01     5.814662399024539e-01
     7.641601562500000e-01     8.036884621246763e-01
    -8.608398437500000e-01    -9.000152415790276e-01
    -3.608398437500000e-01     4.333180917543060e-01
     6.391601562500000e-01    -6.777930193568054e-01
    -6.108398437500000e-01    -1.112635269013873e-02
     3.891601562500000e-01     6.555403139765279e-01
     8.891601562500000e-01     2.110958695320837e-01
    -9.233398437500000e-01     8.777625361987502e-01
     5.766601562500000e-01     5.073921658283800e-01
    -6.733398437500000e-01    -6.037189452827314e-01
     8.266601562500000e-01    -3.814967230605091e-01
    -7.983398437500000e-01     2.851699436061577e-01
     7.016601562500000e-01    -2.827312909617437e-01
     9.516601562500000e-01     6.061575979271452e-01
    -9.545898437500000e-01    -5.049535131839660e-01
     4.541015625000000e-02     1.617131534827010e-01
    -7.045898437500000e-01    -2.086572168876696e-01
     2.954101562500000e-01     4.580094497789973e-01
     7.954101562500000e-01     1.356500533455285e-02
    -8.295898437500000e-01     6.802316720012191e-01
     6.704101562500000e-01     9.024538942234415e-01
    -7.958984375000000e-02     5.320835238530712e-01
     9.204101562500000e-01    -5.790275872580399e-01
    -8.920898437500000e-01     8.763907940862681e-02
     6.079101562500000e-01     3.098613016308491e-01
     8.579101562500000e-01     3.427831123304375e-01
    -7.670898437500000e-01    -7.683279987806737e-01
    -2.670898437500000e-01     5.650053345526596e-01
     7.329101562500000e-01    -5.461057765584515e-01
     4.829101562500000e-01     7.872275567748819e-01
     9.829101562500000e-01    -2.498094802621552e-01
    -9.702148437500000e-01     4.168571864045116e-01
     5.297851562500000e-01     6.390794086267335e-01
    -7.202148437500000e-01    -4.720317024843774e-01
     7.797851562500000e-01    -8.424020728547478e-01
    -8.452148437500000e-01    -1.757354061880811e-01
     1.547851562500000e-01     4.909312604785856e-01
     6.547851562500000e-01     4.648681603414118e-02
    -5.952148437500000e-01     7.131534827008077e-01
    -9.521484375000000e-02     2.687090382563635e-01
     9.047851562500000e-01     9.353757049230300e-01
    -6.577148437500000e-01    -7.696997408931572e-02
     3.422851562500000e-01     5.896966925773510e-01
     8.422851562500000e-01     1.452522481329068e-01
    -7.827148437500000e-01     8.119189147995733e-01
     7.172851562500000e-01     4.415485444292031e-01
     9.672851562500000e-01    -4.473403444596861e-01
    -9.389648437500000e-01     2.193263222069808e-01
    -6.889648437500000e-01     5.156226185032771e-01
     8.110351562500000e-01     7.378448407254989e-01
    -8.139648437500000e-01    -3.732662703856120e-01
     1.860351562500000e-01     2.934003962810547e-01
     9.360351562500000e-01    -5.227861606462436e-02
    -8.764648437500000e-01     6.143880506020423e-01
     6.235351562500000e-01     8.366102728242646e-01
    -1.264648437500000e-01     4.662399024538944e-01
     8.735351562500000e-01    -6.448712086572169e-01
    -7.514648437500000e-01     2.179545800944993e-02
     7.485351562500000e-01     2.440176802316720e-01
     9.985351562500000e-01     5.403139765279683e-01
    -9.985351562500000e-01    -5.707971345831429e-01
    -4.985351562500000e-01     7.625361987501904e-01
    -7.485351562500000e-01     3.180917543057462e-01
     7.514648437500000e-01    -3.156531016613321e-01
    -8.735351562500000e-01     3.510135650053345e-01
     6.264648437500000e-01     5.732357872275566e-01
    -6.235351562500000e-01    -5.378753238835544e-01
     8.764648437500000e-01    -9.082456942539247e-01
    -9.360351562500000e-01    -2.415790275872580e-01
     6.396484375000000e-02     4.250876390794087e-01
    -6.860351562500000e-01     6.473098613016306e-01
     8.139648437500000e-01     8.695320835238529e-01
    -8.110351562500000e-01    -8.341716201798506e-01
    -3.110351562500000e-01     4.991617131534827e-01
     6.889648437500000e-01    -6.119493979576285e-01
     4.389648437500000e-01     7.213839353757048e-01
     9.389648437500000e-01     2.769394909312606e-01
    -9.672851562500000e-01     9.436061575979271e-01
    -7.172851562500000e-01    -7.354061880810853e-01
    -2.172851562500000e-01     5.979271452522481e-01
     7.827148437500000e-01    -5.131839658588631e-01
    -8.422851562500000e-01     1.534827008078039e-01
     6.577148437500000e-01    -2.168876695625667e-01
    -5.922851562500000e-01     4.497789971041002e-01
     9.077148437500000e-01     6.720012193263221e-01
    -9.047851562500000e-01    -4.391098917847889e-01
     9.521484375000000e-02     2.275567748818779e-01
    -6.547851562500000e-01    -1.428135954884926e-01
     3.452148437500000e-01     5.238530711781741e-01
     8.452148437500000e-01     7.940862673372950e-02
    -7.797851562500000e-01     7.460752934003960e-01
    -2.797851562500000e-01     3.016308489559518e-01
     7.202148437500000e-01     9.682975156226183e-01
    -2.978515625000000e-02     4.003962810547173e-01
     9.702148437500000e-01    -7.107148300563939e-01
    -9.829101562500000e-01    -4.404816338972717e-02
    -7.329101562500000e-01     8.448407254991617e-01
     7.670898437500000e-01     4.744703551287914e-01
    -8.579101562500000e-01    -6.366407559823198e-01
    -3.579101562500000e-01     6.966925773510133e-01
     6.420898437500000e-01    -4.144185337600975e-01
    -6.079101562500000e-01     2.522481329065691e-01
     8.920898437500000e-01    -1.181222374638012e-01
    -9.204101562500000e-01     5.485444292028654e-01
     5.795898437500000e-01     7.707666514250875e-01
    -6.704101562500000e-01    -3.403444596860234e-01
     8.295898437500000e-01    -9.960371894528273e-01
    -7.954101562500000e-01    -3.293705227861606e-01
     2.045898437500000e-01     3.372961438805060e-01
     7.045898437500000e-01    -1.071483005639384e-01
    -5.454101562500000e-01     5.595183661027281e-01
     9.545898437500000e-01     7.817405883249504e-01
    -7.016601562500000e-01    -3.307422648986436e-02
     2.983398437500000e-01     6.335924401768021e-01
     7.983398437500000e-01     1.891479957323579e-01
    -8.266601562500000e-01     8.558146623990244e-01
     6.733398437500000e-01     4.854442920286541e-01
     9.233398437500000e-01    -4.034445968602347e-01
    -8.891601562500000e-01     2.632220698064320e-01
     6.108398437500000e-01    -3.046791647614693e-01
    -6.391601562500000e-01     3.619875019051972e-01
     8.608398437500000e-01     5.842097241274196e-01
    -7.641601562500000e-01    -5.269013869836916e-01
     7.358398437500000e-01    -8.972717573540618e-01
     9.858398437500000e-01    -8.382868465172999e-03
    -9.907226562500000e-01     6.582837982014935e-01
     5.092773437500000e-01     8.805060204237158e-01
    -7.407226562500000e-01    -8.231976832799879e-01
    -2.407226562500000e-01     5.101356500533456e-01
     7.592773437500000e-01    -6.009754610577656e-01
    -8.657226562500000e-01     6.569120560890096e-02
     6.342773437500000e-01     2.879134278311233e-01
     8.842773437500000e-01     3.866788599298887e-01
    -9.282226562500000e-01    -7.244322511812225e-01
    -4.282226562500000e-01     6.089010821521108e-01
    -6.782226562500000e-01     1.644566377076666e-01
     8.217773437500000e-01    -2.059137326627039e-01
    -8.032226562500000e-01     4.607529340039629e-01
     6.967773437500000e-01     6.829751562261848e-01
     9.467773437500000e-01    -7.985063252552964e-01
    -9.594726562500000e-01    -1.318396585886298e-01
     4.052734375000000e-02     5.348270080780368e-01
    -7.094726562500000e-01     7.570492303002589e-01
    -2.094726562500000e-01     3.126047858558147e-01
     7.905273437500000e-01     9.792714525224813e-01
    -8.344726562500000e-01    -9.878067367779302e-01
    -3.344726562500000e-01     3.455265965554031e-01
     6.655273437500000e-01    -7.655845145557080e-01
     4.155273437500000e-01     5.677488187776252e-01
     9.155273437500000e-01     1.233043743331810e-01
    -8.969726562500000e-01     7.899710409998475e-01
     6.030273437500000e-01     4.196006706294773e-01
    -6.469726562500000e-01    -6.915104404816339e-01
     8.530273437500000e-01    -4.692882182594117e-01
    -7.719726562500000e-01     1.973784484072549e-01
     7.280273437500000e-01    -1.729919219631154e-01
    -5.219726562500000e-01     4.936747447035512e-01
     9.780273437500000e-01     7.158969669257733e-01
    -9.750976562500000e-01    -3.952141441853376e-01
     2.490234375000000e-02     2.714525224813291e-01
    -7.250976562500000e-01    -2.964487120865722e-01
     2.749023437500000e-01     3.702179545800943e-01
     7.749023437500000e-01    -7.422648986434999e-02
    -8.500976562500000e-01     5.924401768023166e-01
     6.499023437500000e-01     8.146623990245390e-01
    -1.000976562500000e-01     4.442920286541687e-01
     8.999023437500000e-01    -6.668190824569425e-01
    -9.125976562500000e-01    -1.524157902759171e-04
    -6.625976562500000e-01     8.887364730986129e-01
     8.374023437500000e-01     5.183661027282427e-01
    -7.875976562500000e-01    -5.927450083828685e-01
     7.124023437500000e-01    -3.705227861606463e-01
     9.624023437500000e-01    -2.717573540618808e-01
    -9.438476562500000e-01     3.949093126047858e-01
     5.561523437500000e-01     6.171315348270079e-01
    -6.938476562500000e-01    -4.939795762841031e-01
     8.061523437500000e-01    -8.643499466544734e-01
    -8.188476562500000e-01    -1.976832799878068e-01
     1.811523437500000e-01     4.689833866788600e-01
     6.811523437500000e-01     2.453894223441555e-02
    -5.688476562500000e-01     6.912056089010818e-01
    -6.884765625000000e-02     2.467611644566376e-01
     9.311523437500000e-01     9.134278311233042e-01
    -8.813476562500000e-01    -7.902758725803993e-01
    -3.813476562500000e-01     5.430574607529339e-01
     6.186523437500000e-01    -5.680536503581771e-01
    -6.313476562500000e-01     9.861301630848951e-02
     3.686523437500000e-01     7.652796829751560e-01
     8.686523437500000e-01     3.208352385307118e-01
     7.436523437500000e-01     3.537570492303002e-01
     9.936523437500000e-01    -5.351318396585887e-01
    -9.946289062500000e-01     1.315348270080781e-01
    -7.446289062500000e-01     4.278311233043743e-01
     7.553710937500000e-01     6.500533455265962e-01
    -8.696289062500000e-01    -4.610577655845145e-01
     1.303710937500000e-01     2.056089010821520e-01
    -6.196289062500000e-01    -1.647614692882182e-01
     3.803710937500000e-01     5.019051973784483e-01
     8.803710937500000e-01     5.746075293400388e-02
    -9.321289062500000e-01     7.241274196006704e-01
    -1.821289062500000e-01     3.784484072549914e-01
     8.178710937500000e-01    -7.326627038561195e-01
    -8.071289062500000e-01    -6.599603718945279e-02
     1.928710937500000e-01     6.006706294772137e-01
     6.928710937500000e-01     1.562261850327695e-01
    -5.571289062500000e-01     8.228928516994360e-01
     9.428710937500000e-01     4.525224813290658e-01
    -9.633789062500000e-01    -6.585886297820455e-01
    -4.633789062500000e-01     6.747447035512877e-01
    -7.133789062500000e-01     2.303002591068435e-01
     7.866210937500000e-01    -1.400701112635269e-01
    -8.383789062500000e-01     5.265965554031398e-01
     6.616210937500000e-01     7.488187776253616e-01
     9.116210937500000e-01    -9.301935680536504e-01
    -9.008789062500000e-01    -2.635269013869836e-01
     9.912109375000000e-02     4.031397652796829e-01
    -6.508789062500000e-01     6.253619875019050e-01
     8.491210937500000e-01     8.475842097241273e-01
    -7.758789062500000e-01    -8.561194939795763e-01
    -2.758789062500000e-01     4.772138393537571e-01
     7.241210937500000e-01    -6.338972717573541e-01
     4.741210937500000e-01     6.994360615759789e-01
     9.741210937500000e-01     2.549916171315347e-01
    -9.790039062500000e-01     9.216582837982012e-01
     5.209960937500000e-01     5.512879134278310e-01
    -7.290039062500000e-01    -5.598231976832800e-01
     7.709960937500000e-01    -3.376009754610577e-01
    -8.540039062500000e-01     3.290656912056089e-01
     6.459960937500000e-01    -3.266270385611949e-01
    -6.040039062500000e-01     3.400396281054718e-01
     8.959960937500000e-01     5.622618503276939e-01
    -9.165039062500000e-01    -5.488492607834172e-01
    -4.165039062500000e-01     7.844840725499163e-01
    -6.665039062500000e-01    -2.525529644871208e-01
     3.334960937500000e-01     4.141137021795460e-01
     8.334960937500000e-01    -3.033074226489862e-02
    -7.915039062500000e-01     6.363359244017679e-01
     7.084960937500000e-01     8.585581466239902e-01
    -4.150390625000000e-02     4.881877762536200e-01
     9.584960937500000e-01    -6.229233348574913e-01
    -9.477539062500000e-01     4.374333180917556e-02
    -6.977539062500000e-01     9.326322206980644e-01
     8.022460937500000e-01     3.647309861301631e-01
    -8.227539062500000e-01    -7.463801249809481e-01
    -3.227539062500000e-01     5.869532083523854e-01
     6.772460937500000e-01    -5.241579027587259e-01
     4.272460937500000e-01     8.091754305746077e-01
     9.272460937500000e-01    -2.278616064624295e-01
    -8.852539062500000e-01     4.388050602042375e-01
     6.147460937500000e-01     6.610272824264594e-01
    -6.352539062500000e-01    -4.500838286846517e-01
     8.647460937500000e-01    -8.204541990550221e-01
    -7.602539062500000e-01    -1.537875323883554e-01
     2.397460937500000e-01     5.128791342783114e-01
     7.397460937500000e-01     6.843468983386680e-02
    -5.102539062500000e-01     7.351013565005333e-01
    -1.025390625000000e-02     2.906569120560891e-01
    -7.368164062500000e-01    -5.502210028958998e-02
     2.631835937500000e-01     6.116445663770766e-01
     7.631835937500000e-01     1.672001219326325e-01
    -8.618164062500000e-01     8.338667885992990e-01
     6.381835937500000e-01     4.634964182289287e-01
    -6.118164062500000e-01    -6.476146928821827e-01
     8.881835937500000e-01    -4.253924706599603e-01
    -9.243164062500000e-01     2.412741960067064e-01
    -6.743164062500000e-01     5.375704923030027e-01
     8.256835937500000e-01     7.597927145252248e-01
    -7.993164062500000e-01    -3.513183965858863e-01
     2.006835937500000e-01     3.153482700807806e-01
     9.506835937500000e-01    -9.617436366407561e-02
    -9.555664062500000e-01     5.704923030025910e-01
     5.444335937500000e-01     7.927145252248133e-01
    -7.055664062500000e-01    -9.109891784788904e-01
    -2.055664062500000e-01     4.223441548544431e-01
     7.944335937500000e-01    -6.887669562566683e-01
    -8.305664062500000e-01    -2.210028959000154e-02
     6.694335937500000e-01     2.001219326322208e-01
    -5.805664062500000e-01     8.667885992988873e-01
     9.194335937500000e-01     4.964182289285171e-01
    -8.930664062500000e-01    -6.146928821825941e-01
    -3.930664062500000e-01     7.186404511507392e-01
     6.069335937500000e-01    -3.924706599603719e-01
    -6.430664062500000e-01     2.741960067062950e-01
     8.569335937500000e-01    -2.937052278616065e-01
    -7.680664062500000e-01     3.729614388050602e-01
     7.319335937500000e-01     5.951836610272825e-01
    -9.711914062500000e-01    -2.196311537875324e-01
     2.880859375000000e-02     4.470355128791346e-01
    -7.211914062500000e-01     6.692577351013564e-01
     7.788085937500000e-01     8.914799573235788e-01
    -8.461914062500000e-01    -8.122237463801250e-01
    -3.461914062500000e-01     5.211095869532085e-01
     6.538085937500000e-01    -5.900015241579029e-01
     4.038085937500000e-01     7.433318091754304e-01
     9.038085937500000e-01     2.988873647309862e-01
    -9.086914062500000e-01     9.655540313976527e-01
     5.913085937500000e-01     3.976527968297516e-01
    -6.586914062500000e-01    -7.134583142813595e-01
     8.413085937500000e-01    -4.912360920591373e-01
    -7.836914062500000e-01     1.754305746075295e-01
     7.163085937500000e-01    -1.949397957628410e-01
    -5.336914062500000e-01     4.717268709038258e-01
     9.663085937500000e-01     6.939490931260477e-01
    -9.399414062500000e-01    -4.171620179850632e-01
     6.005859375000000e-02     2.495046486816035e-01
    -6.899414062500000e-01    -1.208657216887670e-01
     3.100585937500000e-01     5.458009449778998e-01
     8.100585937500000e-01     1.013565005334554e-01
    -8.149414062500000e-01     7.680231672001219e-01
    -3.149414062500000e-01     3.235787227556777e-01
    -6.494140625000000e-02     3.565005334552660e-01
     9.350585937500000e-01    -7.546105776558452e-01
    -8.774414062500000e-01    -8.794391098917842e-02
     6.225585937500000e-01     1.342783112330439e-01
    -6.274414062500000e-01     8.009449778997104e-01
     8.725585937500000e-01     4.305746075293402e-01
    -7.524414062500000e-01    -6.805365035817712e-01
     7.475585937500000e-01    -4.583142813595488e-01
     9.975585937500000e-01    -1.620179850632525e-01
    -9.965820312500000e-01     5.046486816034141e-01
     5.034179687500000e-01     7.268709038256362e-01
    -7.465820312500000e-01    -3.842402072854747e-01
     2.534179687500000e-01     2.824264593811920e-01
     7.534179687500000e-01    -9.521414418533760e-01
    -8.715820312500000e-01    -2.854747751867093e-01
     1.284179687500000e-01     3.811918914799572e-01
     6.284179687500000e-01    -6.325255296448706e-02
    -6.215820312500000e-01     6.034141137021796e-01
     8.784179687500000e-01     8.256363359244019e-01
    -9.340820312500000e-01    -8.780673677793019e-01
    -4.340820312500000e-01     4.552659655540316e-01
    -6.840820312500000e-01     1.082152110958701e-02
     3.159179687500000e-01     6.774881877762535e-01
     8.159179687500000e-01     2.330437433318093e-01
    -8.090820312500000e-01     8.997104099984758e-01
     6.909179687500000e-01     5.293400396281056e-01
     9.409179687500000e-01    -3.595488492607833e-01
    -9.653320312500000e-01     3.071178174058833e-01
    -7.153320312500000e-01     4.058832495046487e-01
     7.846679687500000e-01     6.281054717268708e-01
    -8.403320312500000e-01    -4.830056393842401e-01
     6.596679687500000e-01    -8.533760097546106e-01
     4.096679687500000e-01     4.799573235787229e-01
     9.096679687500000e-01     3.551287913427847e-02
    -9.028320312500000e-01     7.021795458009448e-01
     5.971679687500000e-01     9.244017680231671e-01
    -6.528320312500000e-01    -7.793019356805365e-01
    -1.528320312500000e-01     5.540313976527969e-01
     8.471679687500000e-01    -5.570797134583143e-01
    -7.778320312500000e-01     1.095869532083524e-01
     7.221679687500000e-01     3.318091754305748e-01
     9.721679687500000e-01     3.354671543971957e-01
    -9.809570312500000e-01    -7.756439567139155e-01
    -4.809570312500000e-01     5.576893766194178e-01
    -7.309570312500000e-01     1.132449321749736e-01
     7.690429687500000e-01    -2.571254381953971e-01
    -8.559570312500000e-01     4.095412284712698e-01
     6.440429687500000e-01     6.317634506934917e-01
    -6.059570312500000e-01    -4.793476604176193e-01
     8.940429687500000e-01    -8.497180307879897e-01
    -9.184570312500000e-01    -1.830513641213231e-01
     8.154296875000000e-02     4.836153025453438e-01
    -6.684570312500000e-01     7.058375247675659e-01
    -1.684570312500000e-01     2.613930803231217e-01
     8.315429687500000e-01     9.280597469897882e-01
    -7.934570312500000e-01    -9.731748209114465e-01
    -2.934570312500000e-01     3.601585124218869e-01
     7.065429687500000e-01    -7.509525986892243e-01
     4.565429687500000e-01     5.823807346441092e-01
     9.565429687500000e-01     1.379362901996650e-01
    -9.497070312500000e-01     8.046029568663315e-01
    -6.997070312500000e-01    -6.768785246151502e-01
     8.002929687500000e-01    -4.546563023929280e-01
    -8.247070312500000e-01     2.120103642737390e-01
     6.752929687500000e-01    -1.583600060966317e-01
    -5.747070312500000e-01     5.083066605700353e-01
     9.252929687500000e-01     7.305288827922571e-01
    -8.872070312500000e-01    -3.805822283188539e-01
     1.127929687500000e-01     2.860844383478129e-01
    -6.372070312500000e-01    -2.818167962200885e-01
     3.627929687500000e-01     3.848498704465784e-01
     8.627929687500000e-01    -5.959457399786627e-02
    -7.622070312500000e-01     6.070720926688005e-01
     7.377929687500000e-01     8.292943148910228e-01
    -1.220703125000000e-02     4.589239445206525e-01
     9.877929687500000e-01    -6.521871665904588e-01
    -9.887695312500000e-01     1.447950007620813e-02
    -7.387695312500000e-01     9.033683889650967e-01
     7.612304687500000e-01     5.329980185947265e-01
    -8.637695312500000e-01    -5.781130925163848e-01
     6.362304687500000e-01    -3.558908702941626e-01
    -6.137695312500000e-01     3.107757963725044e-01
     8.862304687500000e-01    -3.229690595945741e-01
    -9.262695312500000e-01     3.436976070720927e-01
     5.737304687500000e-01     5.659198292943148e-01
    -6.762695312500000e-01    -5.451912818167963e-01
     8.237304687500000e-01    -9.155616521871666e-01
    -8.012695312500000e-01    -2.488949855205000e-01
     1.987304687500000e-01     4.177716811461669e-01
     6.987304687500000e-01    -2.667276329827784e-02
    -5.512695312500000e-01     6.399939033683888e-01
    -5.126953125000000e-02     1.955494589239446e-01
     9.487304687500000e-01     8.622161255906111e-01
    -9.575195312500000e-01    -8.414875781130925e-01
    -4.575195312500000e-01     4.918457552202409e-01
    -7.075195312500000e-01     4.740131077579646e-02
     7.924804687500000e-01     2.696235329980188e-01
    -8.325195312500000e-01     9.362901996646853e-01
     6.674804687500000e-01     3.683889650967840e-01
     9.174804687500000e-01    -5.204999237921049e-01
    -8.950195312500000e-01     1.461667428745621e-01
     6.049804687500000e-01    -2.242036274958087e-01
    -6.450195312500000e-01     4.424630391708584e-01
     8.549804687500000e-01     6.646852613930803e-01
    -7.700195312500000e-01    -4.464258497180309e-01
     7.299804687500000e-01    -8.167962200884011e-01
     4.799804687500000e-01     5.165371132449323e-01
     9.799804687500000e-01     7.209266880048770e-02
    -9.731445312500000e-01     7.387593354671542e-01
    -7.231445312500000e-01    -9.402530102118579e-01
    -2.231445312500000e-01     3.930803231214755e-01
     7.768554687500000e-01    -7.180307879896357e-01
    -8.481445312500000e-01    -5.136412132296919e-02
     6.518554687500000e-01     1.708581008992534e-01
    -5.981445312500000e-01     8.375247675659199e-01
     9.018554687500000e-01     4.671543971955496e-01
    -9.106445312500000e-01    -6.439567139155618e-01
    -4.106445312500000e-01     6.893766194177715e-01
    -6.606445312500000e-01     2.449321749733273e-01
     8.393554687500000e-01    -1.254381953970433e-01
    -7.856445312500000e-01     5.412284712696236e-01
     7.143554687500000e-01     7.634506934918457e-01
    -9.418945312500000e-01    -3.147386069196769e-01
     5.810546875000000e-02     3.519280597469898e-01
    -6.918945312500000e-01     5.741502819692119e-01
     8.081054687500000e-01     7.963725041914342e-01
    -8.168945312500000e-01    -9.073311995122695e-01
    -3.168945312500000e-01     4.260021338210640e-01
     6.831054687500000e-01    -6.851089772900474e-01
     4.331054687500000e-01     6.482243560432859e-01
     9.331054687500000e-01     2.037799115988417e-01
    -8.793945312500000e-01     8.704465782655082e-01
     6.206054687500000e-01     5.000762078951380e-01
    -6.293945312500000e-01    -6.110349032159732e-01
     8.706054687500000e-01    -3.888126809937510e-01
    -7.543945312500000e-01     2.778539856729159e-01
     7.456054687500000e-01    -2.900472488949856e-01
     9.956054687500000e-01     5.988416399939034e-01
    -9.926757812500000e-01    -5.122694711172078e-01
     7.324218750000000e-03     1.543971955494592e-01
    -4.926757812500000e-01     8.210638622161257e-01
    -7.426757812500000e-01    -2.159731748209115e-01
     2.573242187500000e-01     4.506934918457555e-01
     7.573242187500000e-01     6.249047401310825e-03
    -8.676757812500000e-01     6.729157140679773e-01
     6.323242187500000e-01     8.951379362901997e-01
    -1.176757812500000e-01     5.247675659198294e-01
     8.823242187500000e-01    -5.863435451912820e-01
    -9.301757812500000e-01     8.032312147538478e-02
     8.198242187500000e-01     4.013107757963725e-01
    -8.051757812500000e-01    -7.098003353147386e-01
    -3.051757812500000e-01     6.235329980185946e-01
     6.948242187500000e-01    -4.875781130925164e-01
     9.448242187500000e-01    -1.912818167962201e-01
    -9.614257812500000e-01     4.753848498704467e-01
     5.385742187500000e-01     6.976070720926686e-01
    -7.114257812500000e-01    -4.135040390184423e-01
     7.885742187500000e-01    -7.838744093888127e-01
    -8.364257812500000e-01    -1.172077427221461e-01
     1.635742187500000e-01     5.494589239445207e-01
     6.635742187500000e-01     1.050144795000763e-01
    -5.864257812500000e-01     7.716811461667428e-01
    -8.642578125000000e-02     3.272367017222986e-01
    -6.489257812500000e-01    -1.062338058222833e-01
     3.510742187500000e-01     5.604328608443834e-01
     8.510742187500000e-01     1.159884163999392e-01
    -7.739257812500000e-01     7.826550830666057e-01
     7.260742187500000e-01     4.122847126962355e-01
     9.760742187500000e-01    -4.766041761926536e-01
    -9.770507812500000e-01     1.900624904740131e-01
    -7.270507812500000e-01     4.863587867703094e-01
     7.729492187500000e-01     7.085810089925315e-01
    -8.520507812500000e-01    -4.025301021185795e-01
     1.479492187500000e-01     2.641365645480873e-01
    -6.020507812500000e-01    -3.037646700198141e-01
     8.979492187500000e-01    -8.154244779759190e-02
    -9.145507812500000e-01     5.851242188690748e-01
     5.854492187500000e-01     8.073464410912972e-01
    -6.645507812500000e-01    -8.963572626124067e-01
    -1.645507812500000e-01     4.369760707209269e-01
     8.354492187500000e-01    -6.741350403901845e-01
    -7.895507812500000e-01    -7.468373723517829e-03
     7.104492187500000e-01     2.147538484987046e-01
     9.604492187500000e-01     5.110501447950009e-01
    -9.458007812500000e-01    -6.000609663161104e-01
    -4.458007812500000e-01     7.332723670172228e-01
    -6.958007812500000e-01     2.888279225727786e-01
     8.041992187500000e-01    -2.790733119951228e-01
    -8.208007812500000e-01     3.875933546715440e-01
     6.791992187500000e-01     6.098155768937661e-01
     9.291992187500000e-01    -8.716659045877153e-01
    -8.833007812500000e-01    -2.049992379210487e-01
     1.166992187500000e-01     4.616674287456182e-01
     6.166992187500000e-01     1.722298430117375e-02
    -6.333007812500000e-01     6.838896509678400e-01
    -1.333007812500000e-01     2.394452065233958e-01
     8.666992187500000e-01     9.061118731900624e-01
    -7.583007812500000e-01    -7.975918305136412e-01
    -2.583007812500000e-01     5.357415028196921e-01
     7.416992187500000e-01    -5.753696082914190e-01
     4.916992187500000e-01     7.579637250419142e-01
     9.916992187500000e-01     3.135192805974700e-01
    -9.848632812500000e-01     9.801859472641365e-01
    -7.348632812500000e-01    -7.646700198140528e-01
    -2.348632812500000e-01     5.686633135192805e-01
     7.651367187500000e-01    -5.424477975918305e-01
    -8.598632812500000e-01     1.242188690748363e-01
     6.401367187500000e-01    -2.461515012955343e-01
    -6.098632812500000e-01     4.205151653711325e-01
     8.901367187500000e-01     6.427373875933544e-01
    -9.223632812500000e-01    -4.683737235177565e-01
     7.763671875000000e-02     1.982929431489102e-01
    -6.723632812500000e-01    -1.720774272214602e-01
     3.276367187500000e-01     4.945892394452065e-01
     8.276367187500000e-01     5.014479500076208e-02
    -7.973632812500000e-01     7.168114616674286e-01
     7.026367187500000e-01     9.390336838896509e-01
    -4.736328125000000e-02     3.711324493217496e-01
     9.526367187500000e-01    -7.399786617893613e-01
    -9.536132812500000e-01    -7.331199512269482e-02
    -7.036132812500000e-01     8.155768937661942e-01
     7.963867187500000e-01     4.452065233958240e-01
    -8.286132812500000e-01    -6.659045877152874e-01
    -3.286132812500000e-01     6.674287456180459e-01
     6.713867187500000e-01    -4.436823654930652e-01
     9.213867187500000e-01    -1.473860691967689e-01
    -8.911132812500000e-01     5.192805974698980e-01
     6.088867187500000e-01     7.415028196921198e-01
    -6.411132812500000e-01    -3.696082914189911e-01
     8.588867187500000e-01    -9.375095259868922e-01
    -7.661132812500000e-01    -2.708428593202257e-01
     2.338867187500000e-01     3.958238073464411e-01
     7.338867187500000e-01    -4.862063709800346e-02
    -5.161132812500000e-01     6.180460295686632e-01
    -1.611328125000000e-02     1.736015851242190e-01
    -4.692382812500000e-01     4.698978814205153e-01
    -7.192382812500000e-01     2.545343697607083e-02
     7.807617187500000e-01     2.476756591982929e-01
    -8.442382812500000e-01     9.143423258649594e-01
     6.557617187500000e-01     5.439719554945892e-01
     9.057617187500000e-01    -3.449169333942997e-01
    -9.067382812500000e-01     3.217497332723671e-01
    -6.567382812500000e-01     3.546715439719554e-01
     8.432617187500000e-01     5.768937661941775e-01
    -7.817382812500000e-01    -5.342173449169334e-01
     7.182617187500000e-01    -9.045877152873038e-01
     9.682617187500000e-01    -1.569882639841491e-02
    -9.379882812500000e-01     6.509678402682515e-01
     5.620117187500000e-01     8.731900624904738e-01
    -6.879882812500000e-01    -8.305136412132297e-01
    -1.879882812500000e-01     5.028196921201036e-01
     8.120117187500000e-01    -6.082914189910076e-01
    -8.129882812500000e-01     5.837524767565916e-02
     6.870117187500000e-01     2.805974698978815e-01
     9.370117187500000e-01     3.793629019966467e-01
    -8.754882812500000e-01    -7.317482091144643e-01
    -3.754882812500000e-01     6.015851242188690e-01
     6.245117187500000e-01    -5.095259868922422e-01
    -6.254882812500000e-01     1.571406797744248e-01
     8.745117187500000e-01    -2.132296905959458e-01
    -7.504882812500000e-01     4.534369760707211e-01
     7.495117187500000e-01     6.756591982929430e-01
    -9.997558593750000e-01    -1.391556165218717e-01
     2.441406250000000e-04     5.275110501447950e-01
    -7.497558593750000e-01     7.497332723670169e-01
    -2.497558593750000e-01     3.052888279225727e-01
     7.502441406250000e-01     9.719554945892392e-01
    -8.747558593750000e-01    -9.292790733119951e-01
    -3.747558593750000e-01     4.040542600213382e-01
     6.252441406250000e-01    -7.070568510897730e-01
    -6.247558593750000e-01    -4.039018442310627e-02
     3.752441406250000e-01     6.262764822435603e-01
     8.752441406250000e-01     1.818320377991161e-01
    -9.372558593750000e-01     8.484987044657826e-01
     5.627441406250000e-01     4.781283340954123e-01
    -6.872558593750000e-01    -6.329827770156988e-01
     8.127441406250000e-01    -4.107605547934766e-01
    -8.122558593750000e-01     2.559061118731900e-01
     6.877441406250000e-01    -1.144642584971803e-01
    -5.622558593750000e-01     5.522024081694863e-01
     9.377441406250000e-01     7.744246303917084e-01
    -9.685058593750000e-01    -3.366864807194025e-01
     3.149414062500000e-02     3.299801859472642e-01
    -7.185058593750000e-01    -3.257125438195397e-01
     2.814941406250000e-01     3.409541228471271e-01
     7.814941406250000e-01    -1.034903215973175e-01
    -8.435058593750000e-01     5.631763450693492e-01
     6.564941406250000e-01     7.853985672915715e-01
    -9.350585937500000e-02     4.150281969212013e-01
     9.064941406250000e-01    -6.960829141899101e-01
    -9.060058593750000e-01    -2.941624752324346e-02
    -6.560058593750000e-01     8.594726413656455e-01
     8.439941406250000e-01     4.891022709952753e-01
    -7.810058593750000e-01    -6.220088401158361e-01
     7.189941406250000e-01    -3.997866178936138e-01
     9.689941406250000e-01    -3.010211857948484e-01
    -9.841308593750000e-01     3.656454808718184e-01
     5.158691406250000e-01     5.878677030940407e-01
    -7.341308593750000e-01    -5.232434080170707e-01
     7.658691406250000e-01    -8.936137783874409e-01
    -8.591308593750000e-01    -2.269471117207743e-01
     1.408691406250000e-01     4.397195549458928e-01
     6.408691406250000e-01    -4.724889498552098e-03
    -6.091308593750000e-01     6.619417771681146e-01
    -1.091308593750000e-01     2.174973327236704e-01
     8.908691406250000e-01     8.841639993903370e-01
    -9.216308593750000e-01    -8.195397043133669e-01
    -4.216308593750000e-01     5.137936290199667e-01
    -6.716308593750000e-01     6.934918457552208e-02
     8.283691406250000e-01     2.915714067977444e-01
    -7.966308593750000e-01     9.582380734644109e-01
     7.033691406250000e-01     3.903368388965098e-01
     9.533691406250000e-01    -4.985520499923792e-01
    -9.528808593750000e-01     1.681146166742877e-01
    -7.028808593750000e-01     4.644109129705840e-01
     7.971191406250000e-01     6.866331351928059e-01
    -8.278808593750000e-01    -4.244779759183052e-01
     1.721191406250000e-01     2.421886907483617e-01
     6.721191406250000e-01    -7.948483462886755e-01
     4.221191406250000e-01     5.384849870446580e-01
     9.221191406250000e-01     9.404054260021355e-02
    -8.903808593750000e-01     7.607072092668801e-01
    -1.403808593750000e-01     3.491845755220242e-01
     8.596191406250000e-01    -7.619265355890871e-01
    -7.653808593750000e-01    -9.525986892242044e-02
     2.346191406250000e-01     5.714067977442463e-01
     7.346191406250000e-01     1.269623532998021e-01
    -5.153808593750000e-01     7.936290199664686e-01
     9.846191406250000e-01     4.232586495960984e-01
    -9.919433593750000e-01    -6.878524615150130e-01
    -4.919433593750000e-01     6.454808718183203e-01
    -7.419433593750000e-01     2.010364273738761e-01
     7.580566406250000e-01    -1.693339429964945e-01
    -8.669433593750000e-01     4.973327236701723e-01
     6.330566406250000e-01     7.195549458923944e-01
    -6.169433593750000e-01    -3.915561652187167e-01
     8.830566406250000e-01    -9.594573997866179e-01
    -9.294433593750000e-01    -2.927907331199513e-01
     7.055664062500000e-02     3.738759335467154e-01
    -6.794433593750000e-01     5.960981557689378e-01
     8.205566406250000e-01     8.183203779911601e-01
    -8.044433593750000e-01    -8.853833257125439e-01
    -3.044433593750000e-01     4.479500076207898e-01
     6.955566406250000e-01    -6.631611034903216e-01
     4.455566406250000e-01     6.701722298430117e-01
     9.455566406250000e-01     2.257277853985675e-01
    -9.606933593750000e-01     8.923944520652340e-01
     5.393066406250000e-01     5.220240816948638e-01
    -7.106933593750000e-01    -5.890870294162476e-01
     7.893066406250000e-01    -3.668648071940254e-01
    -8.356933593750000e-01     2.998018594726415e-01
     6.643066406250000e-01    -2.680993750952599e-01
     9.143066406250000e-01     6.207895137936290e-01
    -8.981933593750000e-01    -4.903215973174821e-01
     1.018066406250000e-01     1.763450693491848e-01
    -6.481933593750000e-01    -1.940253010211859e-01
     3.518066406250000e-01     4.726413656454811e-01
     8.518066406250000e-01     2.819692120103667e-02
    -7.731933593750000e-01     6.948635878677030e-01
     7.268066406250000e-01     9.170858100899253e-01
     9.768066406250000e-01    -5.643956713915562e-01
    -9.763183593750000e-01     1.022709952751106e-01
     7.736816406250000e-01     3.574150281969213e-01
    -8.513183593750000e-01    -7.536960829141899e-01
    -3.513183593750000e-01     5.796372504191434e-01
     6.486816406250000e-01    -5.314738606919678e-01
    -6.013183593750000e-01     1.351928059746992e-01
     8.986816406250000e-01    -2.351775643956714e-01
    -9.138183593750000e-01     4.314891022709955e-01
     5.861816406250000e-01     6.537113244932173e-01
    -6.638183593750000e-01    -4.573997866178936e-01
     8.361816406250000e-01    -8.277701569882639e-01
    -7.888183593750000e-01    -1.611034903215973e-01
     2.111816406250000e-01     5.055631763450694e-01
     7.111816406250000e-01     6.111873190062500e-02
    -5.388183593750000e-01     7.277853985672915e-01
    -3.881835937500000e-02     2.833409541228473e-01
    -6.950683593750000e-01    -6.233805822283189e-02
     3.049316406250000e-01     6.043286084438348e-01
     8.049316406250000e-01     1.598841639993906e-01
    -8.200683593750000e-01     8.265508306660572e-01
     6.799316406250000e-01     4.561804602956869e-01
     9.299316406250000e-01    -4.327084285932022e-01
    -8.825683593750000e-01     2.339582380734646e-01
     6.174316406250000e-01    -1.364121322969060e-01
    -6.325683593750000e-01     5.302545343697609e-01
     8.674316406250000e-01     7.524767565919828e-01
    -7.575683593750000e-01    -3.586343545191282e-01
     2.424316406250000e-01     3.080323121475386e-01
     7.424316406250000e-01    -9.265355890870294e-01
     9.924316406250000e-01    -3.764670019814054e-02
    -9.958496093750000e-01     6.290199664685261e-01
     5.041503906250000e-01     8.512421886907484e-01
    -7.458496093750000e-01    -8.524615150129553e-01
    -2.458496093750000e-01     4.808718183203782e-01
     7.541503906250000e-01    -6.302392927907332e-01
    -8.708496093750000e-01     3.642737387593376e-02
     6.291503906250000e-01     2.586495960981559e-01
     8.791503906250000e-01     5.549458923944521e-01
    -9.333496093750000e-01    -5.561652187166591e-01
    -4.333496093750000e-01     7.771681146166742e-01
    -6.833496093750000e-01     3.327236701722300e-01
     8.166503906250000e-01    -3.327236701722299e-01
    -8.083496093750000e-01     3.339429964944367e-01
     6.916503906250000e-01     5.561652187166588e-01
    -9.645996093750000e-01    -2.586495960981559e-01
     3.540039062500000e-02     4.080170705685109e-01
    -7.145996093750000e-01     6.302392927907328e-01
     7.854003906250000e-01     8.524615150129551e-01
    -8.395996093750000e-01    -8.512421886907484e-01
    -3.395996093750000e-01     4.820911446425848e-01
     6.604003906250000e-01    -6.290199664685261e-01
     4.104003906250000e-01     7.043133668648069e-01
     9.104003906250000e-01     2.598689224203627e-01
    -9.020996093750000e-01     9.265355890870293e-01
     5.979003906250000e-01     3.586343545191280e-01
    -6.520996093750000e-01    -7.524767565919830e-01
     8.479003906250000e-01    -5.302545343697607e-01
    -7.770996093750000e-01     1.364121322969061e-01
     7.229003906250000e-01    -2.339582380734645e-01
     9.729003906250000e-01     6.549306508154242e-01
    -9.802246093750000e-01    -4.561804602956867e-01
     1.977539062500000e-02     2.104862063709800e-01
    -7.302246093750000e-01    -1.598841639993904e-01
     2.697753906250000e-01     5.067825026672763e-01
     7.697753906250000e-01     6.233805822283167e-02
    -8.552246093750000e-01     7.290047248894982e-01
     6.447753906250000e-01     9.512269471117205e-01
    -1.052246093750000e-01     3.833257125438194e-01
     8.947753906250000e-01    -7.277853985672915e-01
    -9.177246093750000e-01    -6.111873190062500e-02
    -6.677246093750000e-01     8.277701569882638e-01
     8.322753906250000e-01     4.573997866178936e-01
    -7.927246093750000e-01    -6.537113244932176e-01
    -2.927246093750000e-01     6.796220088401155e-01
     7.072753906250000e-01    -4.314891022709954e-01
     9.572753906250000e-01    -1.351928059746991e-01
    -9.489746093750000e-01     5.314738606919676e-01
     5.510253906250000e-01     7.536960829141897e-01
    -6.989746093750000e-01    -3.574150281969213e-01
     3.010253906250000e-01     3.092516384697455e-01
     8.010253906250000e-01    -9.911598841639994e-01
    -8.239746093750000e-01    -3.244932174973328e-01
     1.760253906250000e-01     3.421734491693338e-01
     6.760253906250000e-01    -1.022709952751106e-01
    -5.739746093750000e-01     5.643956713915559e-01
     9.260253906250000e-01     7.866178936137782e-01
    -8.864746093750000e-01    -9.170858100899253e-01
    -3.864746093750000e-01     4.162475232434080e-01
     6.135253906250000e-01    -6.948635878677031e-01
    -6.364746093750000e-01    -2.819692120103656e-02
     3.635253906250000e-01     6.384697454656298e-01
     8.635253906250000e-01     1.940253010211856e-01
    -7.614746093750000e-01     8.606919676878522e-01
     7.385253906250000e-01     4.903215973174819e-01
     9.885253906250000e-01    -3.985672915714069e-01
    -9.880371093750000e-01     2.680993750952598e-01
    -7.380371093750000e-01     3.668648071940250e-01
     7.619628906250000e-01     5.890870294162474e-01
    -8.630371093750000e-01    -5.220240816948636e-01
    -6.130371093750000e-01    -2.257277853985674e-01
     3.869628906250000e-01     4.409388812680994e-01
     8.869628906250000e-01    -3.505563176345206e-03
    -9.255371093750000e-01     6.631611034903213e-01
     5.744628906250000e-01     8.853833257125436e-01
    -6.755371093750000e-01    -8.183203779911599e-01
    -1.755371093750000e-01     5.150129553421734e-01
     8.244628906250000e-01    -5.960981557689377e-01
    -8.005371093750000e-01     7.056851089772875e-02
     6.994628906250000e-01     2.927907331199511e-01
     9.494628906250000e-01     3.915561652187165e-01
    -9.567871093750000e-01    -7.195549458923944e-01
    -4.567871093750000e-01     6.137783874409386e-01
    -7.067871093750000e-01     1.693339429964944e-01
     7.932128906250000e-01    -2.010364273738761e-01
    -8.317871093750000e-01     4.656302392927907e-01
     6.682128906250000e-01     6.878524615150126e-01
     9.182128906250000e-01    -7.936290199664685e-01
    -8.942871093750000e-01    -1.269623532998020e-01
     1.057128906250000e-01     5.397043133668646e-01
     6.057128906250000e-01     9.525986892242022e-02
    -6.442871093750000e-01     7.619265355890867e-01
    -1.442871093750000e-01     3.174820911446425e-01
     8.557128906250000e-01     9.841487578113091e-01
    -7.692871093750000e-01    -9.829294314891023e-01
    -2.692871093750000e-01     3.504039018442309e-01
     7.307128906250000e-01    -7.607072092668801e-01
     4.807128906250000e-01     5.726261240664530e-01
     9.807128906250000e-01     1.281816796220088e-01
    -9.724121093750000e-01     7.948483462886753e-01
    -7.224121093750000e-01    -6.866331351928060e-01
     7.775878906250000e-01    -4.644109129705838e-01
    -8.474121093750000e-01     2.022557536960827e-01
     6.525878906250000e-01    -1.681146166742875e-01
    -5.974121093750000e-01     4.985520499923790e-01
     9.025878906250000e-01     7.207742722146011e-01
    -9.099121093750000e-01    -3.903368388965097e-01
     9.008789062500000e-02     2.763298277701569e-01
    -6.599121093750000e-01    -2.915714067977443e-01
     3.400878906250000e-01     3.750952598689221e-01
     8.400878906250000e-01    -6.934918457552208e-02
    -7.849121093750000e-01     5.973174820911444e-01
     7.150878906250000e-01     8.195397043133668e-01
    -3.491210937500000e-02     4.491693339429965e-01
     9.650878906250000e-01    -6.619417771681146e-01
    -9.411621093750000e-01     4.724889498551876e-03
    -6.911621093750000e-01     8.936137783874407e-01
     8.088378906250000e-01     5.232434080170705e-01
    -8.161621093750000e-01    -5.878677030940406e-01
     6.838378906250000e-01    -3.656454808718184e-01
     9.338378906250000e-01    -2.668800487730529e-01
    -8.786621093750000e-01     3.997866178936136e-01
     6.213378906250000e-01     6.220088401158357e-01
    -6.286621093750000e-01    -4.891022709952751e-01
     8.713378906250000e-01    -8.594726413656455e-01
    -7.536621093750000e-01    -1.928059746989789e-01
     2.463378906250000e-01     4.738606919676878e-01
     7.463378906250000e-01     2.941624752324334e-02
    -5.036621093750000e-01     6.960829141899096e-01
    -3.662109375000000e-03     2.516384697454654e-01
    -4.978027343750000e-01     5.479347660417617e-01
    -7.478027343750000e-01     1.034903215973173e-01
     7.521972656250000e-01     3.257125438195396e-01
     6.271972656250000e-01     3.366864807194023e-01
    -6.228027343750000e-01    -7.744246303917086e-01
     8.771972656250000e-01    -5.522024081694863e-01
    -9.353027343750000e-01     1.144642584971802e-01
    -6.853027343750000e-01     4.107605547934765e-01
     8.146972656250000e-01     6.329827770156984e-01
    -8.103027343750000e-01    -4.781283340954123e-01
     6.896972656250000e-01    -8.484987044657827e-01
     4.396972656250000e-01     4.848346288675505e-01
     9.396972656250000e-01     4.039018442310605e-02
    -9.665527343750000e-01     7.070568510897726e-01
    -7.165527343750000e-01    -9.719554945892395e-01
    -2.165527343750000e-01     3.613778387440936e-01
     7.834472656250000e-01    -7.497332723670173e-01
    -8.415527343750000e-01    -8.306660570035063e-02
     1.584472656250000e-01     5.836000609663159e-01
     6.584472656250000e-01     1.391556165218717e-01
    -5.915527343750000e-01     8.058222831885382e-01
     9.084472656250000e-01     4.354519128181680e-01
    -9.040527343750000e-01    -6.756591982929432e-01
    -4.040527343750000e-01     6.576741350403899e-01
    -6.540527343750000e-01     2.132296905959457e-01
     8.459472656250000e-01    -1.571406797744247e-01
    -7.790527343750000e-01     5.095259868922419e-01
     7.209472656250000e-01     7.317482091144638e-01
    -9.821777343750000e-01    -2.805974698978815e-01
     1.782226562500000e-02     3.860691967687850e-01
    -7.321777343750000e-01     6.082914189910071e-01
     7.678222656250000e-01     8.305136412132295e-01
    -8.571777343750000e-01    -8.731900624904740e-01
    -3.571777343750000e-01     4.601432708428592e-01
     6.428222656250000e-01    -6.509678402682517e-01
    -6.071777343750000e-01     1.569882639841480e-02
     3.928222656250000e-01     6.823654930650811e-01
     8.928222656250000e-01     2.379210486206369e-01
    -9.196777343750000e-01     9.045877152873034e-01
     5.803222656250000e-01     5.342173449169332e-01
    -6.696777343750000e-01    -5.768937661941778e-01
     8.303222656250000e-01    -3.546715439719555e-01
    -7.946777343750000e-01     3.119951226947111e-01
     7.053222656250000e-01    -3.217497332723671e-01
     9.553222656250000e-01     5.671391556165215e-01
    -9.509277343750000e-01    -5.439719554945892e-01
    -4.509277343750000e-01     7.893613778387438e-01
    -7.009277343750000e-01    -2.476756591982930e-01
     2.990722656250000e-01     4.189910074683736e-01
     7.990722656250000e-01    -2.545343697607083e-02
    -8.259277343750000e-01     6.412132296905955e-01
     6.740722656250000e-01     8.634354519128178e-01
    -7.592773437500000e-02     4.930650815424475e-01
     9.240722656250000e-01    -6.180460295686633e-01
    -8.884277343750000e-01     4.862063709800313e-02
     6.115722656250000e-01     2.708428593202254e-01
     8.615722656250000e-01     3.696082914189907e-01
    -7.634277343750000e-01    -7.415028196921201e-01
    -2.634277343750000e-01     5.918305136412130e-01
     7.365722656250000e-01    -5.192805974698979e-01
     4.865722656250000e-01     8.140527358634353e-01
     9.865722656250000e-01    -2.229843011736017e-01
    -9.899902343750000e-01     4.436823654930651e-01
     5.100097656250000e-01     6.659045877152869e-01
    -7.399902343750000e-01    -4.452065233958239e-01
     7.600097656250000e-01    -8.155768937661942e-01
    -8.649902343750000e-01    -1.489102270995276e-01
     1.350097656250000e-01     5.177564395671390e-01
     6.350097656250000e-01     7.331199512269437e-02
    -6.149902343750000e-01     7.399786617893609e-01
    -1.149902343750000e-01     2.955342173449167e-01
     8.850097656250000e-01     9.622008840115832e-01
    -9.274902343750000e-01    -9.390336838896509e-01
    -6.774902343750000e-01    -5.014479500076219e-02
     3.225097656250000e-01     6.165218716659042e-01
     8.225097656250000e-01     1.720774272214600e-01
    -8.024902343750000e-01     8.387440938881265e-01
     6.975097656250000e-01     4.683737235177563e-01
     9.475097656250000e-01    -4.205151653711325e-01
    -9.587402343750000e-01     2.461515012955340e-01
    -7.087402343750000e-01     5.424477975918303e-01
     7.912597656250000e-01     7.646700198140524e-01
    -8.337402343750000e-01    -3.464410912970585e-01
     1.662597656250000e-01     3.202255753696082e-01
     9.162597656250000e-01    -9.129705837524771e-02
    -8.962402343750000e-01     5.753696082914186e-01
     6.037597656250000e-01     7.975918305136409e-01
    -1.462402343750000e-01     4.272214601432707e-01
     8.537597656250000e-01    -6.838896509678403e-01
    -7.712402343750000e-01    -1.722298430117364e-02
     7.287597656250000e-01     2.049992379210483e-01
     9.787597656250000e-01     5.012955342173446e-01
    -9.743652343750000e-01    -6.098155768937662e-01
    -4.743652343750000e-01     7.235177564395667e-01
    -7.243652343750000e-01     2.790733119951225e-01
     7.756347656250000e-01    -2.888279225727786e-01
    -8.493652343750000e-01     3.778387440938877e-01
     6.506347656250000e-01     6.000609663161101e-01
     9.006347656250000e-01    -8.814205151653711e-01
    -9.118652343750000e-01    -2.147538484987045e-01
     8.813476562500000e-02     4.519128181679621e-01
    -6.618652343750000e-01     6.741350403901840e-01
    -1.618652343750000e-01     2.296905959457398e-01
     8.381347656250000e-01     8.963572626124063e-01
    -7.868652343750000e-01    -8.073464410912971e-01
    -2.868652343750000e-01     5.259868922420361e-01
     7.131347656250000e-01    -5.851242188690748e-01
     4.631347656250000e-01     7.482091144642580e-01
     9.631347656250000e-01     3.037646700198138e-01
    -9.431152343750000e-01     9.704313366864803e-01
    -6.931152343750000e-01    -7.085810089925316e-01
     8.068847656250000e-01    -4.863587867703094e-01
    -8.181152343750000e-01     1.803078798963571e-01
     6.818847656250000e-01    -1.900624904740131e-01
    -5.681152343750000e-01     4.766041761926534e-01
     9.318847656250000e-01     6.988263984148753e-01
    -8.806152343750000e-01    -4.122847126962353e-01
     1.193847656250000e-01     2.543819539704311e-01
    -6.306152343750000e-01    -1.159884163999391e-01
     3.693847656250000e-01     5.506782502667273e-01
     8.693847656250000e-01     1.062338058222829e-01
    -7.556152343750000e-01     7.729004724889494e-01
    -2.556152343750000e-01     3.284560280445052e-01
    -5.615234375000000e-03     3.394299649443682e-01
    -9.938964843750000e-01    -1.050144795000763e-01
    -7.438964843750000e-01     7.838744093888126e-01
     7.561035156250000e-01     4.135040390184423e-01
    -8.688964843750000e-01    -6.976070720926688e-01
    -3.688964843750000e-01     6.357262612406642e-01
     6.311035156250000e-01    -4.753848498704466e-01
    -6.188964843750000e-01     1.912818167962200e-01
     8.811035156250000e-01    -1.790885535741503e-01
    -9.313964843750000e-01     4.875781130925163e-01
     5.686035156250000e-01     7.098003353147384e-01
    -6.813964843750000e-01    -4.013107757963725e-01
     8.186035156250000e-01    -9.692120103642737e-01
    -8.063964843750000e-01    -3.025453436976071e-01
     1.936035156250000e-01     3.641213229690594e-01
     6.936035156250000e-01    -8.032312147538490e-02
    -5.563964843750000e-01     5.863435451912817e-01
     9.436035156250000e-01     8.085657674135041e-01
    -4.626464843750000e-01     4.381953970431338e-01
    -7.126464843750000e-01    -6.249047401310825e-03
     2.873535156250000e-01     6.604176192653557e-01
     7.873535156250000e-01     2.159731748209115e-01
    -8.376464843750000e-01     8.826398414875780e-01
     6.623535156250000e-01     5.122694711172078e-01
     9.123535156250000e-01    -3.766194177716812e-01
    -9.001464843750000e-01     2.900472488949855e-01
    -6.501464843750000e-01     3.888126809937509e-01
     8.498535156250000e-01     6.110349032159730e-01
    -7.751464843750000e-01    -5.000762078951380e-01
     7.248535156250000e-01    -8.704465782655083e-01
     4.748535156250000e-01     4.628867550678251e-01
     9.748535156250000e-01     1.844231062338064e-02
    -9.782714843750000e-01     6.851089772900469e-01
    -7.282714843750000e-01    -7.963725041914342e-01
    -2.282714843750000e-01     5.369608291418990e-01
     7.717285156250000e-01    -5.741502819692120e-01
    -8.532714843750000e-01     9.251638469745460e-02
     6.467285156250000e-01     3.147386069196769e-01
     8.967285156250000e-01     3.476604176192652e-01
    -9.157714843750000e-01    -7.634506934918458e-01
    -4.157714843750000e-01     5.698826398414873e-01
    -6.657714843750000e-01     1.254381953970432e-01
     8.342285156250000e-01    -2.449321749733273e-01
    -7.907714843750000e-01     4.217344916933394e-01
     7.092285156250000e-01     6.439567139155613e-01
     9.592285156250000e-01    -8.375247675659199e-01
    -9.470214843750000e-01    -1.708581008992532e-01
     5.297851562500000e-02     4.958085657674134e-01
    -6.970214843750000e-01     7.180307879896355e-01
    -1.970214843750000e-01     2.735863435451913e-01
     8.029785156250000e-01     9.402530102118578e-01
    -8.220214843750000e-01    -9.609815576893767e-01
    -3.220214843750000e-01     3.723517756439565e-01
     6.779785156250000e-01    -7.387593354671544e-01
     4.279785156250000e-01     5.945739978661788e-01
     9.279785156250000e-01     1.501295534217346e-01
    -8.845214843750000e-01     8.167962200884011e-01
     6.154785156250000e-01     4.464258497180309e-01
    -6.345214843750000e-01    -6.646852613930803e-01
     8.654785156250000e-01    -4.424630391708582e-01
    -7.595214843750000e-01     2.242036274958086e-01
     7.404785156250000e-01    -1.461667428745619e-01
    -5.095214843750000e-01     5.204999237921049e-01
    -9.860839843750000e-01    -3.683889650967841e-01
     1.391601562500000e-02     2.982777015698825e-01
    -7.360839843750000e-01    -2.696235329980187e-01
     2.639160156250000e-01     3.970431336686480e-01
     7.639160156250000e-01    -4.740131077579646e-02
    -8.610839843750000e-01     6.192653558908701e-01
     6.389160156250000e-01     8.414875781130924e-01
    -1.110839843750000e-01     4.711172077427221e-01
     8.889160156250000e-01    -6.399939033683890e-01
    -9.235839843750000e-01     2.667276329827772e-02
    -6.735839843750000e-01     9.155616521871663e-01
     8.264160156250000e-01     5.451912818167961e-01
    -7.985839843750000e-01    -5.659198292943148e-01
     7.014160156250000e-01    -3.436976070720927e-01
     9.514160156250000e-01    -3.107757963725042e-01
    -9.548339843750000e-01     3.558908702941623e-01
     5.451660156250000e-01     5.781130925163844e-01
    -7.048339843750000e-01    -5.329980185947265e-01
     7.951660156250000e-01    -9.033683889650967e-01
    -8.298339843750000e-01    -2.367017222984301e-01
     1.701660156250000e-01     4.299649443682365e-01
     6.701660156250000e-01    -1.447950007620791e-02
    -5.798339843750000e-01     6.521871665904584e-01
    -7.983398437500000e-02     2.077427221460142e-01
     9.201660156250000e-01     8.744093888126807e-01
    -8.923339843750000e-01    -8.292943148910227e-01
    -3.923339843750000e-01     5.040390184423105e-01
     6.076660156250000e-01    -6.070720926688005e-01
    -6.423339843750000e-01     5.959457399786605e-02
     3.576660156250000e-01     7.262612406645326e-01
     8.576660156250000e-01     2.818167962200884e-01
    -7.673339843750000e-01     9.484834628867549e-01
     7.326660156250000e-01     3.805822283188536e-01
     9.826660156250000e-01    -5.083066605700350e-01
    -9.704589843750000e-01     1.583600060966317e-01
    -7.204589843750000e-01     4.546563023929280e-01
     7.795410156250000e-01     6.768785246151499e-01
    -8.454589843750000e-01    -4.342325864959610e-01
     1.545410156250000e-01     2.324340801707057e-01
     6.545410156250000e-01    -8.046029568663313e-01
     4.045410156250000e-01     5.287303764670019e-01
     9.045410156250000e-01     8.428593202255730e-02
    -9.079589843750000e-01     7.509525986892238e-01
    -1.579589843750000e-01     4.052735863435450e-01
     8.420410156250000e-01    -7.058375247675659e-01
    -7.829589843750000e-01    -3.917085810089926e-02
     7.170410156250000e-01     1.830513641213229e-01
    -5.329589843750000e-01     8.497180307879895e-01
     9.670410156250000e-01     4.793476604176192e-01
    -9.392089843750000e-01    -6.317634506934919e-01
    -4.392089843750000e-01     7.015698826398411e-01
    -6.892089843750000e-01     2.571254381953969e-01
     8.107910156250000e-01    -1.132449321749733e-01
    -8.142089843750000e-01     5.534217344916932e-01
     6.857910156250000e-01     7.756439567139153e-01
    -8.767089843750000e-01    -3.318091754305746e-01
     1.232910156250000e-01     3.348574912360920e-01
     6.232910156250000e-01    -1.095869532083524e-01
    -6.267089843750000e-01     5.570797134583141e-01
     8.732910156250000e-01     7.793019356805364e-01
    -7.517089843750000e-01    -9.244017680231672e-01
    -2.517089843750000e-01     4.089315653101662e-01
     7.482910156250000e-01    -7.021795458009450e-01
     4.982910156250000e-01     6.311537875323880e-01
     9.982910156250000e-01     1.867093430879438e-01
    -9.987792968750000e-01     8.533760097546104e-01
     5.012207031250000e-01     4.830056393842401e-01
    -7.487792968750000e-01    -6.281054717268709e-01
     7.512207031250000e-01    -4.058832495046487e-01
    -8.737792968750000e-01     2.607834171620180e-01
     6.262207031250000e-01    -3.071178174058833e-01
    -6.237792968750000e-01     3.595488492607832e-01
     8.762207031250000e-01     5.817710714830056e-01
    -9.362792968750000e-01    -5.293400396281055e-01
    -4.362792968750000e-01     8.039932937052279e-01
    -6.862792968750000e-01    -2.330437433318092e-01
     3.137207031250000e-01     4.336229233348576e-01
     8.137207031250000e-01    -1.082152110958701e-02
    -8.112792968750000e-01     6.558451455570795e-01
     6.887207031250000e-01     8.780673677793018e-01
    -6.127929687500000e-02     5.076969974089316e-01
     9.387207031250000e-01    -6.034141137021796e-01
    -9.675292968750000e-01     6.325255296448695e-02
    -7.175292968750000e-01     9.521414418533758e-01
     7.824707031250000e-01     3.842402072854747e-01
    -8.425292968750000e-01    -7.268709038256363e-01
    -3.425292968750000e-01     6.064624295076968e-01
     6.574707031250000e-01    -5.046486816034141e-01
     9.074707031250000e-01    -2.083523853071179e-01
    -9.050292968750000e-01     4.583142813595489e-01
     5.949707031250000e-01     6.805365035817708e-01
    -6.550292968750000e-01    -4.305746075293401e-01
     8.449707031250000e-01    -8.009449778997104e-01
    -7.800292968750000e-01    -1.342783112330438e-01
     2.199707031250000e-01     5.323883554336228e-01
     7.199707031250000e-01     8.794391098917842e-02
    -5.300292968750000e-01     7.546105776558449e-01
    -3.002929687500000e-02     3.101661332114007e-01
    -7.331542968750000e-01    -1.013565005334554e-01
     2.668457031250000e-01     5.653101661332112e-01
     7.668457031250000e-01     1.208657216887670e-01
    -8.581542968750000e-01     7.875323883554335e-01
     6.418457031250000e-01     4.171620179850632e-01
     8.918457031250000e-01    -4.717268709038257e-01
    -9.206542968750000e-01     1.949397957628409e-01
    -6.706542968750000e-01     4.912360920591372e-01
     8.293457031250000e-01     7.134583142813593e-01
    -7.956542968750000e-01    -3.976527968297516e-01
     2.043457031250000e-01     2.690138698369151e-01
     9.543457031250000e-01    -7.666514250876399e-02
    -9.519042968750000e-01     5.900015241579026e-01
     5.480957031250000e-01     8.122237463801250e-01
    -7.019042968750000e-01    -8.914799573235788e-01
    -2.019042968750000e-01     4.418533760097547e-01
     7.980957031250000e-01    -6.692577351013564e-01
    -8.269042968750000e-01    -2.591068434689925e-03
     6.730957031250000e-01     2.196311537875324e-01
    -5.769042968750000e-01     8.862978204541989e-01
     9.230957031250000e-01     5.159274500838287e-01
    -8.894042968750000e-01    -5.951836610272825e-01
    -3.894042968750000e-01     7.381496723060506e-01
     6.105957031250000e-01    -3.729614388050603e-01
    -6.394042968750000e-01     2.937052278616064e-01
     8.605957031250000e-01    -2.741960067062948e-01
    -7.644042968750000e-01     3.924706599603718e-01
     7.355957031250000e-01     6.146928821825939e-01
    -9.909667968750000e-01    -2.001219326322208e-01
     9.033203125000000e-03     4.665447340344460e-01
    -7.409667968750000e-01     6.887669562566678e-01
     7.590332031250000e-01     9.109891784788902e-01
    -8.659667968750000e-01    -7.927145252248133e-01
    -3.659667968750000e-01     5.406188081085199e-01
     6.340332031250000e-01    -5.704923030025910e-01
    -6.159667968750000e-01     9.617436366407550e-02
     3.840332031250000e-01     7.628410303307420e-01
     8.840332031250000e-01     3.183965858862978e-01
    -9.284667968750000e-01     9.850632525529643e-01
    -6.784667968750000e-01    -7.597927145252248e-01
    -1.784667968750000e-01     5.735406188081082e-01
     8.215332031250000e-01    -5.375704923030027e-01
    -8.034667968750000e-01     1.290961743636641e-01
     6.965332031250000e-01    -2.412741960067063e-01
     9.465332031250000e-01     6.476146928821822e-01
    -9.597167968750000e-01    -4.634964182289285e-01
     4.028320312500000e-02     2.031702484377380e-01
    -7.097167968750000e-01    -1.672001219326322e-01
     2.902832031250000e-01     4.994665447340343e-01
     7.902832031250000e-01     5.502210028958987e-02
    -8.347167968750000e-01     7.216887669562564e-01
     6.652832031250000e-01     9.439109891784787e-01
    -8.471679687500000e-02     3.760097546105774e-01
     9.152832031250000e-01    -7.351013565005335e-01
    -8.972167968750000e-01    -6.843468983386680e-02
     6.027832031250000e-01     1.537875323883555e-01
    -6.472167968750000e-01     8.204541990550220e-01
     8.527832031250000e-01     4.500838286846518e-01
    -7.722167968750000e-01    -6.610272824264594e-01
     7.277832031250000e-01    -4.388050602042372e-01
     9.777832031250000e-01    -1.425087639079409e-01
    -9.753417968750000e-01     5.241579027587258e-01
     5.246582031250000e-01     7.463801249809476e-01
    -7.253417968750000e-01    -3.647309861301631e-01
     2.746582031250000e-01     3.019356805365034e-01
     7.746582031250000e-01    -9.326322206980643e-01
    -8.503417968750000e-01    -2.659655540313977e-01
     1.496582031250000e-01     4.007011126352689e-01
     6.496582031250000e-01    -4.374333180917545e-02
    -6.003417968750000e-01     6.229233348574910e-01
    -1.003417968750000e-01     1.784788904130468e-01
     8.996582031250000e-01     8.451455570797133e-01
    -9.128417968750000e-01    -8.585581466239902e-01
    -4.128417968750000e-01     4.747751867093430e-01
    -6.628417968750000e-01     3.033074226489862e-02
     3.371582031250000e-01     6.969974089315649e-01
     8.371582031250000e-01     2.525529644871207e-01
    -7.878417968750000e-01     9.192196311537872e-01
     7.121582031250000e-01     5.488492607834170e-01
     9.621582031250000e-01    -3.400396281054717e-01
    -9.440917968750000e-01     3.266270385611949e-01
    -6.940917968750000e-01     3.376009754610576e-01
     8.059082031250000e-01     5.598231976832797e-01
    -8.190917968750000e-01    -5.512879134278311e-01
     6.809082031250000e-01    -9.216582837982015e-01
     9.309082031250000e-01    -3.276939490931263e-02
    -8.815917968750000e-01     6.338972717573537e-01
     6.184082031250000e-01     8.561194939795760e-01
    -1.315917968750000e-01     4.857491236092057e-01
     8.684082031250000e-01    -6.253619875019052e-01
    -7.565917968750000e-01     4.130467916476133e-02
     7.434082031250000e-01     2.635269013869836e-01
     9.934082031250000e-01     3.622923334857489e-01
    -4.948730468750000e-01     5.845145557079712e-01
    -7.448730468750000e-01     1.400701112635270e-01
     7.551269531250000e-01    -2.303002591068435e-01
    -8.698730468750000e-01     4.363664075598233e-01
     6.301269531250000e-01     6.585886297820451e-01
    -6.198730468750000e-01    -4.525224813290657e-01
     8.801269531250000e-01    -8.228928516994360e-01
    -9.323730468750000e-01    -1.562261850327694e-01
     6.762695312500000e-02     5.104404816338972e-01
    -6.823730468750000e-01     7.326627038561191e-01
    -1.823730468750000e-01     2.882182594116749e-01
     8.176269531250000e-01     9.548849260783414e-01
    -8.073730468750000e-01    -9.463496418228928e-01
    -3.073730468750000e-01     3.869836915104403e-01
     6.926269531250000e-01    -7.241274196006706e-01
     4.426269531250000e-01     6.092059137326624e-01
     9.426269531250000e-01     1.647614692882182e-01
    -9.636230468750000e-01     8.314281359548847e-01
     5.363769531250000e-01     4.610577655845145e-01
    -7.136230468750000e-01    -6.500533455265965e-01
     7.863769531250000e-01    -4.278311233043743e-01
    -8.386230468750000e-01     2.388355433622922e-01
     6.613769531250000e-01    -1.315348270080781e-01
    -5.886230468750000e-01     5.351318396585885e-01
     9.113769531250000e-01     7.573540618808106e-01
    -9.011230468750000e-01    -3.537570492303003e-01
     9.887695312500000e-02     3.129096174363664e-01
    -6.511230468750000e-01    -3.208352385307118e-01
     8.488769531250000e-01    -9.861301630848962e-02
    -7.761230468750000e-01     5.680536503581768e-01
     7.238769531250000e-01     7.902758725803991e-01
    -2.612304687500000e-02     4.199055022100289e-01
     9.738769531250000e-01    -6.912056089010821e-01
    -9.792480468750000e-01    -2.453894223441555e-02
    -7.292480468750000e-01     8.643499466544731e-01
     7.707519531250000e-01     4.939795762841028e-01
    -8.542480468750000e-01    -6.171315348270081e-01
    -3.542480468750000e-01     7.162017985063249e-01
     6.457519531250000e-01    -3.949093126047859e-01
    -6.042480468750000e-01     2.717573540618807e-01
     8.957519531250000e-01    -2.961438805060205e-01
    -9.167480468750000e-01     3.705227861606459e-01
     5.832519531250000e-01     5.927450083828683e-01
    -6.667480468750000e-01    -5.183661027282427e-01
     8.332519531250000e-01    -8.887364730986130e-01
    -7.917480468750000e-01    -2.220698064319464e-01
     2.082519531250000e-01     4.445968602347203e-01
     7.082519531250000e-01     1.524157902759171e-04
    -5.417480468750000e-01     6.668190824569422e-01
    -4.174804687500000e-02     2.223746380124980e-01
    -9.479980468750000e-01    -8.146623990245390e-01
    -4.479980468750000e-01     5.186709343087943e-01
    -6.979980468750000e-01     7.422648986434965e-02
     8.020019531250000e-01     2.964487120865720e-01
    -8.229980468750000e-01     9.631153787532385e-01
     6.770019531250000e-01     3.952141441853374e-01
     9.270019531250000e-01    -4.936747447035513e-01
    -8.854980468750000e-01     1.729919219631153e-01
     6.145019531250000e-01    -1.973784484072550e-01
    -6.354980468750000e-01     4.692882182594116e-01
     8.645019531250000e-01     6.915104404816335e-01
    -7.604980468750000e-01    -4.196006706294773e-01
     2.395019531250000e-01     2.470659960371893e-01
     7.395019531250000e-01    -7.899710409998476e-01
     4.895019531250000e-01     5.433622923334855e-01
     9.895019531250000e-01     9.891784788904112e-02
    -9.870605468750000e-01     7.655845145557076e-01
    -7.370605468750000e-01    -9.792714525224814e-01
    -2.370605468750000e-01     3.540618808108518e-01
     7.629394531250000e-01    -7.570492303002592e-01
    -8.620605468750000e-01    -9.038256363359243e-02
     6.379394531250000e-01     1.318396585886297e-01
    -6.120605468750000e-01     7.985063252552962e-01
     8.879394531250000e-01     4.281359548849260e-01
    -9.245605468750000e-01    -6.829751562261850e-01
    -4.245605468750000e-01     6.503581771071478e-01
    -6.745605468750000e-01     2.059137326627036e-01
     8.254394531250000e-01    -1.644566377076665e-01
    -7.995605468750000e-01     5.022100289589999e-01
     7.004394531250000e-01     7.244322511812220e-01
    -9.558105468750000e-01    -2.879134278311233e-01
     4.418945312500000e-02     3.787532388355430e-01
    -7.058105468750000e-01     6.009754610577653e-01
     7.941894531250000e-01     8.231976832799877e-01
    -8.308105468750000e-01    -8.805060204237158e-01
    -3.308105468750000e-01     4.528273129096174e-01
     6.691894531250000e-01    -6.582837982014937e-01
     4.191894531250000e-01     6.750495351318393e-01
     9.191894531250000e-01     2.306050906873951e-01
    -8.933105468750000e-01     8.972717573540616e-01
     6.066894531250000e-01     5.269013869836914e-01
    -6.433105468750000e-01    -5.842097241274196e-01
     8.566894531250000e-01    -3.619875019051974e-01
    -7.683105468750000e-01     3.046791647614691e-01
     7.316894531250000e-01    -2.632220698064319e-01
     9.816894531250000e-01     6.256668190824566e-01
    -9.714355468750000e-01    -4.854442920286541e-01
     2.856445312500000e-02     1.812223746380124e-01
    -7.214355468750000e-01    -1.891479957323579e-01
     2.785644531250000e-01     4.775186709343087e-01
     7.785644531250000e-01     3.307422648986424e-02
    -8.464355468750000e-01     6.997408931565305e-01
     6.535644531250000e-01     9.219631153787529e-01
     9.035644531250000e-01    -5.595183661027283e-01
    -9.089355468750000e-01     1.071483005639382e-01
     8.410644531250000e-01     3.403444596860234e-01
    -7.839355468750000e-01    -7.707666514250877e-01
    -2.839355468750000e-01     5.625666819082455e-01
     7.160644531250000e-01    -5.485444292028654e-01
     4.660644531250000e-01     7.847889041304679e-01
     9.660644531250000e-01    -2.522481329065691e-01
    -9.401855468750000e-01     4.144185337600976e-01
     5.598144531250000e-01     6.366407559823195e-01
    -6.901855468750000e-01    -4.744703551287913e-01
     8.098144531250000e-01    -8.448407254991617e-01
    -8.151855468750000e-01    -1.781740588324950e-01
     1.848144531250000e-01     4.884926078341716e-01
     6.848144531250000e-01     4.404816338972717e-02
    -5.651855468750000e-01     7.107148300563937e-01
    -6.518554687500000e-02     2.662703856119495e-01
    -8.776855468750000e-01    -9.682975156226185e-01
     6.223144531250000e-01    -7.460752934003962e-01
    -6.276855468750000e-01    -7.940862673372961e-02
     3.723144531250000e-01     5.872580399329370e-01
     8.723144531250000e-01     1.428135954884928e-01
    -7.526855468750000e-01     8.094802621551593e-01
     7.473144531250000e-01     4.391098917847891e-01
     9.973144531250000e-01    -4.497789971041000e-01
    -9.968261718750000e-01     2.168876695625668e-01
    -7.468261718750000e-01     5.131839658588631e-01
     7.531738281250000e-01     7.354061880810849e-01
    -8.718261718750000e-01    -3.757049230300259e-01
     1.281738281250000e-01     2.909617436366407e-01
    -6.218261718750000e-01    -2.769394909312605e-01
     3.781738281250000e-01     3.897271757354062e-01
     8.781738281250000e-01    -5.471726870903826e-02
    -9.343261718750000e-01     6.119493979576283e-01
     5.656738281250000e-01     8.341716201798506e-01
    -6.843261718750000e-01    -8.695320835238531e-01
    -1.843261718750000e-01     4.638012498094803e-01
     8.156738281250000e-01    -6.473098613016308e-01
    -8.093261718750000e-01     1.935680536503592e-02
     6.906738281250000e-01     2.415790275872580e-01
     9.406738281250000e-01     5.378753238835543e-01
    -9.655761718750000e-01    -5.732357872275569e-01
    -4.655761718750000e-01     7.600975461057764e-01
    -7.155761718750000e-01     3.156531016613322e-01
     7.844238281250000e-01    -3.180917543057461e-01
    -8.405761718750000e-01     3.485749123609205e-01
     6.594238281250000e-01     5.707971345831426e-01
     9.094238281250000e-01    -9.106843468983387e-01
    -9.030761718750000e-01    -2.440176802316720e-01
     9.692382812500000e-02     4.226489864349947e-01
    -6.530761718750000e-01     6.448712086572166e-01
    -1.530761718750000e-01     2.004267642127724e-01
     8.469238281250000e-01     8.670934308794389e-01
    -7.780761718750000e-01    -8.366102728242646e-01
    -2.780761718750000e-01     4.967230605090687e-01
     7.219238281250000e-01    -6.143880506020424e-01
     4.719238281250000e-01     7.189452827312908e-01
     9.719238281250000e-01     2.745008382868466e-01
    -9.812011718750000e-01     9.411675049535131e-01
    -7.312011718750000e-01    -7.378448407254992e-01
    -2.312011718750000e-01     5.954884926078341e-01
     7.687988281250000e-01    -5.156226185032770e-01
    -8.562011718750000e-01     1.510440481633899e-01
     6.437988281250000e-01    -2.193263222069807e-01
    -6.062011718750000e-01     4.473403444596862e-01
     8.937988281250000e-01     6.695625666819081e-01
    -9.187011718750000e-01    -4.415485444292029e-01
     8.129882812500000e-02     2.251181222374639e-01
    -6.687011718750000e-01    -1.452522481329066e-01
     3.312988281250000e-01     5.214144185337601e-01
     8.312988281250000e-01     7.696997408931550e-02
    -7.937011718750000e-01     7.436366407559820e-01
    -2.937011718750000e-01     2.991921963115378e-01
     7.062988281250000e-01     9.658588629782043e-01
    -4.370117187500000e-02     3.979576284103032e-01
     9.562988281250000e-01    -7.131534827008078e-01
    -9.499511718750000e-01    -4.648681603414118e-02
    -6.999511718750000e-01     8.424020728547477e-01
     8.000488281250000e-01     4.720317024843774e-01
    -8.249511718750000e-01    -6.390794086267337e-01
    -3.249511718750000e-01     6.942539247065993e-01
     6.750488281250000e-01    -4.168571864045115e-01
     9.250488281250000e-01    -1.205608901082152e-01
    -8.874511718750000e-01     5.461057765584514e-01
     6.125488281250000e-01     7.683279987806735e-01
    -6.374511718750000e-01    -3.427831123304375e-01
     8.625488281250000e-01    -9.765279682975156e-01
    -7.624511718750000e-01    -3.098613016308489e-01
     2.375488281250000e-01     3.568053650358176e-01
     7.375488281250000e-01    -8.763907940862670e-02
    -5.124511718750000e-01     5.790275872580397e-01
    -7.390136718750000e-01    -1.356500533455263e-02
     2.609863281250000e-01     6.531016613321137e-01
     7.609863281250000e-01     2.086572168876695e-01
    -8.640136718750000e-01     8.753238835543360e-01
     6.359863281250000e-01     5.049535131839658e-01
    -6.140136718750000e-01    -6.061575979271453e-01
     8.859863281250000e-01    -3.839353757049230e-01
    -9.265136718750000e-01     2.827312909617437e-01
    -6.765136718750000e-01     3.814967230605089e-01
     8.234863281250000e-01     6.037189452827312e-01
    -8.015136718750000e-01    -5.073921658283799e-01
     6.984863281250000e-01    -8.777625361987502e-01
     4.484863281250000e-01     4.555707971345833e-01
     9.484863281250000e-01     1.112635269013862e-02
    -9.577636718750000e-01     6.777930193568051e-01
     5.422363281250000e-01     9.000152415790275e-01
    -7.077636718750000e-01    -8.036884621246762e-01
    -2.077636718750000e-01     5.296448712086572e-01
     7.922363281250000e-01    -5.814662399024539e-01
    -8.327636718750000e-01     8.520042676421258e-02
     6.672363281250000e-01     3.074226489864349e-01
     9.172363281250000e-01     4.061880810852003e-01
    -8.952636718750000e-01    -7.049230300259107e-01
    -3.952636718750000e-01     6.284103033074224e-01
     6.047363281250000e-01    -4.827008078036884e-01
    -6.452636718750000e-01     1.839658588629782e-01
     8.547363281250000e-01    -1.864045115073921e-01
    -7.702636718750000e-01     4.802621551592745e-01
     7.297363281250000e-01     7.024843773814964e-01
    -9.733886718750000e-01    -1.123304374333181e-01
    -7.233886718750000e-01     7.765584514555706e-01
    -2.233886718750000e-01     3.321140070111264e-01
     7.766113281250000e-01     9.987806736777929e-01
     6.516113281250000e-01    -7.753391251333638e-01
     4.016113281250000e-01     5.579942081999694e-01
     9.016113281250000e-01     1.135497637555252e-01
    -9.108886718750000e-01     7.802164304221917e-01
     5.891113281250000e-01     4.098460600518214e-01
    -6.608886718750000e-01    -7.012650510592897e-01
     8.391113281250000e-01    -4.790428288370676e-01
    -7.858886718750000e-01     1.876238378295991e-01
     7.141113281250000e-01    -1.827465325407713e-01
    -5.358886718750000e-01     4.839201341258954e-01
     9.641113281250000e-01     7.061423563481175e-01
    -9.421386718750000e-01    -4.049687547629935e-01
     5.786132812500000e-02     2.616979119036733e-01
    -6.921386718750000e-01    -3.062033226642281e-01
     3.078613281250000e-01     3.604633440024385e-01
     8.078613281250000e-01    -8.398110044200591e-02
    -8.171386718750000e-01     5.826855662246608e-01
     6.828613281250000e-01     8.049077884468832e-01
    -6.713867187500000e-02     4.345374180765129e-01
     9.328613281250000e-01    -6.765736930345985e-01
    -8.796386718750000e-01    -9.907026367931837e-03
     6.203613281250000e-01     2.123151958542906e-01
    -6.296386718750000e-01     8.789818625209571e-01
     8.703613281250000e-01     5.086114921505869e-01
    -7.546386718750000e-01    -6.024996189605243e-01
     7.453613281250000e-01    -3.802773967383022e-01
     9.953613281250000e-01    -2.815119646395368e-01
    -9.929199218750000e-01     3.851547020271300e-01
     5.070800781250000e-01     6.073769242493521e-01
    -7.429199218750000e-01    -5.037341868617589e-01
     7.570800781250000e-01    -8.741045572321292e-01
    -8.679199218750000e-01    -2.074378905654627e-01
     1.320800781250000e-01     4.592287761012042e-01
     6.320800781250000e-01     1.478433165675974e-02
    -6.179199218750000e-01     6.814509983234260e-01
    -1.179199218750000e-01     2.370065538789818e-01
     8.820800781250000e-01     9.036732205456484e-01
    -9.304199218750000e-01    -8.000304831580551e-01
    -4.304199218750000e-01     5.333028501752781e-01
    -6.804199218750000e-01     8.885840573083370e-02
     8.195800781250000e-01     3.110806279530560e-01
     6.945800781250000e-01     3.440024386526443e-01
     9.445800781250000e-01    -5.448864502362445e-01
    -9.616699218750000e-01     1.217802164304223e-01
    -7.116699218750000e-01     4.180765127267185e-01
     7.883300781250000e-01     6.402987349489404e-01
    -8.366699218750000e-01    -4.708123761621705e-01
     1.633300781250000e-01     1.958542905044962e-01
     6.633300781250000e-01    -8.411827465325408e-01
     4.133300781250000e-01     4.921505868007925e-01
     9.133300781250000e-01     4.770614235634807e-02
    -8.991699218750000e-01     7.143728090230146e-01
     6.008300781250000e-01     9.365950312452369e-01
    -1.491699218750000e-01     3.686937966773356e-01
     8.508300781250000e-01    -7.424173144337753e-01
    -7.741699218750000e-01    -7.575064776710883e-02
     2.258300781250000e-01     5.909160188995579e-01
     7.258300781250000e-01     1.464715744551137e-01
    -5.241699218750000e-01     8.131382411217802e-01
     9.758300781250000e-01     4.427678707514100e-01
    -9.772949218750000e-01    -6.683432403597013e-01
    -4.772949218750000e-01     6.649900929736319e-01
    -7.272949218750000e-01     2.205456485291877e-01
     7.727050781250000e-01    -1.498247218411829e-01
    -8.522949218750000e-01     5.168419448254840e-01
     6.477050781250000e-01     7.390641670477058e-01
    -6.022949218750000e-01    -3.720469440634051e-01
     8.977050781250000e-01    -9.399481786313062e-01
    -9.147949218750000e-01    -2.732815119646397e-01
     8.520507812500000e-02     3.933851547020271e-01
    -6.647949218750000e-01     6.156073769242492e-01
     8.352050781250000e-01     8.378295991464715e-01
    -7.897949218750000e-01    -8.658741045572321e-01
    -2.897949218750000e-01     4.674592287761012e-01
     7.102050781250000e-01    -6.436518823350099e-01
     4.602050781250000e-01     6.896814509983231e-01
     9.602050781250000e-01     2.452370065538789e-01
    -9.460449218750000e-01     9.119036732205454e-01
     5.539550781250000e-01     5.415333028501752e-01
    -6.960449218750000e-01    -5.695778082609358e-01
     8.039550781250000e-01    -3.473555860387137e-01
    -8.210449218750000e-01     3.193110806279531e-01
     6.789550781250000e-01    -3.144337753391252e-01
     9.289550781250000e-01     5.744551135497635e-01
    -8.835449218750000e-01    -5.366559975613474e-01
    -6.335449218750000e-01    -2.403597012650511e-01
     3.664550781250000e-01     4.263069654016156e-01
     8.664550781250000e-01    -1.813747904282892e-02
    -7.585449218750000e-01     6.485291876238375e-01
     7.414550781250000e-01     8.707514098460598e-01
    -8.544921875000000e-03     5.003810394756896e-01
     9.914550781250000e-01    -6.107300716354215e-01
    -9.851074218750000e-01     5.593659503124515e-02
    -7.351074218750000e-01     9.448254839201340e-01
     7.648925781250000e-01     3.769242493522327e-01
    -8.601074218750000e-01    -7.341868617588783e-01
    -3.601074218750000e-01     5.991464715744550e-01
     6.398925781250000e-01    -5.119646395366561e-01
    -6.101074218750000e-01     1.547020271300108e-01
     8.898925781250000e-01    -2.156683432403598e-01
    -9.226074218750000e-01     4.509983234263071e-01
     5.773925781250000e-01     6.732205456485290e-01
    -6.726074218750000e-01    -4.378905654625820e-01
     8.273925781250000e-01    -8.082609358329522e-01
    -7.976074218750000e-01    -1.415942691662857e-01
     2.023925781250000e-01     5.250723975003810e-01
     7.023925781250000e-01     8.062795305593640e-02
    -5.476074218750000e-01     7.472946197226029e-01
    -4.760742187500000e-02     3.028501752781587e-01
    -7.038574218750000e-01    -4.282883706752028e-02
     2.961425781250000e-01     6.238378295991462e-01
     7.961425781250000e-01     1.793933851547020e-01
    -8.288574218750000e-01     8.460600518213686e-01
     6.711425781250000e-01     4.756896814509983e-01
     9.211425781250000e-01    -4.131992074378906e-01
    -8.913574218750000e-01     2.534674592287760e-01
     6.086425781250000e-01    -1.169029111415943e-01
    -6.413574218750000e-01     5.497637555250723e-01
     8.586425781250000e-01     7.719859777472944e-01
    -7.663574218750000e-01    -3.391251333638166e-01
     2.336425781250000e-01     3.275415333028502e-01
     9.836425781250000e-01    -1.059289742417315e-01
    -9.694824218750000e-01     5.607376924249350e-01
     5.305175781250000e-01     7.829599146471573e-01
    -7.194824218750000e-01    -9.207437890565463e-01
    -2.194824218750000e-01     4.125895442767871e-01
     7.805175781250000e-01    -6.985215668343241e-01
    -8.444824218750000e-01    -3.185490016765746e-02
     6.555175781250000e-01     1.903673220545647e-01
    -5.944824218750000e-01     8.570339887212313e-01
     9.055175781250000e-01     4.866636183508610e-01
    -9.069824218750000e-01    -6.244474927602499e-01
    -4.069824218750000e-01     7.088858405730831e-01
    -6.569824218750000e-01     2.644413961286389e-01
     8.430175781250000e-01    -3.034598384392624e-01
    -7.819824218750000e-01     3.632068282274041e-01
     7.180175781250000e-01     5.854290504496265e-01
    -9.382324218750000e-01    -2.293857643651883e-01
     6.176757812500000e-02     4.372809023014785e-01
    -6.882324218750000e-01     6.595031245237004e-01
    -1.882324218750000e-01     2.150586800792562e-01
     8.117675781250000e-01     8.817253467459227e-01
    -8.132324218750000e-01    -8.219783569577808e-01
    -3.132324218750000e-01     5.113549763755525e-01
     6.867675781250000e-01    -5.997561347355587e-01
     4.367675781250000e-01     7.335771985977744e-01
     9.367675781250000e-01     2.891327541533302e-01
    -8.757324218750000e-01     9.557994208199967e-01
     6.242675781250000e-01     3.878981862520956e-01
    -6.257324218750000e-01    -7.232129248590153e-01
     8.742675781250000e-01    -5.009907026367932e-01
    -7.507324218750000e-01     1.656759640298735e-01
     7.492675781250000e-01    -2.046944063404970e-01
    -5.007324218750000e-01     4.619722603261698e-01
    -9.992675781250000e-01    -4.269166285627192e-01
     7.324218750000000e-04     2.397500381039475e-01
    -7.492675781250000e-01    -1.306203322664229e-01
     2.507324218750000e-01     5.360463344002437e-01
     7.507324218750000e-01     9.160188995579932e-02
    -8.742675781250000e-01     7.582685566224658e-01
    -1.242675781250000e-01     3.467459228776100e-01
     8.757324218750000e-01    -7.643651882335010e-01
    -9.367675781250000e-01    -9.769852156683445e-02
    -6.867675781250000e-01     7.911903673220544e-01
     8.132324218750000e-01     4.208199969516841e-01
    -8.117675781250000e-01    -6.902911141594269e-01
    -3.117675781250000e-01     6.430422191739060e-01
     6.882324218750000e-01    -4.680688919372048e-01
     9.382324218750000e-01    -1.717725956409085e-01
    -9.680175781250000e-01     4.948940710257581e-01
     5.319824218750000e-01     7.171162932479802e-01
    -7.180175781250000e-01    -3.939948178631307e-01
     7.819824218750000e-01    -9.618960524310318e-01
    -8.430175781250000e-01    -2.952293857643653e-01
     1.569824218750000e-01     3.714372809023012e-01
     6.569824218750000e-01    -7.300716354214309e-02
    -5.930175781250000e-01     5.936595031245235e-01
     9.069824218750000e-01     8.158817253467459e-01
    -9.055175781250000e-01    -8.878219783569578e-01
    -4.055175781250000e-01     4.455113549763756e-01
    -6.555175781250000e-01     1.066910531930976e-03
     3.444824218750000e-01     6.677335771985975e-01
     8.444824218750000e-01     2.232891327541533e-01
    -7.805175781250000e-01     8.899557994208198e-01
     7.194824218750000e-01     5.195854290504496e-01
     9.694824218750000e-01    -3.693034598384394e-01
    -9.836425781250000e-01     2.973632068282273e-01
    -7.336425781250000e-01     3.961286389269927e-01
     7.663574218750000e-01     6.183508611492148e-01
    -8.586425781250000e-01    -4.927602499618962e-01
    -6.086425781250000e-01    -1.964639536655999e-01
     3.913574218750000e-01     4.702027130010669e-01
     8.913574218750000e-01     2.575826855662244e-02
    -9.211425781250000e-01     6.924249352232887e-01
     5.788574218750000e-01     9.146471574455111e-01
    -6.711425781250000e-01    -7.890565462581923e-01
    -1.711425781250000e-01     5.442767870751408e-01
     8.288574218750000e-01    -5.668343240359701e-01
    -7.961425781250000e-01     9.983234263069640e-02
     7.038574218750000e-01     3.220545648529187e-01
     9.538574218750000e-01     3.549763755525071e-01
    -9.523925781250000e-01    -7.561347355586039e-01
    -4.523925781250000e-01     5.771985977747291e-01
    -7.023925781250000e-01     1.327541533302850e-01
     7.976074218750000e-01    -2.376162170400854e-01
    -8.273925781250000e-01     4.290504496265812e-01
     6.726074218750000e-01     6.512726718488031e-01
     9.226074218750000e-01    -8.302088096326780e-01
    -8.898925781250000e-01    -1.635421429660113e-01
     1.101074218750000e-01     5.031245237006552e-01
     6.101074218750000e-01     5.868007925621077e-02
    -6.398925781250000e-01     7.253467459228773e-01
    -1.398925781250000e-01     2.809023014784331e-01
     8.601074218750000e-01     9.475689681450996e-01
    -7.648925781250000e-01    -9.536655997561347e-01
    -2.648925781250000e-01     3.796677335771983e-01
     7.351074218750000e-01    -7.314433775339125e-01
     4.851074218750000e-01     6.018899557994206e-01
     9.851074218750000e-01     1.574455113549764e-01
    -9.914550781250000e-01     8.241121780216429e-01
     5.085449218750000e-01     4.537418076512727e-01
    -7.414550781250000e-01    -6.573693034598385e-01
     7.585449218750000e-01    -4.351470812376163e-01
    -8.664550781250000e-01     2.315195854290504e-01
     6.335449218750000e-01    -1.388507849413200e-01
    -6.164550781250000e-01     5.278158817253467e-01
     8.835449218750000e-01     7.500381039475685e-01
    -9.289550781250000e-01    -3.610730071635422e-01
     7.104492187500000e-02     3.055936595031243e-01
    -6.789550781250000e-01    -2.623075750647768e-01
     3.210449218750000e-01     4.043590916018898e-01
     8.210449218750000e-01    -4.008535284255454e-02
    -8.039550781250000e-01     6.265813138241119e-01
     6.960449218750000e-01     8.488035360463342e-01
    -5.395507812500000e-02     4.784331656759639e-01
     9.460449218750000e-01    -6.326779454351471e-01
    -9.602050781250000e-01     3.398872123151953e-02
    -7.102050781250000e-01     9.228776101204081e-01
     7.897949218750000e-01     5.525072397500379e-01
    -8.352050781250000e-01    -5.586038713610730e-01
     6.647949218750000e-01    -3.363816491388508e-01
     9.147949218750000e-01    -3.254077122389880e-01
    -8.977050781250000e-01     3.412589544276787e-01
     6.022949218750000e-01     5.634811766499008e-01
    -6.477050781250000e-01    -5.476299344612102e-01
     8.522949218750000e-01    -9.180003048315806e-01
    -7.727050781250000e-01    -2.513336381649139e-01
     2.272949218750000e-01     4.153330285017529e-01
     7.272949218750000e-01    -2.911141594269173e-02
    -5.227050781250000e-01     6.375552507239748e-01
    -2.270507812500000e-02     1.931108062795306e-01
    -4.758300781250000e-01     4.894071025758269e-01
    -7.258300781250000e-01     4.496265813138245e-02
     7.741699218750000e-01     2.671848803536048e-01
    -8.508300781250000e-01     9.338515470202713e-01
     6.491699218750000e-01     3.659503124523700e-01
     8.991699218750000e-01    -5.229385764365189e-01
    -9.133300781250000e-01     1.437280902301481e-01
    -6.633300781250000e-01     4.400243865264444e-01
     8.366699218750000e-01     6.622466087486663e-01
    -7.883300781250000e-01    -4.488645023624448e-01
     7.116699218750000e-01    -8.192348727328151e-01
     4.616699218750000e-01     5.140984606005183e-01
     9.616699218750000e-01     6.965401615607369e-02
    -9.445800781250000e-01     7.363206828227402e-01
    -6.945800781250000e-01    -9.426916628562719e-01
    -1.945800781250000e-01     3.906416704770614e-01
     8.054199218750000e-01    -7.204694406340497e-01
    -8.195800781250000e-01    -5.380277396738309e-02
     6.804199218750000e-01     1.684194482548393e-01
    -5.695800781250000e-01     8.350861149215059e-01
     9.304199218750000e-01     4.647157445511356e-01
    -8.820800781250000e-01    -6.463953665599756e-01
    -3.820800781250000e-01     6.869379667733575e-01
     6.179199218750000e-01    -4.241731443377534e-01
    -6.320800781250000e-01     2.424935223289133e-01
     8.679199218750000e-01    -1.278768480414572e-01
    -7.570800781250000e-01     5.387898186252096e-01
     7.429199218750000e-01     7.610120408474317e-01
    -9.953613281250000e-01    -3.171772595640909e-01
     4.638671875000000e-03     3.494894071025758e-01
    -7.453613281250000e-01     5.717116293247979e-01
     7.546386718750000e-01     7.939338515470202e-01
    -8.703613281250000e-01    -9.097698521566835e-01
    -3.703613281250000e-01     4.235634811766500e-01
     6.296386718750000e-01    -6.875476299344612e-01
    -6.203613281250000e-01    -2.088096326779465e-02
     3.796386718750000e-01     6.457857033988719e-01
     8.796386718750000e-01     2.013412589544277e-01
    -9.328613281250000e-01     8.680079256210942e-01
     5.671386718750000e-01     4.976375552507240e-01
    -6.828613281250000e-01    -6.134735558603872e-01
     8.171386718750000e-01    -3.912513336381650e-01
    -8.078613281250000e-01     2.754153330285019e-01
     6.921386718750000e-01    -2.924859015393996e-01
     9.421386718750000e-01     5.964029873494894e-01
    -9.641113281250000e-01    -5.147081237616218e-01
    -4.641113281250000e-01     8.186252095717117e-01
    -7.141113281250000e-01    -2.184118274653255e-01
     2.858886718750000e-01     4.482548392013415e-01
     7.858886718750000e-01     3.810394756896818e-03
    -8.391113281250000e-01     6.704770614235633e-01
     6.608886718750000e-01     8.926992836457857e-01
    -8.911132812500000e-02     5.223289132754154e-01
     9.108886718750000e-01    -5.887821978356957e-01
    -9.016113281250000e-01     7.788446883097078e-02
     8.483886718750000e-01     3.988721231519585e-01
    -7.766113281250000e-01    -7.122389879591526e-01
    -2.766113281250000e-01     6.210943453741806e-01
     7.233886718750000e-01    -4.900167657369304e-01
     4.733886718750000e-01     8.433165675964029e-01
     9.733886718750000e-01    -1.937204694406341e-01
    -9.797363281250000e-01     4.729461972260327e-01
     5.202636718750000e-01     6.951684194482546e-01
    -7.297363281250000e-01    -4.159426916628564e-01
     7.702636718750000e-01    -7.863130620332266e-01
    -8.547363281250000e-01    -1.196463953665601e-01
     1.452636718750000e-01     5.470202713001067e-01
     6.452636718750000e-01     1.025758268556622e-01
    -6.047363281250000e-01     7.692424935223288e-01
    -1.047363281250000e-01     3.247980490778846e-01
    -6.672363281250000e-01    -8.672458466697153e-02
     3.327636718750000e-01     5.799420819996950e-01
     8.327636718750000e-01     1.354976375552508e-01
    -7.922363281250000e-01     8.021643042219173e-01
     7.077636718750000e-01     4.317939338515471e-01
     9.577636718750000e-01    -4.570949550373419e-01
    -9.484863281250000e-01     2.095717116293248e-01
    -6.984863281250000e-01     5.058680079256210e-01
     8.015136718750000e-01     7.280902301478431e-01
    -8.234863281250000e-01    -3.830208809632678e-01
     1.765136718750000e-01     2.836457857033989e-01
     9.265136718750000e-01    -6.203322664228017e-02
    -8.859863281250000e-01     6.046334400243865e-01
     6.140136718750000e-01     8.268556622466088e-01
    -1.359863281250000e-01     4.564852918762385e-01
     8.640136718750000e-01    -6.546258192348728e-01
    -7.609863281250000e-01     1.204084743179390e-02
     7.390136718750000e-01     2.342630696540162e-01
     9.890136718750000e-01     5.305593659503125e-01
    -9.875488281250000e-01    -5.805517451607987e-01
    -4.875488281250000e-01     7.527815881725344e-01
    -7.375488281250000e-01     3.083371437280902e-01
     7.624511718750000e-01    -2.595640908398110e-01
    -8.625488281250000e-01     4.071025758268556e-01
     6.374511718750000e-01     6.293247980490777e-01
    -6.125488281250000e-01    -4.817863130620332e-01
     8.874511718750000e-01    -8.521566834324036e-01
    -9.250488281250000e-01    -1.854900167657370e-01
     7.495117187500000e-02     4.811766499009298e-01
    -6.750488281250000e-01     7.033988721231517e-01
    -1.750488281250000e-01     2.589544276787075e-01
     8.249511718750000e-01     9.256210943453740e-01
    -8.000488281250000e-01    -7.780826093583295e-01
    -3.000488281250000e-01     5.552507239750037e-01
     6.999511718750000e-01    -5.558603871361074e-01
     4.499511718750000e-01     7.774729461972258e-01
     9.499511718750000e-01     3.330285017527816e-01
    -7.062988281250000e-01    -7.776761672509271e-01
    -2.062988281250000e-01     5.556571660824059e-01
     7.937011718750000e-01    -5.554539450287050e-01
    -8.312988281250000e-01     1.112127216379617e-01
     6.687011718750000e-01    -2.591576487324088e-01
     9.187011718750000e-01     6.297312401564799e-01
    -8.937988281250000e-01    -4.813798709546310e-01
     1.062011718750000e-01     1.852867957120357e-01
    -6.437988281250000e-01    -1.850835746583347e-01
     3.562011718750000e-01     4.815830920083319e-01
     8.562011718750000e-01     3.713864756388752e-02
    -7.687988281250000e-01     7.038053142305540e-01
     7.312011718750000e-01     9.260275364527764e-01
    -1.879882812500000e-02     3.581263018848750e-01
     9.812011718750000e-01    -7.529848092262359e-01
    -9.719238281250000e-01    -8.631814255956927e-02
    -7.219238281250000e-01     8.025707463293197e-01
     7.780761718750000e-01     4.322003759589494e-01
    -8.469238281250000e-01    -6.789107351521617e-01
    -3.469238281250000e-01     6.544225981811713e-01
     6.530761718750000e-01    -4.566885129299396e-01
     9.030761718750000e-01    -1.603922166336433e-01
    -9.094238281250000e-01     5.062744500330234e-01
     5.905761718750000e-01     7.284966722552453e-01
    -6.594238281250000e-01    -3.826144388558655e-01
     8.405761718750000e-01    -9.505156734237667e-01
    -7.844238281250000e-01    -2.838490067571001e-01
     2.155761718750000e-01     3.828176599095665e-01
     7.155761718750000e-01    -6.162678453487791e-02
    -5.344238281250000e-01     6.050398821317886e-01
    -3.442382812500000e-02     1.605954376873444e-01
     9.655761718750000e-01     8.272621043540109e-01
    -9.406738281250000e-01    -8.764415993496927e-01
    -4.406738281250000e-01     4.568917339836407e-01
    -6.906738281250000e-01     1.244728953919627e-02
     3.093261718750000e-01     6.791139562058626e-01
     8.093261718750000e-01     2.346695117614184e-01
    -8.156738281250000e-01     9.013361784280849e-01
     6.843261718750000e-01     5.309658080577146e-01
     9.343261718750000e-01    -3.579230808311742e-01
    -8.781738281250000e-01     3.087435858354926e-01
     6.218261718750000e-01    -3.250012701315858e-01
    -6.281738281250000e-01     3.416653965350809e-01
     8.718261718750000e-01     5.638876187573030e-01
    -7.531738281250000e-01    -5.472234923538078e-01
     7.468261718750000e-01    -9.175938627241782e-01
     9.968261718750000e-01    -2.870497383528947e-02
    -9.973144531250000e-01     6.379616928313769e-01
     5.026855468750000e-01     8.601839150535993e-01
    -7.473144531250000e-01    -8.435197886501041e-01
    -2.473144531250000e-01     4.898135446832290e-01
     7.526855468750000e-01    -6.212975664278819e-01
    -8.723144531250000e-01     4.536910023878460e-02
     6.276855468750000e-01     2.675913224610069e-01
     8.776855468750000e-01     3.663567545597721e-01
    -9.348144531250000e-01    -7.447543565513387e-01
    -4.348144531250000e-01     5.885789767819944e-01
    -6.848144531250000e-01     1.441345323375502e-01
     8.151855468750000e-01    -2.262358380328203e-01
    -8.098144531250000e-01     4.404308286338465e-01
     6.901855468750000e-01     6.626530508560684e-01
     9.401855468750000e-01    -8.188284306254128e-01
    -9.660644531250000e-01    -1.521617639587463e-01
     3.393554687500000e-02     5.145049027079205e-01
    -7.160644531250000e-01     7.367271249301424e-01
    -2.160644531250000e-01     2.922826804856982e-01
     7.839355468750000e-01     9.589493471523647e-01
    -8.410644531250000e-01    -9.422852207488696e-01
    -3.410644531250000e-01     3.910481125844636e-01
     6.589355468750000e-01    -7.200629985266473e-01
     4.089355468750000e-01     6.132703348066857e-01
     9.089355468750000e-01     1.688258903622415e-01
    -9.035644531250000e-01     8.354925570289080e-01
     5.964355468750000e-01     4.651221866585378e-01
    -6.535644531250000e-01    -6.459889244525733e-01
     8.464355468750000e-01    -4.237667022303512e-01
    -7.785644531250000e-01     2.428999644363155e-01
     7.214355468750000e-01    -1.274704059340549e-01
    -5.285644531250000e-01     5.391962607326117e-01
     9.714355468750000e-01     7.614184829548338e-01
    -9.816894531250000e-01    -3.496926281562771e-01
     1.831054687500000e-02     3.169740385103896e-01
    -7.316894531250000e-01    -3.167708174566886e-01
     2.683105468750000e-01     3.498958492099780e-01
     7.683105468750000e-01    -9.454859523446635e-02
    -8.566894531250000e-01     5.721180714322001e-01
     6.433105468750000e-01     7.943402936544224e-01
    -1.066894531250000e-01     4.239699232840521e-01
     8.933105468750000e-01    -6.871411878270589e-01
    -9.191894531250000e-01    -2.047452116039228e-02
    -6.691894531250000e-01     8.684143677284963e-01
     8.308105468750000e-01     4.980439973581261e-01
    -7.941894531250000e-01    -6.130671137529848e-01
     7.058105468750000e-01    -3.908448915307626e-01
     9.558105468750000e-01    -2.920794594319972e-01
    -9.504394531250000e-01     3.745872072346692e-01
     5.495605468750000e-01     5.968094294568915e-01
    -7.004394531250000e-01    -5.143016816542194e-01
     7.995605468750000e-01    -8.846720520245898e-01
    -8.254394531250000e-01    -2.180053853579231e-01
     1.745605468750000e-01     4.486612813087436e-01
     6.745605468750000e-01     4.216836864298967e-03
    -5.754394531250000e-01     6.708835035309655e-01
    -7.543945312500000e-02     2.264390590865213e-01
     9.245605468750000e-01     8.931057257531878e-01
    -8.879394531250000e-01    -8.105979779505157e-01
    -3.879394531250000e-01     5.227353553828176e-01
     6.120605468750000e-01    -5.883757557282935e-01
    -6.379394531250000e-01     7.829091093837293e-02
     3.620605468750000e-01     7.449575776050394e-01
     8.620605468750000e-01     3.005131331605952e-01
     7.370605468750000e-01     3.992785652593607e-01
     9.870605468750000e-01    -4.896103236295281e-01
    -9.895019531250000e-01     1.770563430371386e-01
    -7.395019531250000e-01     4.733526393334349e-01
     7.604980468750000e-01     6.955748615556567e-01
    -8.645019531250000e-01    -4.155362495554540e-01
     1.354980468750000e-01     2.511304171112125e-01
     6.354980468750000e-01    -7.859066199258243e-01
    -6.145019531250000e-01    -1.192399532591577e-01
     3.854980468750000e-01     5.474267134075088e-01
     8.854980468750000e-01     1.029822689630644e-01
    -9.270019531250000e-01     7.696489356297309e-01
    -1.770019531250000e-01     3.361784280851494e-01
     8.229980468750000e-01    -7.749326830259615e-01
    -8.020019531250000e-01    -1.082660163592949e-01
     1.979980468750000e-01     5.584006503073715e-01
     6.979980468750000e-01     1.139562058629273e-01
    -5.520019531250000e-01     7.806228725295938e-01
     9.479980468750000e-01     4.102525021592236e-01
    -9.582519531250000e-01    -7.008586089518873e-01
    -4.582519531250000e-01     6.324747243814455e-01
    -7.082519531250000e-01     1.880302799370013e-01
     7.917480468750000e-01    -1.823400904333690e-01
    -8.332519531250000e-01     4.843265762332976e-01
     6.667480468750000e-01     7.065487984555197e-01
    -8.957519531250000e-01    -3.057968805568257e-01
     1.042480468750000e-01     3.608697861098407e-01
     6.042480468750000e-01    -8.357465833460354e-02
    -6.457519531250000e-01     5.830920083320630e-01
     8.542480468750000e-01     8.053142305542853e-01
    -7.707519531250000e-01    -8.983894731494183e-01
    -2.707519531250000e-01     4.349438601839151e-01
     7.292480468750000e-01    -6.761672509271961e-01
     4.792480468750000e-01     6.571660824061369e-01
     9.792480468750000e-01     2.127216379616927e-01
    -9.738769531250000e-01     8.793883046283593e-01
     5.261230468750000e-01     5.090179342579890e-01
    -7.238769531250000e-01    -6.020931768531219e-01
     7.761230468750000e-01    -3.798709546308998e-01
    -8.488769531250000e-01     2.867957120357667e-01
     6.511230468750000e-01    -2.811055225321344e-01
    -5.988769531250000e-01     3.855611441345321e-01
     9.011230468750000e-01     6.077833663567542e-01
    -9.113769531250000e-01    -5.033277447543565e-01
     8.862304687500000e-02     1.633389219123100e-01
    -6.613769531250000e-01    -2.070314484580603e-01
     3.386230468750000e-01     4.596352182086063e-01
     8.386230468750000e-01     1.519077376416189e-02
    -7.863769531250000e-01     6.818574404308282e-01
     7.136230468750000e-01     9.040796626530505e-01
     9.636230468750000e-01    -5.774018188284307e-01
    -9.426269531250000e-01     8.926484783823585e-02
     8.073730468750000e-01     3.444088807600465e-01
    -8.176269531250000e-01    -7.667022303510644e-01
    -3.176269531250000e-01     5.666311029822686e-01
     6.823730468750000e-01    -5.444800081288421e-01
     4.323730468750000e-01     7.888533252044909e-01
     9.323730468750000e-01    -2.481837118325460e-01
    -8.801269531250000e-01     4.184829548341207e-01
     6.198730468750000e-01     6.407051770563426e-01
    -6.301269531250000e-01    -4.704059340547682e-01
     8.698730468750000e-01    -8.407763044251384e-01
    -7.551269531250000e-01    -1.741096377584719e-01
     2.448730468750000e-01     4.925570289081946e-01
     7.448730468750000e-01     4.811258446375022e-02
    -5.051269531250000e-01     7.147792511304167e-01
    -5.126953125000000e-03     2.703348066859725e-01
    -7.434082031250000e-01    -7.534420565970645e-02
     2.565917968750000e-01     5.913224610069601e-01
     7.565917968750000e-01     1.468780165625159e-01
    -8.684082031250000e-01     8.135446832291824e-01
     6.315917968750000e-01     4.431743128588121e-01
    -6.184082031250000e-01    -6.679367982522989e-01
     8.815917968750000e-01    -4.457145760300768e-01
    -9.309082031250000e-01     2.209520906365898e-01
    -6.809082031250000e-01     5.172483869328861e-01
     8.190917968750000e-01     7.394706091551080e-01
    -8.059082031250000e-01    -3.716405019560027e-01
     1.940917968750000e-01     2.950261647106638e-01
     6.940917968750000e-01    -9.395417365239038e-01
     9.440917968750000e-01    -5.065284763501510e-02
    -9.621582031250000e-01     6.160138190316513e-01
     5.378417968750000e-01     8.382360412538736e-01
    -7.121582031250000e-01    -8.654676624498299e-01
    -2.121582031250000e-01     4.678656708835034e-01
     7.878417968750000e-01    -6.432454402276075e-01
    -8.371582031250000e-01     2.342122643905897e-02
     6.628417968750000e-01     2.456434486612811e-01
     9.128417968750000e-01     5.419397449575774e-01
    -8.996582031250000e-01    -5.691713661535335e-01
    -3.996582031250000e-01     7.641619671797995e-01
     6.003417968750000e-01    -3.469491439313114e-01
    -6.496582031250000e-01     3.197175227353553e-01
     8.503417968750000e-01    -3.140273332317228e-01
    -7.746582031250000e-01     3.526393334349436e-01
     7.253417968750000e-01     5.748615556571657e-01
    -9.777832031250000e-01    -2.399532591576488e-01
     2.221679687500000e-02     4.267134075090178e-01
    -7.277832031250000e-01     6.489356297312396e-01
     7.722167968750000e-01     8.711578519534620e-01
    -8.527832031250000e-01    -8.325458517502413e-01
    -3.527832031250000e-01     5.007874815830917e-01
     6.472167968750000e-01    -6.103236295280191e-01
    -6.027832031250000e-01     5.634303713864730e-02
     3.972167968750000e-01     7.230097038053138e-01
     8.972167968750000e-01     2.785652593608696e-01
    -9.152832031250000e-01     9.452319260275361e-01
    -6.652832031250000e-01    -7.337804196514759e-01
     8.347167968750000e-01    -5.115581974292537e-01
    -7.902832031250000e-01     1.551084692374129e-01
     7.097167968750000e-01    -2.152619011329574e-01
    -5.402832031250000e-01     4.514047655337092e-01
     9.597167968750000e-01     6.736269877559311e-01
    -9.465332031250000e-01    -4.374841233551796e-01
     5.346679687500000e-02     2.291825433114869e-01
    -6.965332031250000e-01    -1.411878270588833e-01
     3.034667968750000e-01     5.254788396077832e-01
     8.034667968750000e-01     8.103439516333855e-02
    -8.215332031250000e-01     7.477010618300051e-01
     6.784667968750000e-01     9.699232840522274e-01
    -7.153320312500000e-02     4.020220494843263e-01
     9.284667968750000e-01    -7.090890616267845e-01
    -8.840332031250000e-01    -4.242239496011790e-02
     6.159667968750000e-01     1.797998272621042e-01
    -6.340332031250000e-01     8.464664939287707e-01
     8.659667968750000e-01     4.760961235584005e-01
    -7.590332031250000e-01    -6.350149875527105e-01
     7.409667968750000e-01    -4.127927653304883e-01
     9.909667968750000e-01    -1.164964690341920e-01
    -9.855957031250000e-01     5.501701976324744e-01
     5.144042968750000e-01     7.723924198546965e-01
    -7.355957031250000e-01    -3.387186912564142e-01
     2.644042968750000e-01     3.279479754102523e-01
     7.644042968750000e-01    -9.944114210232180e-01
    -8.605957031250000e-01    -3.277447543565514e-01
     1.394042968750000e-01     3.389219123101153e-01
     6.394042968750000e-01    -1.055225321343292e-01
    -6.105957031250000e-01     5.611441345323374e-01
     8.894042968750000e-01     7.833663567545597e-01
    -9.230957031250000e-01    -9.203373469491439e-01
    -4.230957031250000e-01     4.129959863841894e-01
    -6.730957031250000e-01    -3.144845806025509e-02
     3.269042968750000e-01     6.352182086064113e-01
     8.269042968750000e-01     1.907737641619671e-01
    -7.980957031250000e-01     8.574404308286336e-01
     7.019042968750000e-01     4.870700604582634e-01
     9.519042968750000e-01    -4.018188284306254e-01
    -9.543457031250000e-01     2.648478382360413e-01
    -7.043457031250000e-01     3.636132703348065e-01
     7.956542968750000e-01     5.858354925570288e-01
    -8.293457031250000e-01    -5.252756185540822e-01
     6.706542968750000e-01    -8.956459889244526e-01
     4.206542968750000e-01     4.376873444088809e-01
     9.206542968750000e-01    -6.757100035563735e-03
    -8.918457031250000e-01     6.599095666311028e-01
     6.081542968750000e-01     8.821317888533251e-01
    -6.418457031250000e-01    -8.215719148503785e-01
    -1.418457031250000e-01     5.117614184829549e-01
     8.581542968750000e-01    -5.993496926281563e-01
    -7.668457031250000e-01     6.731697403851022e-02
     7.331542968750000e-01     2.895391962607325e-01
     9.831542968750000e-01     3.883046283594980e-01
    -9.699707031250000e-01    -7.228064827516131e-01
    -4.699707031250000e-01     6.105268505817201e-01
    -7.199707031250000e-01     1.660824061372759e-01
     7.800292968750000e-01    -2.042879642330946e-01
    -8.449707031250000e-01     4.623787024335722e-01
     6.550292968750000e-01     6.846009246557940e-01
     9.050292968750000e-01    -7.968805568256871e-01
    -9.074707031250000e-01    -1.302138901590205e-01
     9.252929687500000e-02     5.364527765076461e-01
    -6.574707031250000e-01     7.586749987298682e-01
    -1.574707031250000e-01     3.142305542854240e-01
     8.425292968750000e-01     9.808972209520905e-01
    -7.824707031250000e-01    -9.861809683483209e-01
    -2.824707031250000e-01     3.471523649850123e-01
     7.175292968750000e-01    -7.639587461260987e-01
     4.675292968750000e-01     5.693745872072344e-01
     9.675292968750000e-01     1.249301427627902e-01
    -9.387207031250000e-01     7.915968094294568e-01
    -6.887207031250000e-01    -6.898846720520246e-01
     8.112792968750000e-01    -4.676624498298024e-01
    -8.137207031250000e-01     1.990042168368642e-01
     6.862792968750000e-01    -1.713661535335061e-01
    -5.637207031250000e-01     4.953005131331605e-01
     9.362792968750000e-01     7.175227353553826e-01
    -8.762207031250000e-01    -3.935883757557284e-01
     1.237792968750000e-01     2.730782909109384e-01
    -6.262207031250000e-01    -2.948229436569629e-01
     3.737792968750000e-01     3.718437230097036e-01
     8.737792968750000e-01    -7.260072143474072e-02
    -7.512207031250000e-01     5.940659452319259e-01
     7.487792968750000e-01     8.162881674541482e-01
    -1.220703125000000e-03     4.459177970837780e-01
    -9.982910156250000e-01     1.473352639333347e-03
    -7.482910156250000e-01     8.903622415282222e-01
     7.517089843750000e-01     5.199918711578519e-01
    -8.732910156250000e-01    -5.911192399532592e-01
    -3.732910156250000e-01     7.422140933800738e-01
     6.267089843750000e-01    -3.688970177310370e-01
    -6.232910156250000e-01     2.977696489356296e-01
     8.767089843750000e-01    -2.701315856322716e-01
    -9.357910156250000e-01     3.965350810343951e-01
     5.642089843750000e-01     6.187573032566172e-01
    -6.857910156250000e-01    -4.923538078544938e-01
     8.142089843750000e-01    -8.627241782248641e-01
    -8.107910156250000e-01    -1.960575115581975e-01
     1.892089843750000e-01     4.706091551084692e-01
     6.892089843750000e-01     2.616471066402482e-02
    -5.607910156250000e-01     6.928313773306911e-01
    -6.079101562500000e-02     2.483869328862469e-01
    -9.670410156250000e-01    -7.886501041507901e-01
    -4.670410156250000e-01     5.446832291825432e-01
    -7.170410156250000e-01     1.002387847380988e-01
     7.829589843750000e-01     3.224610069603211e-01
     6.579589843750000e-01     3.553828176599094e-01
     9.079589843750000e-01    -5.335060712289794e-01
    -9.045410156250000e-01     1.331605954376873e-01
    -6.545410156250000e-01     4.294568917339836e-01
     8.454589843750000e-01     6.516791139562055e-01
    -7.795410156250000e-01    -4.594319971549052e-01
     7.204589843750000e-01    -8.298023675252756e-01
     4.704589843750000e-01     5.035309658080576e-01
     9.704589843750000e-01     5.908652136361314e-02
    -9.826660156250000e-01     7.257531880302797e-01
    -7.326660156250000e-01    -9.532591576487324e-01
    -2.326660156250000e-01     3.800741756846007e-01
     7.673339843750000e-01    -7.310369354265103e-01
    -8.576660156250000e-01    -6.437026875984353e-02
     6.423339843750000e-01     1.578519534623788e-01
    -6.076660156250000e-01     8.245186201290453e-01
     8.923339843750000e-01     4.541482497586751e-01
    -9.201660156250000e-01    -6.569628613524361e-01
    -4.201660156250000e-01     6.763704719808969e-01
    -6.701660156250000e-01     2.319260275364528e-01
     8.298339843750000e-01    -1.384443428339176e-01
    -7.951660156250000e-01     5.282223238327490e-01
     7.048339843750000e-01     7.504445460549709e-01
    -9.514160156250000e-01    -2.619011329573744e-01
     4.858398437500000e-02     4.047655337092921e-01
    -7.014160156250000e-01     6.269877559315142e-01
     7.985839843750000e-01     8.492099781537366e-01
    -8.264160156250000e-01    -8.544937255499669e-01
    -3.264160156250000e-01     4.788396077833663e-01
     6.735839843750000e-01    -6.322715033277448e-01
     4.235839843750000e-01     7.010618300055882e-01
     9.235839843750000e-01     2.566173855611440e-01
    -8.889160156250000e-01     9.232840522278105e-01
     6.110839843750000e-01     5.529136818574403e-01
    -6.389160156250000e-01    -5.581974292536707e-01
     8.610839843750000e-01    -3.359752070314485e-01
    -7.639160156250000e-01     3.306914596352182e-01
     7.360839843750000e-01    -3.323172280648276e-01
     9.860839843750000e-01     5.565716608240612e-01
    -9.904785156250000e-01    -5.545394502870498e-01
    -4.904785156250000e-01     7.787938830462835e-01
    -7.404785156250000e-01    -2.582431539907535e-01
     2.595214843750000e-01     4.084235126759133e-01
     7.595214843750000e-01    -3.602093176853127e-02
    -8.654785156250000e-01     6.306457348981351e-01
     6.345214843750000e-01     8.528679571203575e-01
    -1.154785156250000e-01     4.824975867499872e-01
     8.845214843750000e-01    -6.286135243611238e-01
    -9.279785156250000e-01     3.805314230554280e-02
    -6.779785156250000e-01     9.269420311944316e-01
     8.220214843750000e-01     3.590407966265303e-01
    -8.029785156250000e-01    -7.520703144845806e-01
    -3.029785156250000e-01     5.812630188487526e-01
     6.970214843750000e-01    -5.298480922623584e-01
     4.470214843750000e-01     8.034852410709750e-01
     9.470214843750000e-01    -2.335517959660621e-01
    -9.592285156250000e-01     4.331148707006047e-01
     5.407714843750000e-01     6.553370929228266e-01
    -7.092285156250000e-01    -4.557740181882843e-01
     7.907714843750000e-01    -8.261443885586547e-01
    -8.342285156250000e-01    -1.594777218919881e-01
     1.657714843750000e-01     5.071889447746787e-01
     6.657714843750000e-01     6.274450033023404e-02
    -5.842285156250000e-01     7.294111669969006e-01
    -8.422851562500000e-02     2.849667225524564e-01
    -8.967285156250000e-01    -9.496011786821115e-01
    -6.467285156250000e-01    -6.071228979322263e-02
     3.532714843750000e-01     6.059543768734439e-01
     8.532714843750000e-01     1.615099324289997e-01
    -7.717285156250000e-01     8.281765990956662e-01
     7.282714843750000e-01     4.578062287252960e-01
     9.782714843750000e-01    -4.310826601635930e-01
    -9.748535156250000e-01     2.355840065030737e-01
    -7.248535156250000e-01     5.318803027993699e-01
     7.751464843750000e-01     7.541025250215920e-01
    -8.498535156250000e-01    -3.570085860895189e-01
     1.501464843750000e-01     3.096580805771478e-01
     9.001464843750000e-01    -1.018645531677083e-01
    -9.123535156250000e-01     5.648021134989583e-01
     5.876464843750000e-01     7.870243357211806e-01
    -1.623535156250000e-01     4.166539653508103e-01
     8.376464843750000e-01    -6.944571457603008e-01
    -7.873535156250000e-01    -2.779047909363419e-02
     7.126464843750000e-01     1.944317431285880e-01
    -5.373535156250000e-01     8.610984097952545e-01
     9.626464843750000e-01     4.907280394248843e-01
    -9.436035156250000e-01    -6.203830716862266e-01
    -4.436035156250000e-01     7.129502616471064e-01
    -6.936035156250000e-01     2.685058172026622e-01
     8.063964843750000e-01    -2.993954173652391e-01
    -8.186035156250000e-01     3.672712493014274e-01
     6.813964843750000e-01     5.894934715236497e-01
     9.313964843750000e-01    -8.919880099578317e-01
    -8.811035156250000e-01    -2.253213432911650e-01
     1.188964843750000e-01     4.413453233755018e-01
     6.188964843750000e-01    -3.099121068942834e-03
    -6.311035156250000e-01     6.635675455977237e-01
    -1.311035156250000e-01     2.191231011532795e-01
     8.688964843750000e-01     8.857897678199460e-01
    -7.561035156250000e-01    -8.179139358837576e-01
    -2.561035156250000e-01     5.154193974495758e-01
     7.438964843750000e-01    -5.956917136615354e-01
     4.938964843750000e-01     7.376416196717976e-01
     9.938964843750000e-01     2.931971752273534e-01
    -9.943847656250000e-01     9.598638418940200e-01
    -7.443847656250000e-01    -7.191485037849921e-01
    -2.443847656250000e-01     6.141848295483410e-01
     7.556152343750000e-01    -4.969262815627700e-01
    -8.693847656250000e-01     1.697403851038968e-01
     6.306152343750000e-01    -2.006299852664737e-01
    -6.193847656250000e-01     4.660366814001931e-01
     8.806152343750000e-01     6.882589036224149e-01
    -9.318847656250000e-01    -4.228522074886959e-01
     6.811523437500000e-02     2.438144591779707e-01
    -6.818847656250000e-01    -1.265559111923996e-01
     3.181152343750000e-01     5.401107554742670e-01
     8.181152343750000e-01     9.566631102982259e-02
    -8.068847656250000e-01     7.623329776964891e-01
    -3.068847656250000e-01     3.178885332520449e-01
    -5.688476562500000e-02     3.508103439516332e-01
     9.431152343750000e-01    -7.603007671594777e-01
    -9.631347656250000e-01    -9.363410049281107e-02
    -7.131347656250000e-01     7.952547883960777e-01
     7.868652343750000e-01     4.248844180257074e-01
    -8.381347656250000e-01    -6.862266930854037e-01
    -3.381347656250000e-01     6.471066402479293e-01
     6.618652343750000e-01    -4.640044708631814e-01
     9.118652343750000e-01    -1.677081745668851e-01
    -9.006347656250000e-01     4.989584920997814e-01
     5.993652343750000e-01     7.211807143220035e-01
    -6.506347656250000e-01    -3.899303967891073e-01
     8.493652343750000e-01    -9.578316313570086e-01
    -7.756347656250000e-01    -2.911649646903419e-01
     2.243652343750000e-01     3.755017019763245e-01
     7.243652343750000e-01    -6.894274246811971e-02
    -5.256347656250000e-01     5.977239241985468e-01
    -2.563476562500000e-02     1.532794797541026e-01
    -4.787597656250000e-01     4.495757760503989e-01
    -7.287597656250000e-01     5.131331605954248e-03
     2.712402343750000e-01     6.717979982726208e-01
     7.712402343750000e-01     2.273535538281766e-01
    -8.537597656250000e-01     8.940202204948431e-01
     6.462402343750000e-01     5.236498501244728e-01
    -6.037597656250000e-01    -5.874612609866383e-01
     8.962402343750000e-01    -3.652390387644160e-01
    -9.162597656250000e-01     3.014276279022505e-01
    -6.662597656250000e-01     4.001930600010160e-01
     8.337402343750000e-01     6.224152822232381e-01
    -7.912597656250000e-01    -4.886958288878728e-01
     7.087402343750000e-01    -8.590661992582431e-01
     4.587402343750000e-01     4.742671340750901e-01
     9.587402343750000e-01     2.982268963064572e-02
    -9.475097656250000e-01     6.964893562973120e-01
    -6.975097656250000e-01    -7.849921251841691e-01
    -1.975097656250000e-01     5.483412081491641e-01
     8.024902343750000e-01    -5.627699029619468e-01
    -8.225097656250000e-01     1.038967637047197e-01
     6.774902343750000e-01     3.261189859269420e-01
     9.274902343750000e-01     3.370929228268047e-01
    -8.850097656250000e-01    -7.740181882843062e-01
    -3.850097656250000e-01     5.593151450490268e-01
     6.149902343750000e-01    -5.517959660620840e-01
    -6.350097656250000e-01     1.148707006045826e-01
     8.649902343750000e-01    -2.554996697657878e-01
    -7.600097656250000e-01     4.111669969008789e-01
     7.399902343750000e-01     6.333892191231008e-01
    -9.865722656250000e-01    -1.814255956917137e-01
     1.342773437500000e-02     4.852410709749528e-01
    -7.365722656250000e-01     7.074632931971749e-01
    -2.365722656250000e-01     2.630188487527307e-01
     7.634277343750000e-01     9.296855154193973e-01
    -8.615722656250000e-01    -9.715490524818371e-01
    -3.615722656250000e-01     3.617842808514959e-01
     6.384277343750000e-01    -7.493268302596149e-01
    -6.115722656250000e-01    -8.266016359294825e-02
     3.884277343750000e-01     5.840065030737183e-01
     8.884277343750000e-01     1.395620586292741e-01
    -9.240722656250000e-01     8.062287252959406e-01
     5.759277343750000e-01     4.358583549255703e-01
    -6.740722656250000e-01    -6.752527561855408e-01
     8.259277343750000e-01    -4.530305339633186e-01
    -7.990722656250000e-01     2.136361327033480e-01
     7.009277343750000e-01    -1.567342376670223e-01
    -5.490722656250000e-01     5.099324289996443e-01
     9.509277343750000e-01     7.321546512218662e-01
    -9.553222656250000e-01    -3.789564598892445e-01
     4.467773437500000e-02     2.877102067774220e-01
    -7.053222656250000e-01    -2.801910277904791e-01
     2.946777343750000e-01     3.864756388761874e-01
     7.946777343750000e-01    -5.796880556825690e-02
    -8.303222656250000e-01     6.086978610984095e-01
     6.696777343750000e-01     8.309200833206318e-01
    -8.032226562500000e-02     4.605497129502616e-01
     9.196777343750000e-01    -6.505613981608495e-01
    -8.928222656250000e-01     1.610526850581717e-02
     6.071777343750000e-01     2.383274907280393e-01
    -6.428222656250000e-01     9.049941573947058e-01
     8.571777343750000e-01     5.346237870243356e-01
    -7.678222656250000e-01    -5.764873240867754e-01
     7.321777343750000e-01    -3.542651018645532e-01
     9.821777343750000e-01    -3.213432911649647e-01
    -9.709472656250000e-01     3.453233755017018e-01
     5.290527343750000e-01     5.675455977239239e-01
    -7.209472656250000e-01    -5.435655133871868e-01
     7.790527343750000e-01    -9.139358837575573e-01
    -8.459472656250000e-01    -2.472692170908907e-01
     1.540527343750000e-01     4.193974495757760e-01
     6.540527343750000e-01    -2.504699486866846e-02
    -5.959472656250000e-01     6.416196717979978e-01
    -9.594726562500000e-02     1.971752273535536e-01
     9.040527343750000e-01     8.638418940202202e-01
    -9.084472656250000e-01    -8.398618096834832e-01
    -4.084472656250000e-01     4.934715236498499e-01
    -6.584472656250000e-01     4.902707920540550e-02
     3.415527343750000e-01     7.156937458720720e-01
     8.415527343750000e-01     2.712493014276278e-01
    -7.834472656250000e-01     9.379159680942943e-01
     7.165527343750000e-01     3.700147335263930e-01
     9.665527343750000e-01    -5.188741553624956e-01
    -9.396972656250000e-01     1.477925113041711e-01
    -6.896972656250000e-01     4.440888076004674e-01
     8.103027343750000e-01     6.663110298226893e-01
    -8.146972656250000e-01    -4.448000812884215e-01
     1.853027343750000e-01     2.218665853782451e-01
     6.853027343750000e-01    -8.151704516587919e-01
     4.353027343750000e-01     5.181628816745414e-01
     9.353027343750000e-01     7.371843723009674e-02
    -8.771972656250000e-01     7.403851038967633e-01
    -1.271972656250000e-01     3.947060915510845e-01
     8.728027343750000e-01    -7.164050195600264e-01
    -7.521972656250000e-01    -4.973835289335982e-02
     2.478027343750000e-01     6.169283137733066e-01
     7.478027343750000e-01     1.724838693288624e-01
    -5.021972656250000e-01     8.391505359955289e-01
     9.978027343750000e-01     4.687801656251587e-01
    -9.963378906250000e-01    -6.423309454859523e-01
    -4.963378906250000e-01     6.910023878473806e-01
    -7.463378906250000e-01     2.465579434029364e-01
     7.536621093750000e-01    -1.238124269674339e-01
    -8.713378906250000e-01     5.428542396992326e-01
     6.286621093750000e-01     7.650764619214547e-01
    -6.213378906250000e-01    -3.460346491896561e-01
    -9.338378906250000e-01    -3.131128384900675e-01
     6.616210937500000e-02     3.535538281765989e-01
    -6.838378906250000e-01     5.757760503988210e-01
     8.161621093750000e-01     7.979982726210433e-01
    -8.088378906250000e-01    -9.057054310826602e-01
    -3.088378906250000e-01     4.276279022506730e-01
     6.911621093750000e-01    -6.834832088604379e-01
     4.411621093750000e-01     6.498501244728949e-01
     9.411621093750000e-01     2.054056800284507e-01
    -9.650878906250000e-01     8.720723466951172e-01
     5.349121093750000e-01     5.017019763247470e-01
    -7.150878906250000e-01    -6.094091347863639e-01
     7.849121093750000e-01    -3.871869125641416e-01
    -8.400878906250000e-01     2.794797541025249e-01
     6.599121093750000e-01    -2.884214804653762e-01
     9.099121093750000e-01     6.004674084235124e-01
    -9.025878906250000e-01    -5.106437026875985e-01
    -6.525878906250000e-01    -2.143474063913021e-01
     3.474121093750000e-01     4.523192602753645e-01
     8.474121093750000e-01     7.874815830919868e-03
    -7.775878906250000e-01     6.745414824975864e-01
     7.224121093750000e-01     8.967637047198087e-01
    -2.758789062500000e-02     5.263933343494385e-01
     9.724121093750000e-01    -5.847177767616725e-01
    -9.807128906250000e-01     8.194888990499383e-02
     7.692871093750000e-01     4.029365442259816e-01
    -8.557128906250000e-01    -7.081745668851294e-01
    -3.557128906250000e-01     6.251587664482037e-01
     6.442871093750000e-01    -4.859523446629070e-01
    -6.057128906250000e-01     1.807143220037595e-01
     8.942871093750000e-01    -1.896560483666108e-01
    -9.182128906250000e-01     4.770106183000558e-01
     5.817871093750000e-01     6.992328405222776e-01
    -6.682128906250000e-01    -4.118782705888330e-01
     8.317871093750000e-01    -7.822486409592033e-01
    -7.932128906250000e-01    -1.155819742925367e-01
     2.067871093750000e-01     5.510846923741297e-01
     7.067871093750000e-01     1.066402479296853e-01
    -5.432128906250000e-01     7.733069145963518e-01
    -4.321289062500000e-02     3.288624701519076e-01
    -6.994628906250000e-01    -1.046080373926739e-01
     3.005371093750000e-01     5.620586292739926e-01
     8.005371093750000e-01     1.176141848295484e-01
    -8.244628906250000e-01     7.842808514962150e-01
     6.755371093750000e-01     4.139104811258447e-01
     9.255371093750000e-01    -4.749784077630442e-01
    -8.869628906250000e-01     1.916882589036224e-01
     6.130371093750000e-01    -1.786821114667480e-01
    -6.369628906250000e-01     4.879845551999187e-01
     8.630371093750000e-01     7.102067774221408e-01
    -7.619628906250000e-01    -4.009043336889702e-01
     2.380371093750000e-01     2.657623329776966e-01
     7.380371093750000e-01    -9.688055682568714e-01
     9.880371093750000e-01    -7.991667936798252e-02
    -9.885253906250000e-01     5.867499872986841e-01
     5.114746093750000e-01     8.089722095209064e-01
    -7.385253906250000e-01    -8.947314941827973e-01
    -2.385253906250000e-01     4.386018391505362e-01
     7.614746093750000e-01    -6.725092719605752e-01
    -8.635253906250000e-01    -5.842605293908454e-03
     6.364746093750000e-01     2.163796169283139e-01
    -6.135253906250000e-01     8.830462835949804e-01
     8.864746093750000e-01     5.126759132246101e-01
    -9.260253906250000e-01    -5.984351978865010e-01
    -4.260253906250000e-01     7.348981354468320e-01
    -6.760253906250000e-01     2.904536910023878e-01
     8.239746093750000e-01    -2.774475435655134e-01
    -8.010253906250000e-01     3.892191231011533e-01
     6.989746093750000e-01     6.114413453233754e-01
     9.489746093750000e-01    -8.700401361581060e-01
    -9.572753906250000e-01    -2.033734694914393e-01
     4.272460937500000e-02     4.632931971752274e-01
    -7.072753906250000e-01     6.855154193974493e-01
    -2.072753906250000e-01     2.410709749530051e-01
     7.927246093750000e-01     9.077376416196716e-01
    -8.322753906250000e-01    -7.959660620840319e-01
    -3.322753906250000e-01     5.373672712493014e-01
     6.677246093750000e-01    -5.737438398618098e-01
     4.177246093750000e-01     7.595894934715235e-01
     9.177246093750000e-01     3.151450490270793e-01
    -8.947753906250000e-01     9.818117156937458e-01
     6.052246093750000e-01     3.480668597266676e-01
    -6.447753906250000e-01    -7.630442513844434e-01
     8.552246093750000e-01    -5.408220291622212e-01
    -7.697753906250000e-01     1.258446375044455e-01
     7.302246093750000e-01    -2.445257328659249e-01
     9.802246093750000e-01     6.443631560229637e-01
    -9.729003906250000e-01    -4.667479550881471e-01
     2.709960937500000e-02     1.999187115785195e-01
    -7.229003906250000e-01    -1.704516587918509e-01
     2.770996093750000e-01     4.962150078748158e-01
     7.770996093750000e-01     5.177056343037134e-02
    -8.479003906250000e-01     7.184372300970379e-01
     6.520996093750000e-01     9.406594523192602e-01
    -9.790039062500000e-02     3.727582177513589e-01
     9.020996093750000e-01    -7.383528933597521e-01
    -9.104003906250000e-01    -7.168622669308544e-02
    -6.604003906250000e-01     8.172026621958035e-01
     8.395996093750000e-01     4.468322918254333e-01
    -7.854003906250000e-01    -6.642788192856780e-01
    -2.854003906250000e-01     6.690545140476551e-01
     7.145996093750000e-01    -4.420565970634558e-01
     9.645996093750000e-01    -1.457603007671595e-01
    -9.416503906250000e-01     5.209063658995072e-01
     5.583496093750000e-01     7.431285881217291e-01
    -6.916503906250000e-01    -3.679825229893817e-01
     8.083496093750000e-01    -9.358837575572829e-01
    -8.166503906250000e-01    -2.692170908906163e-01
     1.833496093750000e-01     3.974495757760503e-01
     6.833496093750000e-01    -4.699486866839409e-02
    -5.666503906250000e-01     6.196717979982724e-01
    -6.665039062500000e-02     1.752273535538282e-01
     9.333496093750000e-01     8.418940202204948e-01
    -8.791503906250000e-01    -8.618096834832089e-01
    -3.791503906250000e-01     4.715236498501245e-01
     6.208496093750000e-01    -6.395874612609866e-01
    -6.291503906250000e-01     2.707920540568010e-02
     3.708496093750000e-01     6.937458720723464e-01
     8.708496093750000e-01     2.493014276279022e-01
    -7.541503906250000e-01     9.159680942945687e-01
     7.458496093750000e-01     5.455977239241985e-01
     9.958496093750000e-01    -3.432911649646904e-01
    -9.924316406250000e-01     3.233755017019764e-01
    -7.424316406250000e-01     3.562973124015647e-01
     7.575683593750000e-01     5.785195346237868e-01
    -8.674316406250000e-01    -5.325915764873241e-01
    -6.174316406250000e-01    -2.362952801910277e-01
     3.825683593750000e-01     4.303713864756389e-01
     8.825683593750000e-01    -1.407305796880554e-02
    -9.299316406250000e-01     6.525936086978608e-01
     5.700683593750000e-01     8.748158309200831e-01
    -6.799316406250000e-01    -8.288878727836204e-01
    -1.799316406250000e-01     5.044454605497128e-01
     8.200683593750000e-01    -6.066656505613982e-01
    -8.049316406250000e-01     6.000101610526842e-02
     6.950683593750000e-01     2.822232383274907e-01
     9.450683593750000e-01     3.809886704262559e-01
    -9.611816406250000e-01    -7.301224406848550e-01
    -4.611816406250000e-01     6.032108926484783e-01
    -7.111816406250000e-01     1.587664482040341e-01
     7.888183593750000e-01    -2.116039221663364e-01
    -8.361816406250000e-01     4.550627445003304e-01
     6.638183593750000e-01     6.772849667225522e-01
     9.138183593750000e-01    -8.041965147589291e-01
    -8.986816406250000e-01    -1.375298480922623e-01
     1.013183593750000e-01     5.291368185744043e-01
     6.013183593750000e-01     8.469237412995967e-02
    -6.486816406250000e-01     7.513590407966262e-01
    -1.486816406250000e-01     3.069145963521820e-01
     8.513183593750000e-01     9.735812630188485e-01
    -7.736816406250000e-01    -9.276533048823858e-01
    -2.736816406250000e-01     4.056800284509474e-01
     7.263183593750000e-01    -7.054310826601636e-01
     4.763183593750000e-01     6.279022506731695e-01
     9.763183593750000e-01     1.834578062287253e-01
    -9.768066406250000e-01     8.501244728953918e-01
     5.231933593750000e-01     4.797541025250216e-01
    -7.268066406250000e-01    -6.313570085860896e-01
     7.731933593750000e-01    -4.091347863638672e-01
    -8.518066406250000e-01     2.575318803027993e-01
     6.481933593750000e-01    -1.128384900675710e-01
    -6.018066406250000e-01     5.538281765990956e-01
     8.981933593750000e-01     7.760503988213177e-01
    -9.143066406250000e-01    -3.350607122897932e-01
     8.569335937500000e-02     3.316059543768735e-01
    -6.643066406250000e-01    -3.314027333231724e-01
     3.356933593750000e-01     3.352639333434944e-01
     8.356933593750000e-01    -1.091805111009502e-01
    -7.893066406250000e-01     5.574861555657165e-01
     7.106933593750000e-01     7.797083777879388e-01
    -3.930664062500000e-02     4.093380074175685e-01
     9.606933593750000e-01    -7.017731036935426e-01
    -9.455566406250000e-01    -3.510643702687610e-02
    -6.955566406250000e-01     8.537824518620127e-01
     8.044433593750000e-01     4.834120814916425e-01
    -8.205566406250000e-01    -6.276990296194687e-01
    -3.205566406250000e-01     7.056343037138646e-01
     6.794433593750000e-01    -4.054768073972465e-01
     9.294433593750000e-01    -3.067113752984810e-01
    -8.830566406250000e-01     3.599552913681856e-01
     6.169433593750000e-01     5.821775135904079e-01
    -6.330566406250000e-01    -5.289335975207032e-01
     8.669433593750000e-01    -8.993039678910735e-01
    -7.580566406250000e-01    -2.326373012244070e-01
     2.419433593750000e-01     4.340293654422600e-01
     7.419433593750000e-01    -1.041507900218475e-02
    -5.080566406250000e-01     6.562515876644819e-01
    -8.056640625000000e-03     2.118071432200377e-01
    -4.846191406250000e-01     5.081034395163340e-01
    -7.346191406250000e-01     6.365899507188932e-02
     7.653808593750000e-01     2.858812172941116e-01
    -8.596191406250000e-01     9.525478839607782e-01
     6.403808593750000e-01     3.846466493928771e-01
     8.903808593750000e-01    -5.042422394960118e-01
    -9.221191406250000e-01     1.624244271706550e-01
    -6.721191406250000e-01     4.587207234669513e-01
     8.278808593750000e-01     6.809429456891731e-01
    -7.971191406250000e-01    -4.301681654219378e-01
     2.028808593750000e-01     2.364985012447289e-01
     7.028808593750000e-01    -8.005385357923080e-01
     4.528808593750000e-01     5.327947975410252e-01
     9.528808593750000e-01     8.835035309658079e-02
    -9.533691406250000e-01     7.550170197632473e-01
    -2.033691406250000e-01     3.434943860183914e-01
     7.966308593750000e-01    -7.676167250927196e-01
    -8.283691406250000e-01    -1.009500584260531e-01
     1.716308593750000e-01     5.657166082406135e-01
     6.716308593750000e-01     1.212721637961693e-01
    -5.783691406250000e-01     7.879388304628359e-01
     9.216308593750000e-01     4.175684600924656e-01
    -8.908691406250000e-01    -6.935426510186455e-01
    -3.908691406250000e-01     6.397906823146875e-01
     6.091308593750000e-01    -4.713204287964234e-01
    -6.408691406250000e-01     1.953462378702433e-01
     8.591308593750000e-01    -1.750241325001272e-01
    -7.658691406250000e-01     4.916425341665396e-01
     7.341308593750000e-01     7.138647563887617e-01
    -9.689941406250000e-01    -2.984809226235839e-01
     3.100585937500000e-02     3.681857440430827e-01
    -7.189941406250000e-01     5.904079662653050e-01
     7.810058593750000e-01     8.126301884875273e-01
    -8.439941406250000e-01    -8.910735152161764e-01
    -3.439941406250000e-01     4.422598181171571e-01
     6.560058593750000e-01    -6.688512929939542e-01
     4.060058593750000e-01     6.644820403393790e-01
     9.060058593750000e-01     2.200375958949348e-01
    -9.064941406250000e-01     8.867042625616013e-01
     5.935058593750000e-01     5.163338921912310e-01
    -6.564941406250000e-01    -5.947772189198801e-01
     8.435058593750000e-01    -3.725549966976580e-01
    -7.814941406250000e-01     2.941116699690087e-01
     7.185058593750000e-01    -2.737895645988926e-01
     9.685058593750000e-01     6.150993242899963e-01
    -9.377441406250000e-01    -4.960117868211148e-01
     6.225585937500000e-02     1.706548798455521e-01
    -6.877441406250000e-01    -1.997154905248185e-01
     3.122558593750000e-01     4.669511761418483e-01
     8.122558593750000e-01     2.250673169740391e-02
    -8.127441406250000e-01     6.891733983640702e-01
     6.872558593750000e-01     9.113956205862925e-01
     9.372558593750000e-01    -5.700858608951888e-01
    -8.752441406250000e-01     9.658080577147787e-02
     6.247558593750000e-01     3.188030279937002e-01
     8.747558593750000e-01     3.517248386932885e-01
    -7.502441406250000e-01    -7.593862724178224e-01
    -2.502441406250000e-01     5.739470609155106e-01
     7.497558593750000e-01    -5.371640501956003e-01
     4.997558593750000e-01     7.961692831377329e-01
     9.997558593750000e-01    -2.408677538993040e-01
    -9.998779296875000e-01     4.257989127673627e-01
     5.001220703125000e-01     6.480211349895846e-01
    -7.498779296875000e-01    -4.630899761215262e-01
     7.501220703125000e-01    -8.334603464918966e-01
    -8.748779296875000e-01    -1.667936798252300e-01
     1.251220703125000e-01     4.998729868414367e-01
     6.251220703125000e-01     5.542854239699224e-02
    -6.248779296875000e-01     7.220952090636588e-01
    -1.248779296875000e-01     2.776507646192146e-01
     8.751220703125000e-01     9.443174312858811e-01
    -6.873779296875000e-01    -6.802824772646454e-02
     3.126220703125000e-01     5.986384189402021e-01
     8.126220703125000e-01     1.541939744957579e-01
    -8.123779296875000e-01     8.208606411624244e-01
     6.876220703125000e-01     4.504902707920542e-01
     9.376220703125000e-01    -4.383986180968349e-01
    -9.686279296875000e-01     2.282680485698318e-01
    -7.186279296875000e-01     5.245643448661281e-01
     7.813720703125000e-01     7.467865670883500e-01
    -8.436279296875000e-01    -3.643245440227608e-01
     1.563720703125000e-01     3.023421226439058e-01
     4.063720703125000e-01     4.011075547426712e-01
     9.063720703125000e-01    -4.333688970177318e-02
    -9.061279296875000e-01     6.233297769648933e-01
     5.938720703125000e-01     8.455519991871157e-01
    -6.561279296875000e-01    -8.581517045165878e-01
    -1.561279296875000e-01     4.751816288167454e-01
     8.438720703125000e-01    -6.359294822943657e-01
    -7.811279296875000e-01     3.073718437230100e-02
     7.188720703125000e-01     2.529594065945231e-01
     9.688720703125000e-01     5.492557028908194e-01
    -9.842529296875000e-01    -5.618554082202917e-01
    -4.842529296875000e-01     7.714779251130415e-01
    -7.342529296875000e-01     3.270334806685973e-01
     7.657470703125000e-01    -3.286592490982067e-01
    -8.592529296875000e-01     3.380074175684600e-01
     6.407470703125000e-01     5.602296397906821e-01
    -6.092529296875000e-01    -5.508814713204289e-01
     8.907470703125000e-01    -9.212518416907992e-01
    -9.217529296875000e-01    -2.545851750241326e-01
     7.824707031250000e-02     4.120814916425342e-01
    -6.717529296875000e-01     6.343037138647560e-01
     8.282470703125000e-01     8.565259360869784e-01
    -7.967529296875000e-01    -8.471777676167251e-01
    -2.967529296875000e-01     4.861555657166081e-01
     7.032470703125000e-01    -6.249555453945028e-01
     4.532470703125000e-01     7.083777879388302e-01
     9.532470703125000e-01     2.639333434943860e-01
    -9.530029296875000e-01     9.306000101610525e-01
    -7.030029296875000e-01    -7.484123355179597e-01
    -2.030029296875000e-01     5.849209978153735e-01
     7.969970703125000e-01    -5.261901132957374e-01
    -8.280029296875000e-01     1.404765533709293e-01
     6.719970703125000e-01    -2.298938169994412e-01
    -5.780029296875000e-01     4.367728496672256e-01
     9.219970703125000e-01     6.589950718894475e-01
    -8.905029296875000e-01    -4.521160392216634e-01
     1.094970703125000e-01     2.145506274450033e-01
    -6.405029296875000e-01    -1.558197429253672e-01
     3.594970703125000e-01     5.108469237412996e-01
     8.594970703125000e-01     6.640247929685494e-02
    -7.655029296875000e-01     7.330691459635215e-01
    -2.655029296875000e-01     2.886247015190773e-01
     7.344970703125000e-01     9.552913681857438e-01
    -1.550292968750000e-02     3.873901336178427e-01
     9.844970703125000e-01    -7.237209774932682e-01
    -9.920654296875000e-01    -5.705431082660173e-02
    -7.420654296875000e-01     8.318345780622871e-01
     7.579345703125000e-01     4.614642076919169e-01
    -8.670654296875000e-01    -6.496469034191943e-01
    -3.670654296875000e-01     6.836864299141387e-01
     6.329345703125000e-01    -4.274246811969721e-01
    -6.170654296875000e-01     2.392419854696946e-01
     8.829345703125000e-01    -1.311283849006758e-01
    -9.295654296875000e-01     5.355382817659908e-01
     5.704345703125000e-01     7.577605039882129e-01
    -6.795654296875000e-01    -3.533506071228980e-01
     8.204345703125000e-01    -9.870954630899761e-01
    -8.045654296875000e-01    -3.204287964233096e-01
     1.954345703125000e-01     3.462378702433571e-01
     6.954345703125000e-01    -9.820657420108736e-02
    -5.545654296875000e-01     5.684600924655792e-01
     9.454345703125000e-01     7.906823146878015e-01
    -7.108154296875000e-01    -2.413250012701329e-02
     2.891845703125000e-01     6.425341665396531e-01
     7.891845703125000e-01     1.980897220952089e-01
    -8.358154296875000e-01     8.647563887618754e-01
     6.641845703125000e-01     4.943860183915052e-01
     9.141845703125000e-01    -3.945028704973836e-01
    -8.983154296875000e-01     2.721637961692831e-01
     6.016845703125000e-01    -2.957374383986182e-01
    -6.483154296875000e-01     3.709292282680483e-01
     8.516845703125000e-01     5.931514504902706e-01
    -7.733154296875000e-01    -5.179596606208403e-01
     7.266845703125000e-01    -8.883300309912107e-01
     4.766845703125000e-01     4.450033023421227e-01
     9.766845703125000e-01     5.588578976780667e-04
    -9.764404296875000e-01     6.672255245643446e-01
     5.235595703125000e-01     8.894477467865669e-01
    -7.264404296875000e-01    -8.142559569171366e-01
    -2.264404296875000e-01     5.190773764161967e-01
     7.735595703125000e-01    -5.920337346949144e-01
    -8.514404296875000e-01     7.463293197175203e-02
     6.485595703125000e-01     2.968551541939743e-01
     8.985595703125000e-01     3.956205862927398e-01
    -9.139404296875000e-01    -7.154905248183712e-01
    -4.139404296875000e-01     6.178428085149619e-01
    -6.639404296875000e-01     1.733983640705177e-01
     8.360595703125000e-01    -1.969720062998528e-01
    -7.889404296875000e-01     4.696946603668140e-01
     7.110595703125000e-01     6.919168825890358e-01
     9.610595703125000e-01    -7.895645988924452e-01
    -9.451904296875000e-01    -1.228979322257787e-01
    -6.951904296875000e-01     7.659909566631100e-01
    -1.951904296875000e-01     3.215465122186658e-01
     8.048095703125000e-01     9.882131788853323e-01
    -8.201904296875000e-01    -9.788650104150790e-01
    -3.201904296875000e-01     3.544683229182541e-01
     6.798095703125000e-01    -7.566427881928568e-01
     4.298095703125000e-01     5.766905451404762e-01
     9.298095703125000e-01     1.322461006960320e-01
    -8.826904296875000e-01     7.989127673626986e-01
     6.173095703125000e-01     4.285423969923283e-01
    -6.326904296875000e-01    -6.825687141187827e-01
     8.673095703125000e-01    -4.603464918965605e-01
    -7.576904296875000e-01     2.063201747701060e-01
     7.423095703125000e-01    -1.640501956002642e-01
    -5.076904296875000e-01     5.026164710664023e-01
    -9.959716796875000e-01    -3.862724178224864e-01
     4.028320312500000e-03     2.803942488441802e-01
    -7.459716796875000e-01    -2.875069857237210e-01
     2.540283203125000e-01     3.791596809429454e-01
     7.540283203125000e-01    -6.528476350149881e-02
    -8.709716796875000e-01     6.013819031651677e-01
     6.290283203125000e-01     8.236041253873900e-01
    -1.209716796875000e-01     4.532337550170198e-01
     8.790283203125000e-01    -6.578773560940914e-01
    -9.334716796875000e-01     8.789310572575149e-03
    -6.834716796875000e-01     8.976781994614640e-01
     8.165283203125000e-01     5.273078290910937e-01
    -8.084716796875000e-01    -5.838032820200173e-01
     6.915283203125000e-01    -3.615810597977951e-01
     9.415283203125000e-01    -2.628156276990297e-01
    -9.647216796875000e-01     4.038510389676369e-01
     5.352783203125000e-01     6.260732611898590e-01
    -7.147216796875000e-01    -4.850378499212519e-01
     7.852783203125000e-01    -8.554082202916222e-01
    -8.397216796875000e-01    -1.887415536249556e-01
     1.602783203125000e-01     4.779251130417110e-01
     6.602783203125000e-01     3.348066859726662e-02
    -5.897216796875000e-01     7.001473352639329e-01
    -8.972167968750000e-02     2.557028908194887e-01
     9.102783203125000e-01     9.223695574861552e-01
    -9.022216796875000e-01    -7.813341462175482e-01
    -4.022216796875000e-01     5.519991871157850e-01
    -6.522216796875000e-01     1.075547426713406e-01
     8.477783203125000e-01     3.297769648935629e-01
     7.227783203125000e-01     3.407509017934258e-01
     9.727783203125000e-01    -5.481379870954631e-01
    -9.803466796875000e-01     1.185286795712037e-01
    -7.303466796875000e-01     4.148249758675000e-01
     7.696533203125000e-01     6.370471980897219e-01
    -8.553466796875000e-01    -4.740639130213891e-01
     1.446533203125000e-01     1.926027536452777e-01
     6.446533203125000e-01    -8.444342833917594e-01
    -6.053466796875000e-01    -1.777676167250928e-01
     3.946533203125000e-01     4.888990499415740e-01
     8.946533203125000e-01     4.445460549712954e-02
    -9.178466796875000e-01     7.111212721637961e-01
    -1.678466796875000e-01     3.654422598181171e-01
     8.321533203125000e-01    -7.456688512929940e-01
    -7.928466796875000e-01    -7.900218462632735e-02
     2.071533203125000e-01     5.876644820403394e-01
     7.071533203125000e-01     1.432200375958952e-01
    -5.428466796875000e-01     8.098867042625617e-01
     9.571533203125000e-01     4.395163338921915e-01
    -9.490966796875000e-01    -6.715947772189199e-01
    -4.490966796875000e-01     6.617385561144133e-01
    -6.990966796875000e-01     2.172941116699691e-01
     8.009033203125000e-01    -1.530762587004014e-01
    -8.240966796875000e-01     5.135904079662654e-01
     6.759033203125000e-01     7.358126301884873e-01
    -8.865966796875000e-01    -2.765330488238582e-01
     1.134033203125000e-01     3.901336178428085e-01
     6.134033203125000e-01    -5.431082660163600e-02
    -6.365966796875000e-01     6.123558400650306e-01
     8.634033203125000e-01     8.345780622872530e-01
    -7.615966796875000e-01    -8.691256414164508e-01
    -2.615966796875000e-01     4.642076919168827e-01
     7.384033203125000e-01    -6.469034191942286e-01
     4.884033203125000e-01     6.864299141391046e-01
     9.884033203125000e-01     2.419854696946604e-01
    -9.881591796875000e-01     9.086521363613269e-01
     5.118408203125000e-01     5.382817659909567e-01
    -7.381591796875000e-01    -5.728293451201545e-01
     7.618408203125000e-01    -3.506071228979323e-01
    -8.631591796875000e-01     3.160595437687346e-01
     6.368408203125000e-01    -3.176853121983438e-01
    -6.131591796875000e-01     3.489813544683229e-01
     8.868408203125000e-01     5.712035766905450e-01
    -9.256591796875000e-01    -5.399075344205659e-01
    -4.256591796875000e-01     7.934257989127673e-01
    -6.756591796875000e-01    -2.436112381242698e-01
     3.243408203125000e-01     4.230554285423971e-01
     8.243408203125000e-01    -2.138901590204756e-02
    -8.006591796875000e-01     6.452776507646190e-01
     6.993408203125000e-01     8.674998729868413e-01
    -5.065917968750000e-02     4.971295026164710e-01
     9.493408203125000e-01    -6.139816084946401e-01
    -9.569091796875000e-01     5.268505817202662e-02
    -7.069091796875000e-01     9.415739470609155e-01
     7.930908203125000e-01     3.736727124930141e-01
    -8.319091796875000e-01    -7.374383986180968e-01
    -3.319091796875000e-01     5.958949347152365e-01
     6.680908203125000e-01    -5.152161763958747e-01
     9.180908203125000e-01    -2.189198800995784e-01
    -8.944091796875000e-01     4.477467865670886e-01
     6.055908203125000e-01     6.699690087893104e-01
    -6.444091796875000e-01    -4.411421023218006e-01
     8.555908203125000e-01    -8.115124726921710e-01
    -7.694091796875000e-01    -1.448458060255043e-01
     2.305908203125000e-01     5.218208606411625e-01
     7.305908203125000e-01     7.737641619671787e-02
    -5.194091796875000e-01     7.440430828633844e-01
    -1.940917968750000e-02     2.995986384189402e-01
    -7.225341796875000e-01    -4.608037392673892e-02
     2.774658203125000e-01     6.205862927399277e-01
     7.774658203125000e-01     1.761418482954835e-01
    -8.475341796875000e-01     8.428085149621500e-01
     6.524658203125000e-01     4.724381445917798e-01
     9.024658203125000e-01    -4.164507442971093e-01
    -9.100341796875000e-01     2.502159223695575e-01
    -6.600341796875000e-01     5.465122186658538e-01
     8.399658203125000e-01     7.687344408880759e-01
    -7.850341796875000e-01    -3.423766702230352e-01
     2.149658203125000e-01     3.242899964436317e-01
     9.649658203125000e-01    -8.723263730122444e-02
    -9.412841796875000e-01     5.794340293654421e-01
     5.587158203125000e-01     8.016562515876644e-01
    -6.912841796875000e-01    -9.020474521160392e-01
    -1.912841796875000e-01     4.312858812172942e-01
     8.087158203125000e-01    -6.798252298938170e-01
    -8.162841796875000e-01    -1.315856322715037e-02
     6.837158203125000e-01     2.090636589950718e-01
    -5.662841796875000e-01     8.757303256617384e-01
     9.337158203125000e-01     5.053599552913681e-01
    -8.787841796875000e-01    -6.057511558197430e-01
    -3.787841796875000e-01     7.275821775135902e-01
     6.212158203125000e-01    -3.835289335975207e-01
    -6.287841796875000e-01     2.831377330691460e-01
     8.712158203125000e-01    -2.847635014987553e-01
    -7.537841796875000e-01     3.819031651679112e-01
     7.462158203125000e-01     6.041253873901336e-01
    -9.979248046875000e-01    -2.106894274246812e-01
     2.075195312500000e-03     4.559772392419856e-01
    -7.479248046875000e-01     6.781994614642075e-01
     7.520751953125000e-01     9.004216836864298e-01
    -8.729248046875000e-01    -8.032820200172738e-01
    -3.729248046875000e-01     5.300513133160596e-01
     6.270751953125000e-01    -5.810597977950516e-01
    -6.229248046875000e-01     8.560686887161495e-02
     3.770751953125000e-01     7.522735355382815e-01
     8.770751953125000e-01     3.078290910938373e-01
    -9.354248046875000e-01     9.744957577605038e-01
    -6.854248046875000e-01    -7.045165879185085e-01
     8.145751953125000e-01    -4.822943656962861e-01
    -8.104248046875000e-01     1.843723009703806e-01
     6.895751953125000e-01    -1.859980693999899e-01
    -5.604248046875000e-01     4.806685972666769e-01
     9.395751953125000e-01     7.028908194888988e-01
    -9.666748046875000e-01    -4.082202916222121e-01
     3.332519531250000e-02     2.584463750444546e-01
    -7.166748046875000e-01    -1.119239953259158e-01
     2.833251953125000e-01     5.547426713407508e-01
     7.833251953125000e-01     1.102982268963064e-01
    -8.416748046875000e-01     7.769648935629729e-01
    -9.167480468750000e-02     3.337397754407356e-01
     9.083251953125000e-01    -7.773713356703754e-01
    -9.041748046875000e-01    -1.107046690037089e-01
    -6.541748046875000e-01     7.781842198851801e-01
     8.458251953125000e-01     4.078138495148098e-01
    -7.791748046875000e-01    -7.032972615963013e-01
    -2.791748046875000e-01     6.300360717370317e-01
     7.208251953125000e-01    -4.810750393740792e-01
     4.708251953125000e-01     8.522582939592540e-01
     9.708251953125000e-01    -1.847787430777830e-01
    -9.822998046875000e-01     4.818879235888838e-01
     5.177001953125000e-01     7.041101458111059e-01
    -7.322998046875000e-01    -4.070009653000052e-01
     7.677001953125000e-01    -9.749021998679063e-01
    -8.572998046875000e-01    -3.082355332012398e-01
     1.427001953125000e-01     3.584311334654269e-01
     6.427001953125000e-01    -8.601331097901754e-02
    -6.072998046875000e-01     5.806533556876492e-01
     8.927001953125000e-01     8.028755779098715e-01
    -9.197998046875000e-01    -9.008281257938322e-01
    -4.197998046875000e-01     4.325052075395013e-01
    -6.697998046875000e-01    -1.193923690494347e-02
     3.302001953125000e-01     6.547274297617232e-01
     8.302001953125000e-01     2.102829853172790e-01
    -7.947998046875000e-01     8.769496519839455e-01
     7.052001953125000e-01     5.065792816135752e-01
     9.552001953125000e-01    -3.823096072753138e-01
    -9.510498046875000e-01     2.843570593913529e-01
    -7.010498046875000e-01     3.831224914901183e-01
     7.989501953125000e-01     6.053447137123404e-01
    -8.260498046875000e-01    -5.057663973987705e-01
     6.739501953125000e-01    -8.761367677691408e-01
     4.239501953125000e-01     4.571965655641925e-01
     9.239501953125000e-01     1.275212111974811e-02
    -8.885498046875000e-01     6.794187877864144e-01
     6.114501953125000e-01     9.016410100086367e-01
    -6.385498046875000e-01    -8.020626936950668e-01
    -1.385498046875000e-01     5.312706396382665e-01
     8.614501953125000e-01    -5.798404714728447e-01
    -7.635498046875000e-01     8.682619519382206e-02
     7.364501953125000e-01     3.090484174160444e-01
     9.864501953125000e-01     3.419702281156327e-01
    -9.901123046875000e-01    -7.691408829954783e-01
    -4.901123046875000e-01     5.641924503378548e-01
    -7.401123046875000e-01     1.197480058934106e-01
     7.598876953125000e-01    -2.506223644769600e-01
    -8.651123046875000e-01     4.160443021897069e-01
     6.348876953125000e-01     6.382665244119288e-01
    -6.151123046875000e-01    -4.728445866991822e-01
     8.848876953125000e-01    -8.432149570695524e-01
    -9.276123046875000e-01    -1.765482904028859e-01
     7.238769531250000e-02     4.901183762637809e-01
    -6.776123046875000e-01     7.123405984860030e-01
    -1.776123046875000e-01     2.678961540415588e-01
     8.223876953125000e-01     9.345628207082253e-01
    -8.026123046875000e-01    -9.666717471930092e-01
    -3.026123046875000e-01     3.666615861403240e-01
     6.973876953125000e-01    -7.444495249707870e-01
     4.473876953125000e-01     5.888838083625463e-01
     9.473876953125000e-01     1.444393639181021e-01
    -9.588623046875000e-01     8.111060305847686e-01
    -7.088623046875000e-01    -6.703754508967129e-01
     7.911376953125000e-01    -4.481532286744908e-01
    -8.338623046875000e-01     2.185134379921760e-01
     6.661376953125000e-01    -1.518569323781945e-01
    -5.838623046875000e-01     5.148097342884723e-01
     9.161376953125000e-01     7.370319565106942e-01
    -8.963623046875000e-01    -3.740791546004167e-01
     1.036376953125000e-01     2.925875120662500e-01
    -6.463623046875000e-01    -2.753137225016513e-01
     3.536376953125000e-01     3.913529441650154e-01
     8.536376953125000e-01    -5.309150027942910e-02
    -7.713623046875000e-01     6.135751663872375e-01
     7.286376953125000e-01     8.357973886094598e-01
    -2.136230468750000e-02     4.654270182390896e-01
     9.786376953125000e-01    -6.456840928720216e-01
    -9.744873046875000e-01     2.098257379464519e-02
    -7.244873046875000e-01     9.098714626835338e-01
     7.755126953125000e-01     5.395010923131636e-01
    -8.494873046875000e-01    -5.716100187979475e-01
     6.505126953125000e-01    -3.493877965757254e-01
     9.005126953125000e-01    -3.164659858761368e-01
    -9.119873046875000e-01     3.502006807905298e-01
     5.880126953125000e-01     5.724229030127519e-01
    -6.619873046875000e-01    -5.386882080983590e-01
     8.380126953125000e-01    -9.090585784687294e-01
    -7.869873046875000e-01    -2.423919118020628e-01
     2.130126953125000e-01     4.242747548646040e-01
     7.130126953125000e-01    -2.016968957984056e-02
    -5.369873046875000e-01     6.464969770868259e-01
    -3.698730468750000e-02     2.020525326423817e-01
    -9.432373046875000e-01    -8.349845043946553e-01
    -4.432373046875000e-01     4.983488289386779e-01
    -6.932373046875000e-01     5.390438449423351e-02
     8.067626953125000e-01     2.761266067164558e-01
    -8.182373046875000e-01     9.427932733831224e-01
     6.817626953125000e-01     3.748920388152210e-01
     9.317626953125000e-01    -5.139968500736677e-01
    -8.807373046875000e-01     1.526698165929992e-01
     6.192626953125000e-01    -2.177005537773714e-01
    -6.307373046875000e-01     4.489661128892954e-01
     8.692626953125000e-01     6.711883351115173e-01
    -7.557373046875000e-01    -4.399227759995936e-01
     7.442626953125000e-01    -8.102931463699639e-01
     4.942626953125000e-01     5.230401869633694e-01
     9.942626953125000e-01     7.859574251892476e-02
    -9.940185546875000e-01     7.452624091855913e-01
    -7.440185546875000e-01    -9.337499364934208e-01
    -2.440185546875000e-01     3.995833968399125e-01
     7.559814453125000e-01    -7.115277142711985e-01
    -8.690185546875000e-01    -4.486104760453191e-02
     6.309814453125000e-01     1.773611746176904e-01
    -6.190185546875000e-01     8.440278412843569e-01
     8.809814453125000e-01     4.736574709139867e-01
    -9.315185546875000e-01    -6.374536401971245e-01
    -4.315185546875000e-01     6.958796931362086e-01
    -6.815185546875000e-01     2.514352486917644e-01
     8.184814453125000e-01    -1.189351216786060e-01
    -8.065185546875000e-01     5.477315449880606e-01
     6.934814453125000e-01     7.699537672102827e-01
    -9.627685546875000e-01    -3.301834070009654e-01
     3.723144531250000e-02     3.364832596657013e-01
    -7.127685546875000e-01     5.587054818879233e-01
     7.872314453125000e-01     7.809277041101457e-01
    -8.377685546875000e-01    -9.227759995935579e-01
    -3.377685546875000e-01     4.105573337397754e-01
     6.622314453125000e-01    -7.005537773713357e-01
     4.122314453125000e-01     6.327795559619973e-01
     9.122314453125000e-01     1.883351115175531e-01
    -9.002685546875000e-01     8.550017781842196e-01
     5.997314453125000e-01     4.846314078138494e-01
    -6.502685546875000e-01    -6.264797032972615e-01
     8.497314453125000e-01    -4.042574810750394e-01
    -7.752685546875000e-01     2.624091855916273e-01
     7.247314453125000e-01    -3.054920489762740e-01
     9.747314453125000e-01     5.833968399126148e-01
    -9.783935546875000e-01    -5.277142711984961e-01
    -4.783935546875000e-01     8.056190621348371e-01
    -7.283935546875000e-01    -2.314179749022000e-01
     2.716064453125000e-01     4.352486917644669e-01
     7.716064453125000e-01    -9.195752679977742e-03
    -8.533935546875000e-01     6.574709139866888e-01
     6.466064453125000e-01     8.796931362089111e-01
    -1.033935546875000e-01     5.093227658385409e-01
     8.966064453125000e-01    -6.017883452725703e-01
    -9.158935546875000e-01     6.487832139409622e-02
     8.341064453125000e-01     3.858659757150840e-01
    -7.908935546875000e-01    -7.252451353960270e-01
    -2.908935546875000e-01     6.080881979373061e-01
     7.091064453125000e-01    -5.030229131738049e-01
     4.591064453125000e-01     8.303104201595284e-01
     9.591064453125000e-01    -2.067266168775086e-01
    -9.471435546875000e-01     4.599400497891581e-01
     5.528564453125000e-01     6.821622720113800e-01
    -6.971435546875000e-01    -4.289488390997308e-01
     8.028564453125000e-01    -7.993192094701012e-01
    -8.221435546875000e-01    -1.326525428034345e-01
     1.778564453125000e-01     5.340141238632321e-01
     6.778564453125000e-01     8.956967941878768e-02
    -5.721435546875000e-01     7.562363460854542e-01
    -7.214355468750000e-02     3.117919016410100e-01
    -6.346435546875000e-01    -9.973073210384609e-02
     3.653564453125000e-01     5.669359345628204e-01
     8.653564453125000e-01     1.224914901183762e-01
    -7.596435546875000e-01     7.891581567850428e-01
     7.403564453125000e-01     4.187877864146725e-01
     9.903564453125000e-01    -4.701011024742164e-01
    -9.862060546875000e-01     1.965655641924502e-01
    -7.362060546875000e-01     4.928618604887465e-01
     7.637939453125000e-01     7.150840827109686e-01
    -8.612060546875000e-01    -3.960270284001424e-01
     1.387939453125000e-01     2.706396382665244e-01
    -6.112060546875000e-01    -2.972615963013769e-01
     8.887939453125000e-01    -7.503937407915473e-02
    -9.237060546875000e-01     5.916272925875119e-01
     5.762939453125000e-01     8.138495148097342e-01
    -6.737060546875000e-01    -8.898541888939694e-01
    -1.737060546875000e-01     4.434791444393640e-01
     8.262939453125000e-01    -6.676319666717472e-01
    -7.987060546875000e-01    -9.653000050806604e-04
     7.012939453125000e-01     2.212569222171417e-01
     9.512939453125000e-01     5.175532185134379e-01
    -9.549560546875000e-01    -5.935578925976731e-01
    -4.549560546875000e-01     7.397754407356598e-01
    -7.049560546875000e-01     2.953309962912156e-01
     7.950439453125000e-01    -2.725702382766856e-01
    -8.299560546875000e-01     3.940964283899810e-01
     6.700439453125000e-01     6.163186506122031e-01
     9.200439453125000e-01    -8.651628308692780e-01
    -8.924560546875000e-01    -1.984961642026115e-01
     1.075439453125000e-01     4.681705024640552e-01
     6.075439453125000e-01     2.372605801961081e-02
    -6.424560546875000e-01     6.903927246862771e-01
    -1.424560546875000e-01     2.459482802418329e-01
     8.575439453125000e-01     9.126149469084994e-01
    -7.674560546875000e-01    -7.910887567952040e-01
    -2.674560546875000e-01     5.422445765381292e-01
     7.325439453125000e-01    -5.688665345729818e-01
     4.825439453125000e-01     7.644667987603513e-01
     9.825439453125000e-01     3.200223543159071e-01
    -9.705810546875000e-01     9.866890209825736e-01
    -7.205810546875000e-01    -7.581669460956155e-01
    -2.205810546875000e-01     5.751663872377175e-01
     7.794189453125000e-01    -5.359447238733933e-01
    -8.455810546875000e-01     1.307219427932733e-01
     6.544189453125000e-01    -2.396484275770970e-01
    -5.955810546875000e-01     4.270182390895696e-01
     9.044189453125000e-01     6.492404613117915e-01
    -9.080810546875000e-01    -4.618706497993192e-01
     9.191894531250000e-02     2.047960168673473e-01
    -6.580810546875000e-01    -1.655743535030230e-01
     3.419189453125000e-01     5.010923131636436e-01
     8.419189453125000e-01     5.664786871919913e-02
    -7.830810546875000e-01     7.233145353858657e-01
     7.169189453125000e-01     9.455367576080880e-01
    -3.308105468750000e-02     3.776355230401867e-01
     9.669189453125000e-01    -7.334755880709242e-01
    -9.393310546875000e-01    -6.680892140425754e-02
    -6.893310546875000e-01     8.220799674846313e-01
     8.106689453125000e-01     4.517095971142611e-01
    -8.143310546875000e-01    -6.594015139968501e-01
    -3.143310546875000e-01     6.739318193364829e-01
     6.856689453125000e-01    -4.371792917746279e-01
     9.356689453125000e-01    -1.408829954783316e-01
    -8.768310546875000e-01     5.257836711883350e-01
     6.231689453125000e-01     7.480058934105569e-01
    -6.268310546875000e-01    -3.631052177005538e-01
     8.731689453125000e-01    -9.310064522684550e-01
    -7.518310546875000e-01    -2.643397856017884e-01
     2.481689453125000e-01     4.023268810648781e-01
     7.481689453125000e-01    -4.211756337956618e-02
    -5.018310546875000e-01     6.245491032871002e-01
    -1.831054687500000e-03     1.801046588426560e-01
    -4.989013671875000e-01     4.764009551389523e-01
    -7.489013671875000e-01     3.195651069450789e-02
     7.510986328125000e-01     2.541787329167300e-01
    -8.739013671875000e-01     9.208453995833965e-01
     6.260986328125000e-01     5.504750292130263e-01
    -6.239013671875000e-01    -5.606360818980847e-01
     8.760986328125000e-01    -3.384138596758625e-01
    -9.364013671875000e-01     3.282528069908042e-01
    -6.864013671875000e-01     3.392267438906671e-01
     8.135986328125000e-01     5.614489661128892e-01
    -8.114013671875000e-01    -5.496621449982219e-01
     6.885986328125000e-01    -9.200325153685922e-01
     9.385986328125000e-01    -3.114362647970337e-02
    -9.676513671875000e-01     6.355230401869632e-01
     5.323486328125000e-01     8.577452624091855e-01
    -7.176513671875000e-01    -8.459584412945181e-01
    -2.176513671875000e-01     4.873748920388152e-01
     7.823486328125000e-01    -6.237362190722959e-01
    -8.426513671875000e-01     4.293044759437081e-02
     6.573486328125000e-01     2.651526698165931e-01
     9.073486328125000e-01     3.639181019153583e-01
    -9.051513671875000e-01    -7.471930091957527e-01
    -4.051513671875000e-01     5.861403241375807e-01
    -6.551513671875000e-01     1.416958796931365e-01
     8.448486328125000e-01    -2.286744906772342e-01
    -7.801513671875000e-01     4.379921759894327e-01
     7.198486328125000e-01     6.602143982116546e-01
    -9.832763671875000e-01    -1.546004166031602e-01
     1.672363281250000e-02     5.120662500635067e-01
    -7.332763671875000e-01     7.342884722857286e-01
    -2.332763671875000e-01     2.898440278412844e-01
     7.667236328125000e-01     9.565106945079509e-01
    -8.582763671875000e-01    -9.447238733932836e-01
    -3.582763671875000e-01     3.886094599400498e-01
     6.417236328125000e-01    -7.225016511710614e-01
    -6.082763671875000e-01    -5.583498450439472e-02
     3.917236328125000e-01     6.108316821622719e-01
     8.917236328125000e-01     1.663872377178277e-01
    -9.207763671875000e-01     8.330539043844942e-01
     5.792236328125000e-01     4.626835340141240e-01
    -6.707763671875000e-01    -6.484275770969873e-01
     8.292236328125000e-01    -4.262053548747651e-01
    -7.957763671875000e-01     2.404613117919017e-01
     7.042236328125000e-01    -1.299090585784688e-01
    -5.457763671875000e-01     5.367576080881979e-01
     9.542236328125000e-01     7.589798303104200e-01
    -9.520263671875000e-01    -3.521312808006910e-01
     4.797363281250000e-02     3.145353858659758e-01
    -7.020263671875000e-01    -3.192094701011026e-01
     2.979736328125000e-01     3.474571965655642e-01
     7.979736328125000e-01    -9.698724787888036e-02
    -8.270263671875000e-01     5.696794187877863e-01
     6.729736328125000e-01     7.919016410100086e-01
    -7.702636718750000e-02     4.215312706396384e-01
     9.229736328125000e-01    -6.895798404714728e-01
    -8.895263671875000e-01    -2.291317380480629e-02
     6.104736328125000e-01     1.993090484174160e-01
    -6.395263671875000e-01     8.659757150840826e-01
     8.604736328125000e-01     4.956053447137123e-01
    -7.645263671875000e-01    -6.155057663973988e-01
     7.354736328125000e-01    -3.932835441751766e-01
     9.854736328125000e-01    -2.945181120764112e-01
    -9.910888671875000e-01     3.721485545902554e-01
     5.089111328125000e-01     5.943707768124777e-01
    -7.410888671875000e-01    -5.167403342986334e-01
     7.589111328125000e-01    -8.871107046690037e-01
    -8.660888671875000e-01    -2.204440380023371e-01
     1.339111328125000e-01     4.462226286643298e-01
     6.339111328125000e-01     1.778184219885182e-03
    -6.160888671875000e-01     6.684448508865517e-01
    -1.160888671875000e-01     2.240004064421075e-01
     8.839111328125000e-01     8.906670731087740e-01
    -9.285888671875000e-01    -8.130366305949297e-01
    -4.285888671875000e-01     5.202967027384038e-01
    -6.785888671875000e-01     7.585225829395914e-02
     8.214111328125000e-01     2.980744805161815e-01
    -8.035888671875000e-01     9.647411471828480e-01
     6.964111328125000e-01     3.968399126149469e-01
     9.464111328125000e-01    -4.920489762739421e-01
    -9.598388671875000e-01     1.746176903927248e-01
    -7.098388671875000e-01     4.709139866890211e-01
     7.901611328125000e-01     6.931362089112429e-01
    -8.348388671875000e-01    -4.179749021998680e-01
     1.651611328125000e-01     2.486917644667987e-01
     6.651611328125000e-01    -7.883452725702382e-01
     4.151611328125000e-01     5.449880607630950e-01
     9.151611328125000e-01     1.005436163186506e-01
    -8.973388671875000e-01     7.672102829853171e-01
    -1.473388671875000e-01     3.556876492404613e-01
     8.526611328125000e-01    -7.554234618706498e-01
    -7.723388671875000e-01    -8.875679520398316e-02
     2.276611328125000e-01     5.779098714626834e-01
     7.276611328125000e-01     1.334654270182392e-01
    -5.223388671875000e-01     8.001320936849057e-01
     9.776611328125000e-01     4.297617233145354e-01
    -9.754638671875000e-01    -6.813493877965757e-01
    -4.754638671875000e-01     6.519839455367573e-01
    -7.254638671875000e-01     2.075395010923131e-01
     7.745361328125000e-01    -1.628308692780572e-01
    -8.504638671875000e-01     5.038357973886094e-01
     6.495361328125000e-01     7.260580196108315e-01
    -6.004638671875000e-01    -3.850530915002794e-01
     8.995361328125000e-01    -9.529543260681806e-01
    -9.129638671875000e-01    -2.862876594015140e-01
     8.703613281250000e-02     3.803790072651525e-01
    -6.629638671875000e-01     6.026012294873748e-01
     8.370361328125000e-01     8.248234517095971e-01
    -7.879638671875000e-01    -8.788802519941066e-01
    -2.879638671875000e-01     4.544530813392269e-01
     7.120361328125000e-01    -6.566580297718845e-01
     4.620361328125000e-01     6.766753035614488e-01
     9.620361328125000e-01     2.322308591170046e-01
    -9.442138671875000e-01     8.988975257836711e-01
     5.557861328125000e-01     5.285271554133009e-01
    -6.942138671875000e-01    -5.825839556978103e-01
     8.057861328125000e-01    -3.603617334755881e-01
    -8.192138671875000e-01     3.063049331910785e-01
     6.807861328125000e-01    -2.615963013768227e-01
     9.307861328125000e-01     6.272925875120661e-01
    -8.817138671875000e-01    -4.838185235990449e-01
     1.182861328125000e-01     1.828481430676219e-01
    -6.317138671875000e-01    -1.875222273027486e-01
     3.682861328125000e-01     4.791444393639182e-01
     8.682861328125000e-01     3.469999491947373e-02
    -7.567138671875000e-01     7.013666615861400e-01
     7.432861328125000e-01     9.235888838083623e-01
     9.932861328125000e-01    -5.578925976731191e-01
    -9.949951171875000e-01     1.087740689935477e-01
     7.550048828125000e-01     3.346542701823909e-01
    -8.699951171875000e-01    -7.764568409287202e-01
    -3.699951171875000e-01     5.568764924046130e-01
     6.300048828125000e-01    -5.542346187064980e-01
    -6.199951171875000e-01     1.124320479601688e-01
     8.800048828125000e-01    -2.579383224102018e-01
    -9.324951171875000e-01     4.087283442564651e-01
     5.675048828125000e-01     6.309505664786870e-01
    -6.824951171875000e-01    -4.801605446324240e-01
     8.175048828125000e-01    -8.505309150027943e-01
    -8.074951171875000e-01    -1.838642483361277e-01
     1.925048828125000e-01     4.828024183305391e-01
     6.925048828125000e-01     3.835797388609463e-02
    -5.574951171875000e-01     7.050246405527612e-01
    -5.749511718750000e-02     2.605801961083170e-01
    -7.137451171875000e-01    -8.509881623736226e-02
     2.862548828125000e-01     5.815678504293045e-01
     7.862548828125000e-01     1.371234059848603e-01
    -8.387451171875000e-01     8.037900726515268e-01
     6.612548828125000e-01     4.334197022811566e-01
     9.112548828125000e-01    -4.554691866077326e-01
    -9.012451171875000e-01     2.111974800589342e-01
    -6.512451171875000e-01     5.074937763552305e-01
     8.487548828125000e-01     7.297159985774524e-01
    -7.762451171875000e-01    -3.813951125336585e-01
     2.237548828125000e-01     2.852715541330082e-01
     7.237548828125000e-01    -9.492963471015597e-01
     9.737548828125000e-01    -6.040745821267091e-02
    -9.793701171875000e-01     6.062592084539957e-01
     5.206298828125000e-01     8.284814306762180e-01
    -7.293701171875000e-01    -8.752222730274857e-01
    -2.293701171875000e-01     4.581110603058478e-01
     7.706298828125000e-01    -6.530000508052635e-01
    -8.543701171875000e-01     1.366661586140339e-02
     6.456298828125000e-01     2.358888380836255e-01
    -6.043701171875000e-01     9.025555047502920e-01
     8.956298828125000e-01     5.321851343799218e-01
    -9.168701171875000e-01    -5.789259767311894e-01
    -4.168701171875000e-01     7.544073566021439e-01
    -6.668701171875000e-01     3.099629121576997e-01
     8.331298828125000e-01    -3.237819438093787e-01
    -7.918701171875000e-01     3.428847228572880e-01
     7.081298828125000e-01     5.651069450795101e-01
    -9.481201171875000e-01    -2.497078697353047e-01
     5.187988281250000e-02     4.169587969313622e-01
    -6.981201171875000e-01     6.391810191535841e-01
     8.018798828125000e-01     8.614032413758064e-01
    -8.231201171875000e-01    -8.423004623278971e-01
    -3.231201171875000e-01     4.910328710054361e-01
     6.768798828125000e-01    -6.200782401056750e-01
     4.268798828125000e-01     7.132550932276582e-01
     9.268798828125000e-01     2.688106487832140e-01
    -8.856201171875000e-01     9.354773154498806e-01
     6.143798828125000e-01     3.675760808819792e-01
    -6.356201171875000e-01    -7.435350302291317e-01
     8.643798828125000e-01    -5.213128080069096e-01
    -7.606201171875000e-01     1.453538586597574e-01
     7.393798828125000e-01    -2.250165117106133e-01
     9.893798828125000e-01     6.638723771782755e-01
    -9.871826171875000e-01    -4.472387339328355e-01
     1.281738281250000e-02     2.194279327338313e-01
    -7.371826171875000e-01    -1.509424376365393e-01
     2.628173828125000e-01     5.157242290301276e-01
     7.628173828125000e-01     7.127978458568296e-02
    -8.621826171875000e-01     7.379464512523495e-01
    -1.121826171875000e-01     3.922674389066707e-01
     8.878173828125000e-01    -7.188436722044405e-01
    -9.246826171875000e-01    -5.217700553777382e-02
    -6.746826171875000e-01     8.367118833511151e-01
     8.253173828125000e-01     4.663415129807449e-01
    -7.996826171875000e-01    -6.447695981303663e-01
    -2.996826171875000e-01     6.885637352029668e-01
     7.003173828125000e-01    -4.225473759081442e-01
     9.503173828125000e-01    -1.262510796118479e-01
    -9.559326171875000e-01     5.404155870548188e-01
     5.440673828125000e-01     7.626378092770409e-01
    -7.059326171875000e-01    -3.484733018340701e-01
     2.940673828125000e-01     3.181933648325967e-01
     7.940673828125000e-01    -9.822181578011482e-01
    -8.309326171875000e-01    -3.155514911344816e-01
     1.690673828125000e-01     3.511151755321851e-01
     6.690673828125000e-01    -9.332926891225934e-02
    -5.809326171875000e-01     5.733373977544072e-01
     9.190673828125000e-01     7.955596199766295e-01
    -8.934326171875000e-01    -9.081440837270741e-01
    -3.934326171875000e-01     4.251892496062593e-01
    -6.434326171875000e-01    -1.925519483818527e-02
     3.565673828125000e-01     6.474114718284811e-01
     8.565673828125000e-01     2.029670273840369e-01
    -7.684326171875000e-01     8.696336940507035e-01
     7.315673828125000e-01     4.992633236803332e-01
     9.815673828125000e-01    -3.896255652085556e-01
    -9.715576171875000e-01     2.770411014581111e-01
    -7.215576171875000e-01     3.758065335568763e-01
     7.784423828125000e-01     5.980287557790986e-01
    -8.465576171875000e-01    -5.130823553320125e-01
     4.034423828125000e-01     4.498806076309507e-01
     9.034423828125000e-01     5.436163186506082e-03
    -9.090576171875000e-01     6.721028298531726e-01
     5.909423828125000e-01     8.943250520753949e-01
    -6.590576171875000e-01    -8.093786516283087e-01
    -1.590576171875000e-01     5.239546817050247e-01
     8.409423828125000e-01    -5.871564294060865e-01
    -7.840576171875000e-01     7.951023726058004e-02
     7.159423828125000e-01     3.017324594828024e-01
     9.659423828125000e-01     4.004978915815678e-01
    -9.403076171875000e-01    -7.106132195295434e-01
    -4.403076171875000e-01     6.227201138037899e-01
    -6.903076171875000e-01     1.782756693593457e-01
     8.096923828125000e-01    -1.920947010110248e-01
    -8.153076171875000e-01     4.745719656556420e-01
     6.846923828125000e-01     6.967941878778638e-01
     9.346923828125000e-01    -7.846872936036173e-01
    -8.778076171875000e-01    -1.180206269369507e-01
     1.221923828125000e-01     5.486460397297159e-01
     6.221923828125000e-01     1.042015952852715e-01
    -6.278076171875000e-01     7.708682619519380e-01
    -1.278076171875000e-01     3.264238175074938e-01
    -2.528076171875000e-01     3.373977544073565e-01
     7.471923828125000e-01    -7.737133567037545e-01
     4.971923828125000e-01     5.596199766295786e-01
     9.971923828125000e-01     1.151755321851344e-01
    -9.969482421875000e-01     7.818421988518010e-01
    -7.469482421875000e-01    -6.996392826296804e-01
    -2.469482421875000e-01     6.336940507036526e-01
     7.530517578125000e-01    -4.774170604074582e-01
    -8.719482421875000e-01     1.892496062592084e-01
     6.280517578125000e-01    -1.811207641111620e-01
    -6.219482421875000e-01     4.855459025555047e-01
     8.780517578125000e-01     7.077681247777268e-01
    -9.344482421875000e-01    -4.033429863333842e-01
     6.555175781250000e-02     2.633236803332826e-01
    -6.844482421875000e-01    -3.045775542346187e-01
     3.155517578125000e-01     3.620891124320478e-01
     8.155517578125000e-01    -8.235533201239653e-02
    -8.094482421875000e-01     5.843113346542701e-01
     6.905517578125000e-01     8.065335568764924e-01
    -5.944824218750000e-02     4.361631865061222e-01
     9.405517578125000e-01    -6.749479246049891e-01
    -9.656982421875000e-01    -8.281257938322462e-03
    -7.156982421875000e-01     8.806076309505664e-01
     7.843017578125000e-01     5.102372605801961e-01
    -8.406982421875000e-01    -6.008738505309150e-01
     6.593017578125000e-01    -3.786516283086928e-01
     9.093017578125000e-01    -2.798861962099274e-01
    -9.031982421875000e-01     3.867804704567392e-01
     5.968017578125000e-01     6.090026926789613e-01
    -6.531982421875000e-01    -5.021084184321496e-01
     8.468017578125000e-01    -8.724787888025199e-01
    -7.781982421875000e-01    -2.058121221358533e-01
     2.218017578125000e-01     4.608545445308134e-01
     7.218017578125000e-01     1.641010008636901e-02
    -5.281982421875000e-01     6.830767667530353e-01
    -2.819824218750000e-02     2.386323223085911e-01
    -9.813232421875000e-01    -7.984047147284459e-01
    -4.813232421875000e-01     5.349286186048874e-01
    -7.313232421875000e-01     9.048417416044297e-02
     7.686767578125000e-01     3.127063963826653e-01
    -8.563232421875000e-01     9.793730630493318e-01
     6.436767578125000e-01     3.456282070822536e-01
     8.936767578125000e-01    -5.432606818066352e-01
    -9.188232421875000e-01     1.234059848600315e-01
    -6.688232421875000e-01     4.197022811563278e-01
     8.311767578125000e-01     6.419245033785497e-01
    -7.938232421875000e-01    -4.691866077325612e-01
     7.061767578125000e-01    -8.395569781029315e-01
     4.561767578125000e-01     4.937763552304018e-01
     9.561767578125000e-01     4.933191078595733e-02
    -9.500732421875000e-01     7.159985774526239e-01
    -2.000732421875000e-01     3.703195651069449e-01
     7.999267578125000e-01    -7.407915460041661e-01
    -8.250732421875000e-01    -7.412487933749945e-02
     1.749267578125000e-01     5.925417873291672e-01
     6.749267578125000e-01     1.480973428847230e-01
    -5.750732421875000e-01     8.147640095513895e-01
     9.249267578125000e-01     4.443936391810193e-01
    -8.875732421875000e-01    -6.667174719300919e-01
    -3.875732421875000e-01     6.666158614032411e-01
     6.124267578125000e-01    -4.444952497078698e-01
    -6.375732421875000e-01     2.221714169587969e-01
     8.624267578125000e-01    -1.481989534115735e-01
    -7.625732421875000e-01     5.184677132550932e-01
     7.374267578125000e-01     7.406899354773151e-01
    -9.891357421875000e-01    -2.716557435350303e-01
     1.086425781250000e-02     3.950109231316363e-01
    -7.391357421875000e-01     6.172331453538584e-01
     7.608642578125000e-01     8.394553675760807e-01
    -8.641357421875000e-01    -8.642483361276229e-01
    -3.641357421875000e-01     4.690849972057105e-01
     6.358642578125000e-01    -6.420261139054007e-01
    -6.141357421875000e-01     2.464055276126609e-02
     3.858642578125000e-01     6.913072194279324e-01
     8.858642578125000e-01     2.468627749834882e-01
    -9.266357421875000e-01     9.135294416501547e-01
     5.733642578125000e-01     5.431590712797845e-01
    -6.766357421875000e-01    -5.679520398313265e-01
     8.233642578125000e-01    -3.457298176091044e-01
    -8.016357421875000e-01     3.209368490575624e-01
     6.983642578125000e-01    -3.128080069095158e-01
     9.483642578125000e-01     5.760808819793728e-01
    -9.578857421875000e-01    -5.350302291317381e-01
    -4.578857421875000e-01     7.983031042015951e-01
    -7.078857421875000e-01    -2.387339328354418e-01
     2.921142578125000e-01     4.279327338312249e-01
     7.921142578125000e-01    -1.651171061321954e-02
    -8.328857421875000e-01     6.501549560534468e-01
     6.671142578125000e-01     8.723771782756691e-01
    -8.288574218750000e-02     5.020068079052988e-01
     9.171142578125000e-01    -6.091043032058121e-01
    -8.953857421875000e-01     5.756236346085442e-02
     6.046142578125000e-01     2.797845856830767e-01
     8.546142578125000e-01     3.785500177818419e-01
    -7.703857421875000e-01    -7.325610933292690e-01
    -2.703857421875000e-01     6.007722400040643e-01
     7.296142578125000e-01    -5.103388711070467e-01
     4.796142578125000e-01     8.229944622262866e-01
     9.796142578125000e-01    -2.140425748107504e-01
    -9.735107421875000e-01     4.526240918559163e-01
     5.264892578125000e-01     6.748463140781382e-01
    -7.235107421875000e-01    -4.362647970329726e-01
     7.764892578125000e-01    -8.066351674033430e-01
    -8.485107421875000e-01    -1.399685007366763e-01
     1.514892578125000e-01     5.266981659299903e-01
     6.514892578125000e-01     8.225372148554566e-02
    -5.985107421875000e-01     7.489203881522122e-01
    -9.851074218750000e-02     3.044759437077680e-01
    -9.110107421875000e-01    -9.300919575267997e-01
    -4.110107421875000e-01     4.032413758065334e-01
    -6.610107421875000e-01    -4.120306863791090e-02
     3.389892578125000e-01     6.254635980287555e-01
     8.389892578125000e-01     1.810191535843113e-01
    -7.860107421875000e-01     8.476858202509778e-01
     7.139892578125000e-01     4.773154498806076e-01
     9.639892578125000e-01    -4.115734390082812e-01
    -9.422607421875000e-01     2.550932276583853e-01
    -6.922607421875000e-01     5.513895239546815e-01
     8.077392578125000e-01     7.736117461769036e-01
    -8.172607421875000e-01    -3.374993649342072e-01
     1.827392578125000e-01     3.291673017324594e-01
     9.327392578125000e-01    -1.043032058121222e-01
    -8.797607421875000e-01     5.623634608545445e-01
     6.202392578125000e-01     7.845856830767668e-01
    -1.297607421875000e-01     4.142153127063966e-01
     8.702392578125000e-01    -6.968957984047148e-01
    -7.547607421875000e-01    -3.022913173804809e-02
     2.452392578125000e-01     6.364375349286184e-01
     7.452392578125000e-01     1.919930904841742e-01
     9.952392578125000e-01     4.882893867804705e-01
    -9.930419921875000e-01    -6.228217243306406e-01
    -4.930419921875000e-01     7.105116090026926e-01
    -7.430419921875000e-01     2.660671645582484e-01
     7.569580078125000e-01    -3.018340700096530e-01
    -8.680419921875000e-01     3.648325966570136e-01
     6.319580078125000e-01     5.870548188792359e-01
    -6.180419921875000e-01    -5.240562922318752e-01
     8.819580078125000e-01    -8.944266626022456e-01];
end

